#--*-coding:utf-8-*--

class FilledWith < DiceBot
  
  def initialize
    super
    @d66Type = 1;        #d66の差し替え
    # @fractionType = "omit";     #端数の処理 ("omit"=切り捨て, "roundUp"=切り上げ, "roundOff"=四捨五入)
  end
  
  
  def prefixs
    #ダイスボットで使用するコマンドを配列で列挙すること。
    ['3FW.*', '[\+\-\d]*-3FW.*', 'LOT[NP]', 'HST', 'COOK[1-8]', 'RAND.*', 'RENC.*', 'RED.*', 'TRS.*', 'TRAP[ENHL]', 'ROP[ENHL]']
  end
  
  def gameName
    'フィルトウィズ'
  end
  
  def gameType
    "FilledWith"
  end
  
  def getHelpMessage
    return <<MESSAGETEXT
・判定 (3FW@x#y<=z or z-3FW@x#y)
 3個の6面ダイスを振る判定。
 @x:xにクリティカル値を入力。省略可。(省略時クリティカル値4)
 #y:yにファンブル値を入力。省略可(省略時ファンブル値17)
 <=z or z-:zに目標値を入力。±の計算に対応。省略可。
・【必殺技！】 (HST)
 ホムンクルス特技【必殺技！】表。
・マジカルクッキング (COOKx)
 マジカルクッキングのシェフのおすすめコース。
 xにクッキングレベルを入力。(1-8)
・ナンバーワンくじ (LOTN or LOTP)
 LOTNでノーマルくじ、LOTPでプレミアムくじ。(GURPS-FW版)
----------夢幻の迷宮用----------
・共通書式
 a:aに地形(1-6の数字)を入力。省略可。(省略時ランダム決定)
  (1:洞窟 2:遺跡 3:山岳 4:水辺 5:森林 6:墓場)
 d:dに難易度を入力。(E:初級 N:中級 H:上級 L:悪夢)
・ランダムイベント表 (RANDda)
・ランダムエンカウント表 (RENCda)
・エネミーデータ表 (REDde)
 エネミーデータ参照表。
 GMがシークレットダイスで参照するとPLに知られずにエネミーデータを参照可能。
 e:3桁のイベントダイスを入力(D666の結果)。
・トラップ表 (TRAPd)
・財宝表 (TRSr±x)
 r:rに財宝ランクを入力。
 ±x:xに財宝ランク修正値を入力。省略可。
・迷宮追加オプション表(ROPd)
MESSAGETEXT
  end
  
  def rollDiceCommand(command)
    
	#ダイスロールコマンド
	result = checkRoll( command )
	return result unless( result.nil? )
   
    tableName = ""
	text = ""
	number = 0
    
	#各種コマンド
	case command
	  when /LOT(N|P)/
	    type = $1
	    if(type == "P")
	      tableName = "ナンバーワンプレミアムくじ"
	    else
	      tableName = "ナンバーワンノーマルくじ"
	    end
	    result, number = getLotResult(type)
		
	  when "HST"
	    tableName = "【必殺技！】"
	    result, number = getSpecialResult
		
	  when /COOK([1-8])/
	    lv = $1.to_i
		tableName = "マジカルクッキング"
		result, number = getCookResult(lv)
	  
	  when /TRAP[ENHL]/
	    return getTrapResult(command)
		
	  when /TRS.*/i
	    return getTresureResult(command)
	  
	  when /RAND.*/
	    return getRandomEventResult(command)
	  
	  when /RENC.*/
	    return getRandomEventResult(command)
	  
	  when /RED.*/i
	    return getRandomEnemyDataResult(command)
		
	  when /ROP[ENHL]/
	    return getRandomOptionResult(command)
		
	  else
	    return nil
	end
	
	text = "#{tableName}(#{number}):#{result}"
	
	return text
  end
  
  def checkRoll(command)
    crt = 4
	fmb = 17
	
    if(/(\d[\+\-\d]*)-(\d+)FW(\@(\d+))?(\#(\d+))?/i === command)
	  difficultyText = $1
	  diceCount = $2.to_i
	  crt = $4.to_i unless($3.nil?)
	  fmb = $6.to_i unless($5.nil?)
    elsif( /(\d+)FW(\@(\d+))?(\#(\d+))?(<=([\+\-\d]*))?/i === command )
      diceCount = $1.to_i
	  crt = $3.to_i unless($2.nil?)
	  fmb = $5.to_i unless($4.nil?)
	  difficultyText = $7
	else
	  return nil
    end
	
	#目標値の計算
    difficulty = getValue(difficultyText, nil)
	
	#ダイスロール
	dice, dice_str = roll(diceCount, 6)
	
	#出力用ダイスコマンドを生成
	command = "#{diceCount}FW"
	command += "@#{crt}" unless(crt == 4)
	command += "##{fmb}" unless(fmb == 17)
	command += "<=#{difficulty}" unless(difficulty.nil?)
	
	#出力文の生成
	result = "(#{command}) ＞ #{dice}[#{dice_str}]"
	
	#クリティカル・ファンブルチェック
	if(dice <= crt)
	  result += " ＞ クリティカル！"
	elsif(dice >= fmb)
	  result += " ＞ ファンブル！"
	else
	  #成否判定
	  unless(difficultyText.nil?)
	    success = difficulty-dice
	    if(dice<=difficulty)
	      result += " ＞ 成功(成功度:#{success})"
	    else
	      result += " ＞ 失敗(失敗度:#{success})"
	    end
	  end
	end
	
	return result
  end
  
  def getValue(text, defaultValue)
    return defaultValue if( text == nil or text.empty? ) 
    
    parren_killer("(0" + text + ")").to_i 
  end
  
  def getAdjustNumber(number, table)
    
    min = table.first.first
	return min if(number < min)
    
    max = table.last.first
	return max if(number > max)
    
    return number
  end
  
  #必殺技表
  def getSpecialResult
    table = [
	         '[命中]判定に出目[1,1,1]でクリティカル。更に致傷力に「SLv×20」のボーナスを得る。',
			 '[命中]判定と致傷力に「SLv×10」のボーナスを得る。',
			 '致傷力に「SLv×10」のボーナスを得る。',
			 '攻撃が命中するとバッドステータス「転倒」を与える。',
			 '通常攻撃。',
			 '[命中]判定に[6,6,6]でファンブル。更に、使用者がバッドステータス「転倒」を受ける。',
			]
	return get_table_by_1d6(table)
  end
  
  #マジカルクッキング
  def getCookResult(lv)
  
    def cook(lv, num)
	  case lv
	    when 1
	      table = [
	        'おべんとミートボール',
		    'パリパリ小魚',
		    'キャロットタルト',
		    'おにぎり',
		    lambda{return cook(2, 5)},
		    lambda{return cook(2, 6)},
	      ]
	    when 2
	      table = [
	        'カリカリミミズ肉',
		    '竹つきチクワ',
		    'トロピカルジュース',
		    'イナリ寿司',
		    lambda{return cook(3, 5)},
		    lambda{return cook(3, 6)},
	      ]
	  
	    when 3
	      table = [
	        'ホットミートパイ',
		    '魔界魚の目玉',
		    'パンプキンプリン',
		    'スタミナ丼',
		    lambda{return cook(4, 5)},
		    lambda{return cook(4, 6)},
	      ]
	  
	    when 4
	      table = [
	        'ジャンボ串焼き',
		    'シルヴァまっしぐら',
		    'フラウアイスクリーム',
		    'ピクニックランチ',
		    lambda{return cook(5, 5)},
		    lambda{return cook(5, 6)},
	      ]
	  
	    when 5
	      table = [
	        'グラント風香草焼き',
		    'エドマエスシ',
		    'スターフルーツパフェ',
		    '具沢山本格カレー',
		    lambda{return cook(6, 5)},
		    lambda{return cook(6, 6)},
	      ]
	  
	    when 6
	      table = [
	        'ドラゴンステーキ',
	  	    '刺身盛り合わせ',
		    'エデンのアップルパイ',
		    'フォートレス炒飯',
		    lambda{return cook(7, 5)},
		    lambda{return cook(7, 6)},
	      ]
	  
	    when 7
	      table = [
	        'マツザカスペシャル',
		    'オオトロスシ',
		    'スノーホワイトボンブ',
		    'よもつへぐい',
		    lambda{return cook(8, 5)},
		    lambda{return cook(8, 6)},
	     ]
	  
	    when 8
	      table = [
	        '超特大マンガ肉',
		    '特上うな丼',
		    '魔将樹のかき氷',
		    'ヘブンズランチ',
		    lambda{return cook(9, 5)},
		    lambda{return cook(9, 6)},
	      ]
	  
	    when 9
	      table = [
	        '世界樹のサラダ',
		    '世界樹のサラダ',
		    '世界樹のサラダ',
		    '黄金のラダマン鍋',
		    '黄金のラダマン鍋',
		    '黄金のラダマン鍋',
	      ]
	
	  end
      result, number = get_table_by_1d6(table)
	  if(result.class.name == "Array")
	    number = result[1]
	    result = result[0]
	  end
	  number = "#{num}#{number}"
	  return result, number
    end
	
	return cook(lv, "")
  
  end
   
  #フィルトウィズナンバーワンくじ(GURPS-FW版)
  def getLotResult(type)
  
	#ノーマルくじ表
	def normal(phase, num)
		case phase
			when 1
				table = [
					'イレブンチキン',
					'イレブンチキン',
					'イレブンチキン',
					lambda{return normal(2, 4)},
					lambda{return normal(2, 5)},
					lambda{return normal(3, 6)},
				]
	
			when 2
				table = [
					'バロールたわし',
					'イグニスジッポ',
					'ヤコ仮面or梟の文鎮(選択可)',
					'ナレッジのハンモックorジンジャビースト',
					lambda{return normal(3, 5)},
					lambda{return normal(3, 6)},
				]
			
			when 3
				table = [
					'特性HPポーション',
					'特性MPポーション',
					'黒い甲冑',
					'天体望遠鏡',
					'金獅子の剥製',
					lambda{return normal(4, 6)},
				]

			when 4
				table = [
					'特性スタミナポーション',
					'戦乙女の兜',
					'フェンリルの首輪',
					'フェニックスカーペット',
					'動くアダマンゴーレム',
					lambda{return normal(5, 6)},
				]

			when 5
				table = [
					'キャンディークッション',
					'屑鉄の金床',
					'薪割り王の斧',
					'ロジエの水差し',
					'箱舟の模型',
					lambda{return premium(5, 6)},
				]
			
		end
		
		result, number = get_table_by_1d6(table)
		if(result.class.name == "Array")
			number = result[1]
			result = result[0]
		end
		number = "#{num}#{number}"
		return result, number
	end
	
	#プレミアムくじ表
	def premium(phase, num)
		case phase
			when 1
				table = [
					'プレミアムチキン',
					'プレミアムチキン',
					'プレミアムチキン',
					lambda{return normal(3, 4)},
					lambda{return premium(2, 5)},
					lambda{return premium(2, 6)},
				]

			when 2
				table = [
					'親衛隊バッジ',
					'ハタモトチャブダイ',
					'星のコンパス',
					'白銀の甲冑',
					lambda{return normal(4, 5)},
					lambda{return premium(3, 6)},
				]

			when 3
				table = [
					'特性クイックHPポーション',
					'特性クイックMPポーション',
					'特製クイックスタミナポーション',
					'火龍のフィギュアor氷龍のフィギュア(選択可)',
					'ヒメショーグンドレス',
					lambda{return premium(4, 6)},
				]

			when 4
				table = [
					'クイックユグドラポーション',
					'銀河龍のフィギュア/ドラゴン',
					'銀河龍のフィギュア/魔族',
					'魔族チェスセット',
					'イグニスコンロ',
					lambda{return premium(5, 6)},
				]

			when 5
				table = [
					'グレヴディバリウス',
					'天使の望遠鏡orデスの目覚まし時計(選択可)',
					'世界樹の蔦',
					'死神の飾りドレス',
					'ザバーニヤ等身大フィギュア',
					lambda{return premium(6, 6)},
				]

			when 6
				table = [
					'イレブンチキン',
					'イレブンチキン(2ピース)',
					'イレブンチキン(3ピース)',
					'イレブンチキン(6ピース)',
					'イレブンチキン(12ピース)',
					'wish star',
				]
		
		end
		
		result, number = get_table_by_1d6(table)
		if(result.class.name == "Array")
			number = result[1]
			result = result[0]
		end
		number = "#{num}#{number}"
		return result, number
	end
	
	if(type == "P")
		return premium(1, "")
	else
		return normal(1, "")
	end
	
	return ""
  
  end
  
  #夢幻の迷宮財宝表
  def getTresureResult(command)
    return nil unless(/TRS(\d+)([\+\-]\d)?/ === command)
	rank   = $1.to_i
	modify = $2.to_i
	
	tableName = "財宝表"
	
	rank += modify unless(modify.nil?)
	rank = 0  if( rank < 0  )
	rank = 10 if( rank > 10 )
	
	case rank
	  when 0
	    table = [
		         'HPポーション(消耗品)',
		         'FPポーション(消耗品)',
		         'マジックパウダー:火(消耗品)',
		         'マジックパウダー:氷(消耗品)',
		         'マジックパウダー:雷(消耗品)',
		         '500GP',
		        ]
	  
	  when 1
	    table = [
		         '高級HPポーション(消耗品)',
		         '高級FPポーション(消耗品)',
		         '高級抵抗ポーション(消耗品)',
		         '高級鉄壁ポーション(消耗品)',
		         'マジックパウダー:火、氷、雷の3点セット(消耗品)',
		         '1000GP',
		        ]
	  
	  when 2
	    table = [
		         '鈴のお守り(装飾品)',
		         '盗賊の小手(装飾品)',
		         '狩人の羽帽子(装飾品)',
		         '狙撃手の指貫(装飾品)',
		         '「スタミナバンド」「健康お守り」「レザーマント」3点セット',
		         '2000GP',
		        ]
	  
	  when 3
	    table = [
		         '最高級HPポーション(消耗品)',
		         '最高級FPポーション(消耗品)',
		         '最高級抵抗ポーション(消耗品)',
		         '任意の装飾品1つ(3000GPまでのもの)',
		         'アタッチメント割引券(全員に1枚)',
		         'GP',
		        ]
	  
	  when 4
	    table = [
		         '任意の「ミスリル」武器1つ',
		         'ミスリルシールド(盾)',
		         'ミスリルメイル(鎧)',
		         '任意の装飾品1つ(5000GPまでのもの)',
		         'アタッチメント割引券(全員に2枚)',
		         '5000GP',
		        ]
	  
	  when 5
	    table = [
		         '任意の武器1つ(10000GPまでのもの)',
		         '任意の盾1つ(10000GPまでのもの)',
		         '任意の鎧1つ(10000GPまでのもの)',
		         '最高級HPポーション(人数分)',
		         '任意の装飾品1つ(10000GPまでのもの)',
		         '7500GP',
		        ]
	  
	  when 6
	    table = [
		         '任意の武器1つ(15000GPまでのもの)',
		         '任意の盾1つ(15000GPまでのもの)',
		         '任意の鎧1つ(15000GPまでのもの)',
		         '任意の装飾品1つ(15000GPまでのもの)',
		         '最高級FPポーション(人数分)',
		         '10000GP',
		        ]
	  
	  when 7
	    table = [
		         '任意の武器1つ(30000GPまでのもの)',
		         '任意の盾1つ(30000GPまでのもの)',
		         '任意の鎧1つ(30000GPまでのもの)',
		         '任意の装飾品1つ(30000GPまでのもの)',
		         '蘇生ポーション(消耗品)',
		         '20000GP',
		        ]
	  
	  when 8
	    table = [
		         '任意の武器1つ(60000GPまでのもの)',
		         '任意の盾1つ(60000GPまでのもの)',
		         '任意の鎧1つ(60000GPまでのもの)',
		         '任意の装飾品1つ(60000GPまでのもの)',
		         '蘇生ポーション(装飾品)+アタッチメント割引券10枚(割引券は人数分)',
		         '40000GP',
		        ]
	  
	  when 9
	    table = [
		         '任意の武器1つ(100000GPまでのもの)',
		         '任意の盾1つ(100000GPまでのもの)',
		         '任意の鎧1つ(100000GPまでのもの)',
		         '任意の装飾品1つ(100000GPまでのもの)',
		         '蘇生ポーション(装飾品)+アタッチメント割引券20枚(割引券は人数分)',
		         '60000GP',
		        ]
	  
	  when 10
	    table = [
		         '任意の武器1つ(150000GPまでのもの)',
		         '任意の盾1つ(150000GPまでのもの)',
		         '任意の鎧1つ(150000GPまでのもの)',
		         '任意の装飾品1つ(200000GPまでのもの)',
		         '蘇生ポーション(装飾品)+アタッチメント割引券30枚(割引券は人数分)',
		         '黄金の守護者の証(装飾品)(【ハッキング】があれば黄金の電子暗号キー(装飾品)も追加)',
		        ]
	  
	  else
	    return nil
	end
	
	result, number = get_table_by_1d6(table)
	
	return "#{tableName}(#{number}):#{result}"
  end
  
  #夢幻の迷宮トラップ表
  def getTrapResult(command)
    return nil unless( /TRAP(E|N|H|L)/ === command )
	dif = $1
	tableName = "トラップ表"
	
	case dif
	  when "E"
	    difficultyText = "初級"
		difficulty = 0
	  
	  when "N"
	    difficultyText = "中級"
		difficulty = 1
	  
	  when "H"
	    difficultyText = "上級"
		difficulty = 2
	  
	  when "L"
	    difficultyText = "悪夢"
		difficulty = 3
	  
	  else
	    return nil
	end
	
	table = [
	         "トライディザスター:宝箱から広範囲に火炎・冷気・電撃が放たれる罠。PC全員に「3D+#{[3, 50, 70, 100][difficulty]}」の「火炎」「冷気」「電撃」属性ダメージ。",
	         "ペトロブラスター:広範囲に石化光線を放つ罠。PC全員[抵抗-#{[2, 4, 6, 8][difficulty]}]判定を行い、失敗したPCはBS「石化」を受ける。",
	         "クロスボウストリーム:宝箱から矢の嵐が放たれる罠。PC全員に「3D+#{[20, 40, 60, 90][difficulty]}」の「刺突」属性ダメージ。「ドッジ-#{[4, 6, 8, 10][difficulty]}」で[回避]が可能。",
	         "フォーチュンイーター:PC全員の幸運を食らい、Ftを#{[1, 2, 3, 4][difficulty]}点減少させる。Ftが0の場合「3D+#{[30, 50, 70, 100][difficulty]}」点の防護点無視ダメージ。",
	         "スロット:解除に失敗しても害はないが、スロットが揃うまで開かない宝箱。スロットを1回まわすには#{[100, 300, 600, 1000][difficulty]}GPが必要。行動を消費して[感覚-#{[4, 6, 8, 10][difficulty]}]判定に成功すればスロットは揃う。有利な特異点「ビビット反射」があれば判定に+4のボーナス。",
	         "テレポーター:PC全員(とエンカウントしているエネミー)を転送して道に迷わせる。「財宝ランク」が1段階減少する。",
	         "アイスコフィン:宝箱を開けようとしたキャラクターを氷漬けにする罠。対象1体に「3D+#{[30, 50, 70, 100][difficulty]}」の「冷気」属性ダメージ。更にFPにも#{[5, 10, 15, 20][difficulty]}点の防護点無視ダメージ。",
	         "クロスボウ:宝箱を開けようとしたキャラクターに強力な矢が放たれる罠。対象1体に「3D+#{[20, 40, 60, 90][difficulty]}」の「刺突」属性ダメージ。「ドッジ-#{[4, 6, 8, 10][difficulty]}」",
	         "毒針:宝箱を開けようとしたキャラクターに毒針を突き刺す罠対象1体に#{[15, 30, 45, 60][difficulty]}点の防護点無視ダメージ。更に[抵抗-#{[4, 6, 8, 10][difficulty]}]判定に失敗するとシナリオ終了まであらゆる判定に-2のペナルティ。",
	         "アラーム:即座にその地形のエンカウント表を振って、それに対応したエネミーが出現する。出現したエネミーはそのターンから行動順に組み込まれる。出現するエネミー以外の記述は無視する。",
	         "殺人鬼の斧:宝箱を開けようとしたキャラクターに斧が振り下ろされる罠。対象1体に「3D+#{[30, 50, 70, 100][difficulty]}」の「打撃」「斬撃」属性ダメージ。「ドッジ-#{[4, 6, 8, 10][difficulty]}」か「シールド-#{[4, 6, 8, 10][difficulty]}」で[回避]が可能。",
	         "死神:宝箱を開けようとしたキャラクターに死神を取り憑かせる罠。4ラウンド目が終了するまであらゆる判定に-3のペナルティを受け、4ラウンド目の終了と同時に「3D+#{[30, 50, 70, 100][difficulty]}」の防護点無視ダメージ。",
	         "幻の宝:宝箱に偽の財宝を入れ、本物の財宝を入手させない罠。トラップが発動すると価値の無い偽の宝物「幻の宝」を入手してしまう。「幻の宝」はアイテム欄を3つ占有し、シナリオ終了まで捨てられない。アイテム欄に空きがない場合は、何かを捨てて誰かが必ず持たなくてはならない。",
	         "エクスプロージョン:宝箱が大爆発を起こし、中身を粉々にしてしまう罠。宝箱の中身は消滅する。PC全員に「3D+#{[10, 30, 50, 80][difficulty]}」の「打撃」「火炎」属性ダメージ。",
	         "レインボーポイズン:宝箱から七色の毒ガスが放たれる罠。PC全員に「3D+#{[10, 30, 45, 60][difficulty]}」の防護点無視ダメージ。更にシナリオ終了まであらゆる判定に-2のペナルティ。[抵抗-#{[4, 6, 8, 10][difficulty]}]判定に成功すれば無効。",
	         "デスクラウド:宝箱から致死性の毒ガスを放つ罠。PC全員を即死させる。[抵抗-#{[2, 4, 6, 8][difficulty]}]判定に成功すれば無効。",
	        ]
	
	result, number = get_table_by_nD6(table, 3)
	
	return "#{tableName}<#{difficultyText}>(#{number}):#{result}"
  end
  
  #夢幻の迷宮追加オプション表
  def getRandomOptionResult(command)
	return nil unless(/ROP(E|N|H|L)/ === command)
	dif = $1
	tableName = "迷宮追加オプション表"
	
	case dif
	  when "E"
	    difficultyText = "初級"
		difficulty = 0
	  
	  when "N"
	    difficultyText = "中級"
		difficulty = 1
	  
	  when "H"
	    difficultyText = "上級"
		difficulty = 2
	  
	  when "L"
	    difficultyText = "悪夢"
		difficulty = 3
	  
	  else
	    return nil
	end
	
	table = [
			 [11, "黄金の迷宮(財宝ランク+2):全てが黄金で彩られた迷宮。財宝ランクが大きく上昇する。"],
			 [12, "密林の迷宮(財宝ランク+1):密林の中にひっそりとたたずむ迷宮。分類が「魔獣」「獣人」「霊獣」のエネミーが行うあらゆる判定に+2のボーナス。"],
			 [13, "カラクリの迷宮:複雑なカラクリが周囲で絶え間なく動いている迷宮。分類「ギア」のエネミーが行うあらゆる判定に+2のボーナス。クリア時に「アタッチメント割引券」を全員が#{[1, 2, 3, 5][difficulty]}枚獲得。"],
			 [14, "フラウの舞踏会:あちこちに花畑のある迷宮。フラウが発生するランダムイベントが発生した際、「この迷宮を制覇して、私達が舞踏会を開けるようにしてね」とお願いされ、クリア時の報酬に#{["「キノコの帽子」(装飾品)", "「猛毒の花」(装飾品)", "「フルブロウン」(鎧)", "「緊急召喚の宝珠」(装飾品)"][difficulty]}が追加される。"],
			 [15, "アズマ風の迷宮:風流なアズマ風の迷宮。武器に「刀」を持つエネミーが行うあらゆる判定に+2のボーナス。クリア時に「アタッチメント割引券」を全員が#{[1, 2, 3, 5][difficulty]}枚獲得。"],
			 [16, "枯れた泉の迷宮:「全地形1-1」の回復の泉が全て枯れており、回復効果を得ることができない。「断崖1-6」の貴重な水源や、「水辺1-6」の毒の泉などはそのまま存在する。"],
			 
			 [21, "天空への道(財宝ランク+1):上へ上へと果てしなく登っていく迷宮。空気が薄くなって疲労しやすくなる。【特技】特技などによるFP消費が全て+3。"],
			 [22, "灼熱焦土の迷宮(財宝ランク+1):とてつもなく暑く、あちこちで炎が燃え盛る迷宮。エネミーが行う「火炎」属性を含む攻撃の致傷力に+#{[10, 20, 30, 50][difficulty]}のボーナス。"],
			 [23, "灼熱焦土の迷宮(財宝ランク+1):とてつもなく寒く、気温が氷点下の迷宮。エネミーが行う「冷気」属性を含む攻撃の致傷力に+#{[10, 20, 30, 50][difficulty]}のボーナス。"],
			 [24, "盗賊王の迷宮:迷宮内での罠や鍵を解除する[感覚]判定に-3のペナルティ。4ラウンドまでに出現した宝箱の「財宝ランク」+1。"],
			 [25, "ミミック狂暴化:「全地形2-5」のミミックの致傷力に+#{[20, 30, 50, 80][difficulty]}のボーナス。ミミックを見破った場合に得られるGPが#{[500, 1000, 3000, 5000][difficulty]}GP増加する。"],
			 [26, "トレジャーイーター狂暴化:「全地形2-6」のトレジャーイーターを見破る[感覚]判定に-3のペナルティ。4ラウンドまでに出現した宝箱の「財宝ランク」+1。"],
			 
			 [31, "暗闇の迷宮:どこもかしこも真っ暗な迷宮。「猫の目」がなければ視覚に関する[感覚]判定に-5のペナルティ。"],
			 [32, "騒音の迷宮:常に大音量で謎の音楽(BGM)が鳴っている迷宮。聴覚に関する[感覚]判定に-5のペナルティ。"],
			 [33, "未知の怪物の迷宮(財宝ランク+1):エネミーの姿がシルエットのみになる迷宮。エネミーのデータがいかなる手段でも判明させられなくなる。(通常通り[HP][FP][先制]は判明する)"],
			 [34, "氾濫中の迷宮:大雨が降っており、川などが氾濫している迷宮。水泳を行う際の[敏捷]判定に-5のペナルティ。「森林3-6」の山火事イベントの効果は無視できる。"],
			 [35, "間抜けの迷宮(財宝ランク+1):頭がおかしくなりそうな極彩色の迷宮。[知力][意志]判定に-2のペナルティ。[知力]や[意志]そのものが下がるわけではない。"],
			 [36, "瘴気の迷宮(財宝ランク+1):生命力を奪う紫の霧で満ちた迷宮。"],
			 
			 [41, "加速する迷宮:狂ったように針の動く時計が多数された迷宮。「CT:安息の日」以外の【特技】が「CT:なし」になる。"],
			 [42, "停滞する迷宮(財宝ランク+1):動かない時計が多数設置された迷宮。「CT:安息の日」以外のCTの存在する【特技】が「CT:シナリオ終了」になる。この効果はシナリオ終了まで持続する。"],
			 [43, "猛毒の迷宮(財宝ランク+1):見るからに毒々しい紫色の沼があちこちにある迷宮。エネミーが行う、名称に「毒」もしくは「ポイズン」が入る【特技】や、名称に「毒」もしくは「ポイズン」が入るトラップの致傷力に+#{[10, 20, 40, 50][difficulty]}のボーナス。"],
			 [44, "死の迷宮(財宝ランク+2):死の運命から逃れることのできない、血まみれの迷宮。「生命保険証」の効果が適用されない。"],
			 [45, "幸運の迷宮:何者かの加護を感じる迷宮。PC全員のFtの最大値と現在値に+1のボーナス。この効果はシナリオ終了まで持続する。"],
			 [46, "不運の迷宮:PC全員のFt最大値と現在値に-1のペナルティ。この効果はシナリオ終了まで持続する。"],
			 
			 [51, "レアメタルの迷宮:非常にレアなエネミー「レアメタルキャンディー」「レアメタルクラウン」が生息している迷宮。キャンディークラウン(CL40)、ゴールデンクラウン(CL177)から獲得できる通常ドロップのGPが5倍になる。"],
			 [52, "魔力の泉:PCとエネミーの双方が、[FP]を消費せずに【魔法】を使用できるようになる。最終的な消費[FP]が最大[FP]より大きい【魔法】は使用できない。"],
			 [53, "ブルーの迷宮:陰鬱な気分になり、他のキャラクターと関わる気力を失う。PC全員が不利な特異点「嫌な奴」を1段階得る。"],
			 [54, "レッドの迷宮:なぜか興奮して非常に好戦的になる。PC全員が不利な特異点「脳みそ筋肉」を得る。交戦中に「1:回復系」のイベントが発生しても戦闘を終了させることができない。"],
			 [55, "ピンクの迷宮:なんだか身近な異性(同性も?)が気になって仕方なくなる。PC全員が不利な特異点「英雄色を好む」を得る。魔族も戦闘意欲を失い、「分類:魔族」のエネミーが出現するイベントは無視する。"],
			 [56, "ハズレの迷宮(財宝ランク-1):ツギハギだらけの壁などでできた、ハリボテのような貧相な迷宮。宝箱の中身もなんだか貧相になる。"],
			 
			 [61, "ラダマンティスの迷宮(財宝ランク+2):第一魔将ラダマンティスの像が入口に設置された迷宮。全てのエネミーが行うあらゆる判定に+2のボーナス。また、「遺跡6-6」のイベントのダメージ+#{[20, 40, 60, 80][difficulty]}。"],
			 [62, "グレイヴディガーの迷宮(財宝ランク+2):第二魔将グレイブディガーの像が入口に設置された迷宮。「分類:アンデッド」のエネミーが行うあらゆる判定に+5のボーナス。"],
			 [63, "ハイペリオンの迷宮(財宝ランク+2):第三魔将ハイペリオンの像が入口に設置された迷宮。全てのエネミーが「ターン開始」時に[HP]を全回復する。"],
			 [64, "ムスペルニヴルの迷宮(財宝ランク+2):勇ましくも美しい女性の像が設置された迷宮。エネミーが行う「火炎」もしくは「冷気」属性を含む攻撃の致傷力に+#{[20, 40, 60, 80][difficulty]}のボーナス。"],
			 [65, "ウェルスの迷宮:人懐っこそうなアズマ風の青年が設置された迷宮。シナリオ上で第五魔将の正体が明らかに鳴っている場合のみ、PC全員のFtの最大値と現在値に+5のボーナス。この効果はシナリオ終了まで持続する。"],
			 [66, "バロールの迷宮(財宝ランク+2):第六魔将バロールの像が入口に設置された迷宮。「分類:ギア」のエネミーが行うあらゆる判定に+5のボーナス。"],
			]
	
	result, number = get_table_by_d66(table)
	_,  result = result
	
	return "#{tableName}<#{difficultyText}>(#{number}):#{result}"
  end
  
  #夢幻の迷宮ランダムイベント表
  def getRandomEventResult(command)
    if(/RAND(E|N|H|L)([1-6])?/ === command)
	  dif = $1
	  area  = $2.to_i
	  area, = roll(1, 6) if($2.nil?)
	  type, = roll(1, 6)
	elsif(/RENC(E|N|H|L)([1-6])?/ === command)
	  dif = $1
	  area  = $2.to_i
	  area, = roll(1, 6) if($2.nil?)
	  type  = 4
	else
	  return nil
    end
	
	tableName = "ランダムイベント表"
	
	case dif
	  when "E"
	    difficultyText = "初級"
		difficulty = 0
	  
	  when "N"
	    difficultyText = "中級"
		difficulty = 1
	  
	  when "H"
	    difficultyText = "上級"
		difficulty = 2
	  
	  when "L"
	    difficultyText = "悪夢"
		difficulty = 3
	  
	  else
	    return nil
	end
	
	case area
	  when 1
	    areaText = "洞窟"
		case type
		  when 1
		    table = [
			         "回復の泉。PC全員の[HP][FP]が完全に回復する。「死亡」以外のあらゆるBSも回復する。",
					 "淡い光を放つ鉱石に包まれた部屋に出る。Ftが#{[1, 2, 3, 4][difficulty]}点回復する。",
					 "天井が開いていて植物の育っている洞窟内庭園。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すると、力の枠木の実を見つけてPC全員の[HP][FP]を#{[20, 30, 40, 50][difficulty]}点回復できる。有効：「自然と生きる」【賢人の知恵】",
					 "「きのこっきのこっげんきでろ～♪」洞窟内で栽培できる特殊なキノコを栽培する、キノコのフラウに出会う。100GP支払うことでキノコを1つ譲ってもらうことができ、[HP]が全回復してシナリオ終了まで[HP]の最大値に+#{[10, 15, 20, 25][difficulty]}のボーナスを得る。",
					 "ギア技術を用いた強力な懐中電灯のおいてある休憩室。迷宮を出るまでPC全員に有利な特異点「猫の目」があるものとして扱う。迷宮を出ると懐中電灯は寿命が来たのか壊れてしまう。",
					 "不思議な光を放つ水が湧いている。PCの[HP][FP]のいずれかが減少している場合、このイベントは拒否できない。また全快でも不利な特異点「好奇心は猫を殺す」を持つPCは飲みにいこうとする。飲んだキャラクターは1Dを振り、以下の様な効果が発生する。
----------
1:[HP][FP]と「死亡」以外のBS全回復
2:シナリオ終了まで不利な特異点が全て消滅する
3:シナリオ終了まで精神的に不利な特徴が1つ消滅する
4:[HP]が1点になってしまう。[HP]が0以下の場合は[HP][FP]が全回復
5:シナリオ終了まで余分な獣っぽい耳や尻尾が生える。既に生えているキャラクターはそれが大きくなる。聴覚に関する[感覚]判定+4。
6:あいやー！それ呪いの泉アルよ！シナリオ終了まで性別が男女入替わる。ロールプレイが面白かった場合、シナリオ終了時に「アタッチメント割引券」を与えても良い",
			        ]
		  
		  when 2
		    table = [
			         "財宝ランク#{[0, 2, 4, 6][difficulty]}の宝箱を発見する。カギやトラップはかかっていない。行動を消費することで開けることができる。",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のカギがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でカギを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のトラップがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でトラップを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "頑丈な岩壁に阻まれた隠し財宝の部屋を発見する。岩壁は「打撃」属性で合計#{[100, 200, 300, 500][difficulty]}点のダメージを与えると破壊され、財宝ランク#{[2, 4, 6, 8][difficulty]}のアイテムを入手可能。岩壁はどのHexからでも隣接扱いで攻撃可能。",
					 "ミミックの罠。ランダムなキャラクターに「3D+#{[30, 50, 70, 100][difficulty]}」の「斬撃」属性ダメージを与える。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化でき、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GPを入手可能。有効：【盗賊の心得】【ロックスミス】",
					 "トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化することができ、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GP入手可能。",
			        ]
		  
		  when 3
		    table = [
			         "洞窟内で暗がりの中に近道を発見!有利な特異点「猫の目」を持つキャラクターがいればクリア時の財宝ランク+1。",
					 "洞窟内で近道を発見!だが狭くて通れるかどうか…?有利な特異点「軟体動物」を持つキャラクターがいればクリア時の財宝ランク+1。",
					 "6つの分かれ道だ、どちらに進めばいいのだろうか…?1Dを振って1～3が出ればクリア時の財宝ランク+1。4～6が出ればクリア時の財宝ランク-1。有効:「非凡な直感」",
					 "足場の悪い道だ。うまく降りられればいいが…。[敏捷-#{[3, 6, 9, 12][difficulty]}]判定に成功すればクリア時の財宝ランク+1。失敗すると判定を行ったキャラクターに[3D+20]の防護点無視ダメージ。有効:「軟体動物」",
					 "大きな岩でふさがれた近道。力づくでどかせてやる！[体力-#{[2, 4, 6, 8][difficulty]}]判定に成功すれば売り味の財宝ランク+1。失敗すると判定を行ったキャラクターは[FP]を5点消費する。",
					 "6つの分かれ道だ、どうやら正解の道以外はエネミーの巣だが…。1Dを振って1が出ればクリア時の財宝ランク+1。2～6が出れば即座に洞窟のエンカウントイベントが発生する!有効:「非凡な直感」",
			        ]
		  
		  when 4
		    table = [
			         "水あめ状のボディに王冠をのせた、珍しいエネミーだ!エネミーとエンカウント。",
					 "獣の皮をかぶった魔族が狩った獲物の取り分でもめているようだ。彼らは興奮して争っているが、PCたちを見つけると向きを変えて襲い掛かってくる!エネミーとエンカウント。「マジカルクッキング」で持ち歩くタイプのものを作っていた場合、それを渡すことで戦闘を回避することもできる。",
					 "岩だと思って通りすぎようとしたら魔族だった!?エネミーとエンカウント。相手は洞窟で巧妙に擬態しており、[先制]に+10のボーナスを得る。有利な特異点「虫の知らせ」があれば[先制]ボーナスを無効化できる。",
					 "洞窟でトロッコに乗ったら暴走するギア魔族に追いかけられた!エネミーとエンカウント。トロッコに乗って逃げつつの戦闘になり、2ラウンド以内に倒せなければ轢かれてPC全員が「3D+#{[30, 30, 30, 100][difficulty]}」の防護点無視ダメージを受ける。また、1ラウンドに1人誰かが行動を消費してトロッコを運転する必要があり、これに失敗すると即座に轢かれてしまう。轢かれると戦闘は終了する。PCにケイヴウォーカーがいればトロッコの運転を「支援ターン」で行える。",
					 "炎の燃え盛る洞窟だ!運の悪いことに魔獣までいるようだ…。イベント詳細決定時に敵味方全員が「3D+#{[10, 20, 30, 50][difficulty]}」の「火炎」属性ダメージを受ける。さらにエネミーとエンカウント。",
					 "冷気に包まれた洞窟だ。更に氷の魔族や魔獣まで棲息している!イベント詳細決定時に敵味方全員が「3D+#{[10, 20, 30, 50][difficulty]}」の「冷気」属性ダメージを受ける。さらにエネミーとエンカウント。",
			        ]
		  
		  when 5
		    table = [
			         "突然の落盤がエネミーを押しつぶす!戦闘中の場合、ランダムにエネミー1体を即死させ、ドロップ品も入手可能。それ以外の場合は特に何も起きない。「分類:ネームド」「分類:魔将」のエネミーには「3D+50」の防護点無視ダメージ。",
					 "採掘用のダイナマイトが打ち捨てられている。ケイヴウォーカー用の消耗品#{["「ダイナマイト」", "「特性ダイナマイト」2個と「ダイナマイト」", "「特性ダイナマイト」4個と「ダイナマイト」", "「特性ダイナマイト」"][difficulty]}を持てるだけ持つことができる。",
					 "洞窟内に有毒ガスが発生している!敵味方全員[抵抗-#{[4, 6, 8, 10][difficulty]}]で判定し、失敗したキャラクターは#{[15, 30, 45, 60][difficulty]}点の防護点無視ダメージを受ける。有効:【ガシンショウタン】",
					 "溶岩の流れる部屋だ、早くおさらばしたいところだが…。[敏捷-#{[3, 6, 9, 12][difficulty]}]判定に成功すれば何事も無く渡り切ることができる。失敗するとPC全員に「3D+#{[20, 40, 60, 90][difficulty]}」の「火炎」属性ダメージ。PCにドラコニアンがいれば判定不要。有効:【野伏の歩み】",
					 "突然の落盤がPCのうちランダムに1人を押しつぶす!「3D+#{[40, 60, 80, 120][difficulty]}」の防護点無視ダメージを受ける。「ドッジ-#{[4, 6, 8, 10][difficulty]}」で回避可能。有利な特異点「猫の目」か「虫の知らせ」があれば判定不要。",
					 "突然の地震が起きて洞窟全体が崩落を始める!このイベントが発生すると戦闘は強制終了する。PC全員[敏捷#{["", "-1", "-2", "-4"][difficulty]}]で判定し、失敗したキャラクターは[HP]が0になる。[HP]が0以下だった場合は死亡してしまう。全員が判定に成功した場合、クリア時の財宝ランク+1。",
			        ]
		  
		  when 6
		    table = [
			         "プラネタリウムのように鉱石が輝く部屋。星の配置に関する謎かけになっている。行動を消費して[知力-#{[6, 9, 12, 15][difficulty]}]判定に成功するとこの謎を解くことができる。謎が解けると「うぃっしゅすたー」(大事なもの)#{["か、10000GP", "2個か、20000GP", "3個か、30000GP", "5個か、50000GP"][difficulty]}の好きな方を入手可能。有効:【賢人の知恵】",
					 "地熱で温泉が湧いている!みんなで一休みできそうだ。このイベントが発生すると戦闘は強制終了する。PC全員の[HP][FP][Ft]が全回復する。また、シナリオ終了まで「ターン開始」時に[HP]が#{[5, 10, 15, 20][difficulty]}点ずつ回復する。",
					 "地下渓流を発見する。どうやらここを進んでいくしかないようだ…。このラウンドではPCが「水中」にいるものとする。また、[敏捷-#{[6, 9, 12, 15][difficulty]}]判定に成功すると水中に沈んだ宝箱を発見する。中身は「#{["3Dx100GP", "(3D+10)x100GP", "(3D+30)x100GP", "3Dx1000GP"][difficulty]}」で、カギやトラップはかかっていない。行動を消費することで開けることができる。有効:【野伏の歩み】",
					 "とてつもない量のアダマン合金の原石を発見する!持ち帰り放題だ!「アダマン原石」は1つ#{[300, 500, 1000, 2000][difficulty]}GPで売却可能で、行動を消費することで自分のアイテム欄に好きなだけ入手可能。",
					 "地面から強力な重力で引きつけられる!敵味方全員が[移動]に-5のペナルティを受ける。さらに洞窟のエンカウントイベントが発生。「4-5」と「4-6」の部屋のダメージは適用しない。",
					 "怪しい光を放つ鉱石の部屋。鉱石は不気味な振動を放っており、ラウンド終了時にランダムなPC1人の武器が1つ壊れてシナリオ終了まで使用できなくなる。鉱石は「打撃」属性で合計#{[100, 200, 300, 500][difficulty]}点のダメージを与えると破壊される。鉱石はどのヘクスからでも隣接扱いで攻撃可能。",
			        ]
		  
		  else
		    return nil
		end
	  
	  when 2
	    areaText = "遺跡"
		case type
		  when 1
		    table = [
			         "回復の泉。PC全員の[HP][FP]が完全に回復する。「死亡」以外のあらゆるBSも回復する。",
					 "随分進んだし一休みしよう。ラウンド数が奇数の場合は[FP]が「#{["3D", "3D+5", "3D+10", "3D+15"][difficulty]}」回復する。ラウンド数が偶数の場合は進んだように見せかけて迷っているだけだった。どっと疲れてしまい[FP]は回復せず、クリア時の財宝ランク-1。有利な特異点「精緻な記憶」があれば、偶数ラウンドでも[FP]が回復して財宝ランクも減少しない。",
					 "どうやらここは古代の医務室らしい。なにやら怪しげな機械がたくさんあるが…。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればPC全員の[HP][FP]が完全に回復する。「死亡」以外のあらゆるBSも回復する。有効：【魔導工学のススメ】",
					 "「きみたちの道に光りあれ…お金？いらないよ」道標の光ゴケを栽培している、苔のフラウに出会う。以後「いくつかの道から正解を選ぶ」イベントが発生した場合、光ゴケがそのうちの1つに飛んでいき、必ず正解の道を選ぶことができる。",
					 "ダンジョンの見取り図を書いた部屋に出る。次のランダムイベントでは、好きな地形を選択してからイベント表を振ることができる。次が最終イベントだった場合、クリア時の財宝ランク+1。",
					 "「パワーアップ装置!」と書かれた怪しげな機械が置いてある。#{[3000, 5000, 10000, 20000][difficulty]}GPを支払って使用するとキャラクターを強化(?)可能。使用するかは自由だが、不利な特異点「好奇心は猫を殺す」を持っているキャラクターはGPがあるなら入ってしまう。使用したキャラクターは1Dを振り、以下のような効果が発生する。
----------
1:なんと、ランダムな[主能力]が1点上昇する!
2:ただの日焼けサロンだ!健康的に焼け、シナリオ終了まで「火炎」に対する防護点+10。
3:CLが1上昇する!やったね!【特技】はシナリオが終了してから習得する。
4:装置は突然爆発する!ダメージは受けないが髪型がアフロに。装置は壊れる。
5:巨大化してシナリオ終了まで第代[HP]+50![HP][FP]も全回復。装置は壊れる。
6:故障のせいかランダムな[主能力]が1点下降する…大ショック…",
			        ]
		  
		  when 2
		    table = [
			         "財宝ランク#{[0, 2, 4, 6][difficulty]}の宝箱を発見する。カギやトラップはかかっていない。行動を消費することで開けることができる。",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のカギがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でカギを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のトラップがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でトラップを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "部屋で脱出ゲームのような様々な仕掛けをとかないと開かない宝箱。行動を消費して[知力-#{[6, 9, 12, 15][difficulty]}]判定に成功すれば開けることができ、財宝ランク#{[2, 4, 6, 8][difficulty]}のアイテムを入手可能。判定に失敗すると宝箱を入手可能。判定に失敗すると宝箱は爆発してしまい、中身も失われる。有効:【盗賊の心得】",
					 "ミミックの罠。ランダムなキャラクターに「3D+#{[30, 50, 70, 100][difficulty]}」の「斬撃」属性ダメージを与える。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化でき、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GPを入手可能。有効：【盗賊の心得】【ロックスミス】",
					 "トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化することができ、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GP入手可能。",
			        ]
		  
		  when 3
		    table = [
			         "鏡に映る怪人が自分の真似をしろとジェスチャーしている。[敏捷-#{[6, 8, 10, 12][difficulty]}]判定に成功するとうまく真似してパントマイムすることができ、鏡が消滅して隠し通路が開かれる。クリア時の財宝ランク+1。【華劇:○○】を習得したフラウがいれば判定不要。",
					 "小さな魔将の像がフィルトウィズの地図上で乱雑に置かれている。[知力-#{[6, 9, 12, 15][difficulty]}]判定に成功すれば魔将の所在地を正しく配置することができ、隠し通路が開かれる。クリア時の財宝ランク+1。有効:【賢人の知恵】",
					 "シュートの罠に引っかかるが、結果的に新たな道を発見できた!このイベントが発生すると戦闘は強制終了する。PC全員が「3D+10」の「打撃」属性ダメージを受けるが、クリア時の財宝ランク+1。",
					 "ラダマンティス崇拝者が創りだした巨大な甲羅のようなものが置かれた部屋。登っていけば近道することができそうだが、これはかなり骨が折れそうだ…。行動を消費して[敏捷-#{[6, 9, 12, 15][difficulty]}]判定を行い、成功すればクリア時の財宝ランク+1。判定に挑戦したキャラクターは次のターンまで[回避]判定を行えない。有効:「軟体動物」【野伏の歩み】",
					 "後ろから重い物が転がってくる音がする。ローリングストーンだ!このイベントが発生すると戦闘は強制終了する。ラウンド終了時に全員の[移動]が#{[6, 8, 10, 12][difficulty]}以上であればクリア時の財宝ランク+1。[移動]が#{[6, 8, 10, 12][difficulty]}未満のPCは「3D+#{[30, 50, 70, 100][difficulty]}」の防護点無視ダメージを受ける。",
					 "通路が複雑に入り組んでおり道に迷いそうだ…。2Dを振り、ゾロ目ならクリア時の財宝ランク+1。それ以外の場合はクリア時の財宝ランク-1。有効:「非凡な直感」",
					]
					
		  when 4
		    table = [
			         "絶体絶命、モンスターハウスだ!危機感を煽るBGMも流れてくる。1Dをふって無限の迷宮の地形から1つ選択する。その地形で該当する難易度に名前の書かれたエネミーが全て1体ずつ出現する。特別な強化が施されている場合それも適用する。これらのエネミーを全滅させた際、最後に倒したエネミーからは必ず「レア」を入手できる。エネミー決定後に逃亡を宣言しても良い。その場合クリア時の財宝ランク-2。",
					 "石像が並んでいる通路があるが…なんと石像は警備装置だった!エネミーとエンカウント。奇襲攻撃のため、エネミーからの攻撃の[回避]に-4のペナルティを受ける。【魔導工学のススメ】があれば警戒していたため、このペナルティは受けない。",
					 "魔族が障害物に身を隠しながら狙撃してきた!エネミーとエンカウント。障害物のため、エネミーは近接攻撃に対する防護点に+30のボーナス。",
					 "「汝が戦う理由とは何か?答えい人間!」ブツゼンにモンスターが仁王立ちしており、問答を行ってくる。[意思-6]判定に成功すると戦闘を回避することができ、ドロップ品も入手可能。判定に失敗するか戦闘を望んだ場合、エネミーとエンカウント。有効:【詩人の交渉術】",
                     "進路上に鎖に繋がれたモンスターを発見する。どうやら普通のモンスターより凶暴なようだ、戦うべきか避けるべきか…エネミーとエンカウント。エネミーはあらゆる致傷力に+#{[10, 20, 30, 40][difficulty]}のボーナスを得る。戦闘を避けた場合クリア時の財宝ランク-1。",
					 "暴れゴーレムが襲い掛かってくる!暴走しているせいか凄まじいスピードだ!エネミーとエンカウント。このエネミーは[移動][先制]に+10のボーナスを得ており、全員が行動終了した後、ラウンド終了前にもう1度ターンがまわってくる。",
			        ]
		  
		  when 5
		    table = [
			         "一斉に周囲の壁の射出光が開き、無数の矢が放たれる!PC全員に「3D+#{[20, 40, 60, 90][difficulty]}」の「刺突」属性ダメージ。「ドッジ-#{[4, 6, 8, 10][difficulty]}」で[回避]が可能。有利な特異点「虫の知らせ」があれば[回避]に+4のボーナスを得る。",
					 "突然部屋に白いガスが充満して睡魔が襲ってくる!PC全員がBS「睡眠」を受ける。[抵抗-#{[2, 4, 6, 8][difficulty]}]判定で無効化。",
					 "フロアイミテーターの罠だ!突然部屋の入口が閉まり、君たちを消化し始める!「斬撃」属性で合計#{[100, 200, 300, 500][difficulty]}点のダメージを与えると入り口が開き脱出できるが、それまでPC全員は「ターン開始」時に#{[10, 20, 30, 40][difficulty]}点の防護点無視ダメージを受ける。ラウンドごとの地形変化やイベントは行われず、最終イベントにも進めなくなる。入り口はどのヘクスからでも隣接扱いで攻撃可能。誰も「斬撃」属性の攻撃ができないなら君たちの冒険はここまでだ。",
					 "休憩室のようだ。寝心地のよさそうなふかふかのベッドまである。このイベントが発生すると戦闘は強制終了する。PC全員が[意思-#{[2, 4, 6, 8][difficulty]}]判定を行い、失敗したPCはBS「眠り」を受ける。この「眠り」は誰かが行動を羊皮して叩き起こさない限り、シナリオ終了まで持続する。全員が判定に失敗した場合、君たちの冒険はここまでだ。もう目覚めることはないが、せめていい夢を見れるといいだろう。ホムンクルスは「居眠り禁止」を厳命されているため、「眠り」を受けない。",
					 "「ラダマンティスの蛇」の像と目が合ってしまった。どうやらダンジョンの監視者に見つかってしまったらしい!以後探索中にエネミーと遭遇した場合、CLの最も高いエネミーが1体増加する。このイベントの効果は累積せず、「分類：ネームド」「分類：魔将」のエネミーの数は変化しない。",
					 "怪しげな卵が置かれた部屋。君たちが近寄ると卵が割れて…?1Dを振り、その出目によって中から様々なものが出現する。
----------
1～2:これは財宝だ!財宝ランク#{[2, 4, 6, 8][difficulty]}のアイテムが入手可能。
3～4:卵はそのまま大爆発!PC全員に「3D+#{[30, 50, 70, 100][difficulty]}」の「打撃」「火炎」属性ダメージ。
5～6:卵からドラゴンが!エネミーとエンカウント。",
			        ]
		  
		  when 6
		    table = [
			         "突然ダンジョンの明かりが消えてほぼ真っ暗になってしまう!次のラウンドに入るまであらゆる判定に-6のペナルティを受ける。有利な特異点「猫の目」があればペナルティを受けない。また「洞窟1-5の懐中電灯」や「遺跡1-4の光ゴケ」などがあれば無効。",
					 "どうやら古代の訓練施設のようだ。「パンチングマシーン」と書かれたものがあり、行動を消費すれば100GPを支払って挑戦可能。「格闘」武器でのダメージ判定を1回行い、与えたダメージによってファンファーレとともに景品が出る。1回挑戦すると、ガタが来ていたのか壊れてしまう。
----------
ダメージ#{[20, 40, 60, 80][difficulty]}以上:財宝ランク#{[0, 2, 4, 6][difficulty]}のアイテム
ダメージ#{[30, 50, 70, 90][difficulty]}以上:財宝ランク#{[1, 3, 5, 7][difficulty]}のアイテム
ダメージ#{[40, 60, 80, 100][difficulty]}以上:財宝ランク#{[2, 4, 6, 8][difficulty]}のアイテム",
					 "謎の装置のせいで気になるあの子と体が入れ替わってしまった!?シナリオ終了までPCのうち2人の体や能力が入れ替わってしまう。入れ替わるキャラクターはランダムで決定するか、面白くなるようにGMが選ぶ。戦闘で扱うデータは今までどおりだが、入れ替わったキャラクターのロールプレイを行うこと。",
					 "やった、きんきらきんの宝物庫だ!「2-1」「2-2」「2-3」の宝箱が3つ同時に出現する。ただし、「2-3」の罠の解除に失敗すると、宝箱を開けようとしたキャラクターは黄金像になってしまう。めでたく財宝の仲間入りだ。BS「石化」と同様に扱うが、シナリオ終了までいかなる手段でも治せない。",
					 "キャンディークラウンハウスだ!エネミーとエンカウント。4ラウンド終了までに1体も倒せなかった場合、チャンスを逃した悔しさからPC全員が[FP]に「逃げたキャンディークラウンの数x5」の防護点無視ダメージを受ける。",
					 "なぜここに呼ばれたかお分かりになりますでしょうか?ラダマンティス崇拝者の作りだした審判の部屋に飛ばされてしまった!ラウンド終了時に部屋の中央のラダマンティス像から裁きの光が放たれ、PC全員が「3D+#{[50, 80, 110, 150][difficulty]}」の防護点無視ダメージを受ける。#{[200, 400, 600, 1000][difficulty]}点のダメージを与えれば破壊可能でダメージも受けない。ラダマンティス像はどのヘクスからでも隣接扱いで攻撃可能。破壊に成功すると財宝ランク#{[3, 5, 7, 9][difficulty]}のアイテムが入手可能。",
			        ]
		  
		  else
		    return nil
		end
	  
	  when 3
	    areaText = "山岳"
		case type
		  when 1
		    table = [
			         "回復の泉。PC全員の[HP][FP]が完全に回復する。「死亡」以外のあらゆるBSも回復する。",
					 "休憩に丁度いい広場を見つけた。[FP]が3D#{["", "+5", "+10", "+15"][difficulty]}点回復する!だが、居心地が良すぎて離れづらくなってしまう。PC全員が[意思-#{[2, 3, 4, 6][difficulty]}]判定を行う。PCのうち半分以上が失敗した場合、次のラウンドもこのイベントが発生して、クリア時の財宝ランク-1。",
					 "山小屋を発見し一休み。[HP]と[FP]が3D#{["", "+5", "+10", "+15"][difficulty]}点回復する。PCが4人の時にこのイベントが発生した場合、休憩中の暇つぶしに山小屋の四隅をぐるぐるまわって運動し始める。だが、後から妙なことに気が付きFtが1点減少する…",
					 "「へーっ、こんなとこまでよく来たね!これ、食べる?食べる?」キイチゴを栽培しているフラウに出会う。栄養満点で幸せになる。PC全員の[HP]と[FP]を10点、Ftを1点回復することができる。さらに、【魔法の料理人】を持つPCがいれば、消耗品「いちごジャム」をSLv個入手可能。
----------
名称:いちごジャム
価格:非売品
解説:[HP]と[FP]を10点、Ftを1点回復する。戦闘中には使用できない。",
					 "少し休憩できそうな洞窟を発見する。PC全員の[FP]を10点回復する。中には他のエクスプローラーが残していったと思われる道具もあった。「#{["高級HPポーション", "最高級HPポーション", "特性HPポーション", "うぃっしゅすたー"][difficulty]}」を入手することができる。大雨が降っていたり、火災が起こったりしていた場合、その効果も消滅する。",
					 "回復の泉。PC全員の[HP][FP]が完全に回復する。「死亡」以外のあらゆるBSも回復する。しかし山間の貴重な水源のため亜人によって管理されており、使用するには#{[500, 1000, 2000, 4000][difficulty]}GPが必要。PCのパーティーに管理している亜人と同じ種族がいるか、【詩人の交渉術#{[1, 2, 3, 4][difficulty]}】を持つキャラクターがいれば無料で使用可能。どの種族が管理しているかは1Dを振って決定する。
----------
1:ドラコニアン
2:リザードとワイズマン
3:フラウ
4:シルヴァテイル
5:ストームコーザー
6:グラント",
			        ]
		  
		  when 2
		    table = [
			         "財宝ランク#{[0, 2, 4, 6][difficulty]}の宝箱を発見する。カギやトラップはかかっていない。行動を消費することで開けることができる。",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のカギがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でカギを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のトラップがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でトラップを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "狭い谷底に宝箱があるのが見える。そして手元には岩とロープが。これはもうバンジージャンプで取ってくるしかない!行動を消費して[敏捷-#{[3, 6, 9, 12][difficulty]}][意思-#{[3, 5, 7, 9][difficulty]}]で判定を行い、両方に成功すれば財宝ランク#{[3, 5, 7, 9][difficulty]}のアイテムを入手できる。[敏捷]判定がファンブルだった場合ロープがちぎれてしまい、4ラウンド目が終了するまで戻ってこれない。有効:【野伏の歩み】([敏捷]判定のみ)",
					 "ミミックの罠。ランダムなキャラクターに「3D+#{[30, 50, 70, 100][difficulty]}」の「斬撃」属性ダメージを与える。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化でき、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GPを入手可能。有効：【盗賊の心得】【ロックスミス】",
					 "トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化することができ、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GP入手可能。",
			        ]
		  
		  when 3
		    table = [
			         "山歩きの達人だけが発見できるショートカットコース。有利な特異点「鷹の目」#{["", "", "2段階", "2段階"][difficulty]}か【野伏の歩み#{[1, 2, 3, 4][difficulty]}】を持つキャラクターがいればクリア時の財宝ランク+1。",
					 "鉱物を運んでいたのであろう、運搬用トロッコを発見する。うまく運転できれば素早く進行できそうだが…?[敏捷-#{[3, 6, 9, 12][difficulty]}]判定に成功すればクリア時の財宝ランク+1。判定に失敗すると脱線して放り出されてしまい、PC全員が「3D+10」の防護点無視ダメージを受ける。PCにケイヴウォーカーがいれば判定不要。",
					 "険しい斜面が続く。これは体力勝負になりそうだ…。PC全員が[体力#{["", "-1", "-2", "-4"][difficulty]}]判定を行い、全員が成功すればクリア時の財宝ランク+1。判定に失敗したキャラクターは[FP]に#{[5, 10, 15, 20][difficulty]}点の防護点無視ダメージを受ける。",
					 "空を飛べればショートカットできそうな崖を発見する。なんらかの飛行手段のあるPCがいる場合、クリア時の財宝ランク+1。元々飛行できなくてもラウンド中に【フライト】などの【特技】を使用してラウンド終了時に「飛行状態」であれば良い。",
					 "遠くから山彦のような不思議な声が聞こえる。山彦と会話をすると迷いやすい道を教えてくれるが、大声で会話をしているのでエネミーに見つかりやすくなる。会話をするなら次のイベントは必ず山岳のエンカウントイベントになり、会話を諦めるならクリア時の財宝ランク-1。有利な特異点「天体時計」があれば会話を諦めてもデメリットはない。",
					 "急に突風が吹いてきて、体力のないものは吹き飛ばされてしまう!もっとも「体力」の低いPC1人が[体力-#{[2, 3, 4, 6][difficulty]}]判定を行い、失敗すると「3D+#{[20, 40, 60, 90][difficulty]}」の防護点無視ダメージを受ける。さらに、救助に時間がかかるためクリア時の財宝ランク-1。PCにストームコーザーがいればイベントの効果を無視できる(演出は自由)。",
			        ]
		  
		  when 4
		    table = [
			         "高いところから多数の岩がごろごろと…いや、これは魔物だ!エネミーとエンカウント。高低差で勢いがついているため、エネミーは[移動]に+5、物理攻撃の致傷力に+#{[10, 30, 60, 120][difficulty]}のボーナスを得る",
					 "空中から羽をもった魔物があちこちから攻撃を仕掛けてきた!エネミーとエンカウント。エネミーのうち#{[3, 3, 1, 1][difficulty]}体は任意の「PC配置ヘクス」に設置される。",
					 "「た、隊長、もうダメです!」「バカもん!この程度で根を上げるな!」登山訓練中の魔族の正体と出くわす。だが相手は疲れているようだ?エネミーとエンカウント。[FP]は最大値から10点減少している。",
					 "山道の横から突然穴が空き、魔物と鉢合わせしてしまう!エネミーとエンカウント。PC全員が[感覚-3]判定を行い、失敗したキャラクターはそのラウンド中に行動することができない。([回避]や[抵抗]の判定、自分のターン以外で行う【特技】は可能)有効:「狐の耳」",
					 "ケタケタ笑いながら空から襲撃される。エネミーとエンカウント。彼女達はとても飽きっぽいので2ラウンド行動した後、3ラウンド目の開始前に立ち去ってしまう。(ドロップは入手できない)",
					 "フェニックスがつがいで暮らす縄張りに足を踏み入れてしまった!エネミーとエンカウント。すぐに引き返せば戦闘を回避できるが、クリア時の財宝ランク-1。そのまま進むのであれば[意思-6]で判定を行い、成功すれば見逃してもらうことができる。失敗するとフェニックスは怒り狂い、襲ってくる。有効:【詩人の交渉術】",
			        ]
		  
		  when 5
		    table = [
			         "ジャーンジャーン!げぇ、落石だ!!上から魔族が岩を落とし始める。PC全員に「3D+#{[20, 40, 60, 90][difficulty]}」点の「打撃」属性ダメージ。「ドッジ-#{[3, 5, 7, 9][difficulty]}」で[回避]が可能。",
					 "ファイトー!いっぱーつ!!足場が崩れ出す。PC全員が[敏捷-#{[3, 6, 9, 12][difficulty]}]判定を行い、失敗すると「3D+#{[20, 40, 60, 90][difficulty]}」点の防護点無視ダメージを受ける。成功したPCは[体力]判定を行い、失敗したPC1人を支えることができる。この判定に失敗した場合、支えようとしたキャラクターも一緒にダメージを受ける。有効:【野伏の歩み】",
					 "滑りやすい岩を飛び移っていく道が続いている。敵味方全員が[敏捷-2]で判定を行い、失敗したキャラクターはBS「転倒」を受ける。飛行可能なキャラクターはこの影響を受けない。有効:【野伏の歩み】",
					 "先に進む道に『銀糸の甲殻』アルゲントゥムの巣がびっしり張られている。幸い主はいないようだが、巣が邪魔で移動がしにくい…敵味方全員が4ラウンド目まで飛行状態になれなくなり、[移動]にも-5のペナルティを受ける。不利な特異点「トラウマ:虫」などがあればそれも適用する。",
					 "美しい万年雪の中を進んでいたと思ったのも束の間、雪崩に遭遇してしまう!全員が「3D+#{[30, 50, 70, 100][difficulty]}」点の「打撃」「冷気」属性ダメージを受け、クリア時の財宝ランク-2。[感覚-#{[6, 9, 12, 15][difficulty]}]の判定に成功すれば、すぐに洞窟に避難してやり過ごすことができる。洞窟の中には#{["スノーの結晶(装飾品/3000GP)", "紺碧の瞳(装飾品/10000GP)", "氷狼の爪(装飾品/25000GP)", "氷河龍の盾(盾/65000GP)"][difficulty]}があり、入手可能。有効:「狐の耳」【野伏の歩み】",
					 "下から魔族の大群が登ってくる!ジャーンジャーン!石を落として撃退だ!魔族の群れは射撃攻撃で合計#{[100, 200, 300, 500][difficulty]}点のダメージを与えれば撃退可能。複数の対象を攻撃できる【特技】を使用した場合は、ダメージを2回計算可能。ラウンド終了時までに撃退できなかった場合、PC全員が撃破に足りなかったダメージに等しい防護点無視ダメージを受ける。魔族の群れはどのヘクスからでも攻撃可能だが、射程が10ヘクス以上の攻撃でなければならない。石を落としても攻撃可能で、「3D+#{[10, 20, 30, 50][difficulty]}」点の「打撃」属性ダメージを与える。この攻撃は判定なしで自動的に命中する。",
			        ]
		  
		  when 6
		    table = [
			         "急に大雨が降り出した、屋内に避難したいところだが…地形が「洞窟」か「遺跡」に変更されるまで、ラウンド終了時、[FP]に「#{["1D", "2D", "3D", "3D+5"][difficulty]}」点の防護点無視ダメージを受ける。[FP]に受けるダメージはPCがそれぞれダイスを振って決定する。「水中行動」が可能なPCはこの効果を受けない。",
					 "色とりどりの石が岩肌に…これはカラーストーンの原石だ![知力-#{[6, 9, 12, 15][difficulty]}]判定に成功すればカラーストーン原石を持ち帰ることができる。「カラーストーン原石」は1つ#{[500, 1000, 2000, 3000][difficulty]}GPで売却可能で、行動を消費することで自分のアイテム欄に好きなだけ入手可能。有効:【魔導工学のススメ】",
					 "不思議な岩がある。1Dを振って1～2であれば「火炎」属性、3～4であれば「冷気」属性、5～6であれば「電撃」属性の攻撃で、4ラウンド目終了までに#{[30, 60, 100, 200][difficulty]}点のダメージを与えれば破壊可能。不思議な岩はどのヘクスからでも隣接扱いで攻撃可能で、破壊したあとには財宝ランク#{[2, 4, 6, 8][difficulty]}のアイテムが発見できる。",
					 "「こんなところで人間に会うなんて珍しいな、お前らも食っていくか?」ストームコーザーが獲物を取った後調理している。このイベントが発生するとエネミーは消滅する。マジカルクッキングLv4「ジャンボ串焼き」を食べさせてもらえる。【魔法の料理人】を習得したPCがいれば、Lv5「グラント風香草焼き」にパワーアップする。この料理の効果は、自分たちが「マジカルクッキング」で作った料理と累積する。",
					 "高山植物の群生地を発見する。薬草の材料になるものもありそうだ?[知力-#{[6, 9, 12, 15][difficulty]}]判定に成功すれば、薬草を持ち帰ることができる。「高山の薬草」は1つ#{[500, 1000, 2000, 3000][difficulty]}GPで売却可能で、行動を消費することで自分のアイテム欄に好きなだけ入手可能。【ポーションナレッジ】があれば判定は不要。有効:【賢人の知恵】「自然と生きる」",
					 "岩壁が大きく崩れていく!崩落に巻き込まれて入口付近まで戻されてしまい、クリア時の財宝ランク-2。だが、崩落した後に鈍く輝くアイテムが転がっている…?[感覚-#{[6, 9, 12, 15][difficulty]}]判定に成功すれば#{["アダマンソード(剣/8000GP)", "アダマンスケイル(鎧/15000GP)", "アダマンプレート(鎧/30000GP)", "ヒュージーブレード(剣/45000GP)"][difficulty]}を入手可能。有効:「鷹の目」",
			        ]
		  
		  else
		    return nil
		end
	  
	  when 4
	    areaText = "水辺"
		case type
		  when 1
		    table = [
			         "回復の泉。PC全員の[HP][FP]が完全に回復する。「死亡」以外のあらゆるBSも回復する。",
					 "甲羅干しに適した暖かい小島を見つける。少しだけ休憩しよう。[HP]と[FP]が「3D#{["", "+5", "+10", "+15"][difficulty]}」点回復する。ワイズマンのPCは全回復する。何か面白い寝言を言ったPCに「#{["HPポーション", "高級HPポーション", "最高級HPポーション", "うぃっしゅすたー"][difficulty]}」が空から降ってくる。",
					 "魚の群れを発見!捕まえてたらふくいただくとしよう!【魔法の料理人】があればマジカルクッキングの「魔界魚の目玉」(Lv3)#{["", "、【魔法の料理人2】があれば「シルヴァまっしぐら」(Lv4)と「エドマエスシ」(Lv5)", "、【魔法の料理人2】があれば「シルヴァまっしぐら」(Lv4)と「エドマエスシ」(Lv5)", "、【魔法の料理人2】があれば「シルヴァまっしぐら」(Lv4)と「エドマエスシ」(Lv5)"][difficulty]}#{["", "", "、【魔法の料理人3】があれば「刺身盛り合わせ」(Lv6)と「オオトロスシ」(Lv7)", "、【魔法の料理人3】があれば「刺身盛り合わせ」(Lv6)と「オオトロスシ」(Lv7)"][difficulty]}#{["", "", "", "、【魔法の料理人4】があれば「特上うな丼」(Lv8)"][difficulty]}の全ての効果を得られる。この効果はすでにマジカルクッキングを使用していても累積する。",
					 "「こんにちは、スーっとして気持ちいいよ。…ふふ、一緒に入ろうか?」ミントや菖蒲を育てているフラウに出会い、薬湯に浸かって[FP]が全回復する。さらに、「火炎」属性に対する防護点に+10のボーナス。",
					 "リザードの集落につく。[HP]の減ったキャラクターがいれば持て囃され、マジカルクッキング「カリカリミミズ肉」(Lv2)をごちそうしてもらい、この先の道案内も買って出てくれる。クリア時の財宝ランク+1。全員の[HP]が満タンの場合は、そっけない扱いをされ何も起こらない。この効果はすでにマジカルクッキングを使用していても累積する。",
					 "回復の泉に見せかけた毒の泉。パーティーメンバーの[HP][FP]のいずれかが減少している場合このイベントは拒否できない。毒の水で「3D+#{[10, 20, 30, 50][difficulty]}」点の防護点無視ダメージを受ける。[HP][FP]が全快のキャラクターと「虫の知らせ」があるPCはこの効果を受けない。[知力-6]判定に成功すればこれが毒の泉だとわかる。有効:【野伏の歩み】【賢人の知恵】",
			        ]
		  
		  when 2
		    table = [
			         "財宝ランク#{[0, 2, 4, 6][difficulty]}の宝箱を発見する。カギやトラップはかかっていない。行動を消費することで開けることができる。",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のカギがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でカギを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のトラップがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でトラップを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "水中の奥深くに宝箱があるのが見える。とってくるのは無理そうに見えるが…行動を消費して[敏捷-#{[9, 12, 15, 18][difficulty]}]判定を行い、成功すれば財宝ランク#{[3, 5, 7, 9][difficulty]}のアイテムを入手できる。有利な特異点「水中行動」があれば判定不要。有効:【野伏の歩み】",
					 "ミミックの罠。ランダムなキャラクターに「3D+#{[30, 50, 70, 100][difficulty]}」の「斬撃」属性ダメージを与える。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化でき、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GPを入手可能。有効：【盗賊の心得】【ロックスミス】",
					 "トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化することができ、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GP入手可能。",
			        ]
		  
		  when 3
		    table = [
			         "進みやすい浅瀬が続き、すいすいと進める。クリア時の財宝ランク+1。有利な特異点「水中行動」や【ミズグモ】をもつPCがいればクリア時の財宝ランク+2。ただしグラントがいると浅瀬にもかかわらず溺れてしまい、財宝ランクは変化しない。(RP次第でグラントがいるデメリットをなくしても良い)",
					 "様々な漂流物が流れこむ船の墓場だ。お宝もありそうだが探索は大変そうだ…[FP]を3点消費する代わりに水辺の財宝系イベント「2-1～2-6」が発生する。この効果を望まない場合は特に何も起きない。",
					 "ヒャッハー、ウォータースライダーだ!巨大な植物の幹を滑って進むことができるが、かなり怖いので勇気が必要。PC全員が[意思#{["", "-1", "-2", "-4"][difficulty]}]判定を行い、全員成功すればクリア時の財宝ランク+1。この判定に成功したPCは、失敗したPCを1人まで抱えて滑り落ちることで成功扱いにできる。",
					 "大蓮のような植物の群生地を渡っていく。重たい装備を身に着けていると沈んでしまいそうだ…[必要体力]が15以上の装備を所有しているPCがいるとクリア時の財宝ランク-1。そのPCに有利な特異点「水中行動」や【ミズグモ】があればこのデメリットは受けない。",
					 "水流が複雑になっており、思うように進めず戻されてしまう。[体力-#{[4, 5, 6, 8][difficulty]}]判定に失敗するとクリア時の財宝ランク-1。",
					 "突然の激流にイカダが巻き込まれる!身を任せている場合じゃない!敵味方全員が[敏捷-#{[2, 3, 4, 6][difficulty]}]判定を行い、失敗したキャラクターは4ラウンド終了まで帰ってこれなくなる。全員が失敗してしまった場合、冒険は強制的に失敗となりダンジョンの入口に戻されてしまう。ダンジョン内で手に入れたアイテムも消耗品とGP以外はセバて水に流されて消滅する。有効:【野伏の歩み】",
			        ]
		  
		  when 4
		    table = [
			         "蟹の魔物がイカダをちょんぎろうとしている!早く倒さなくては!エネミーとエンカウント。1ラウンド以内に倒せなかった場合、イカダをちょんぎられてクリア時の財宝ランク-1。",
					 "アシガル潜水隊と遭遇。エネミーとエンカウント。エネミーは奇襲攻撃を仕掛けてくるため[先制]に+5のボーナスを得る。[感覚-#{[6, 8, 10, 12][difficulty]}]判定に成功すると水面に動く竹筒を発見可能で、その場合は[先制]へのボーナスは無効化可能。有効:「鷹の目」",
					 "何か水面が揺れている…まさか、あれはニンジャ!?エネミーとエンカウント。エネミーは謎の光学迷彩ギアで姿を隠しており、[回避]に+#{[2, 2, 4, 6][difficulty]}のボーナス。",
					 "水辺で花を育てている少女に出会う…が、少女は魔族だった!エネミーとエンカウント。彼女が育てている花の根元には無数の動物の死体が無残にも肥料にされている。戦闘開始時に[意思]判定を行い、失敗したキャラクターは戦慄して1ターン行動不可。[回避][抵抗]の判定を行うことはできる。",
					 "高波にのった魔族の騎士が現れる!エネミーとエンカウント。エネミーは波で勢いがついているため、最初のターンは[移動][先制]に+5のボーナス。",
					 "湖の上を渡っていると思ったら巨大なスライムの上だった!?エネミーとエンカウント。エネミーは巨大なため[HP]に+#{[50, 100, 150, 250][difficulty]}のボーナスを得ている。また、全てのヘクスに対して隣接しているものとする。(移動妨害も全てのヘクスで受ける)",
			        ]
		  
		  when 5
		    table = [
			         "美しい歌声が響き渡る、意識が引きずり込まれそうだ。その場にいる敵味方全員は[抵抗-#{[2, 4, 6, 8][difficulty]}]判定を行い、失敗すると1ターンBS「☆眠り」を受ける。有効:【音響補正装置】",
					 "小舟で進んでいると、なにやら激しい水の音がする。この先は滝のようだ!PC全員が[移動-#{[3, 4, 5, 7][difficulty]}]判定を行い(「水中行動」があれば+5のボーナスを得る)、成功したキャラクターがいれば事なきを得る。更に滝の裏の洞窟から財宝ランク#{[3, 5, 7, 9][difficulty]}のアイテムを入手可能。[移動]判定に全員失敗した場合、全員が滝から転落して「3D+#{[20, 30, 40, 60][difficulty]}」の防護点無視ダメージを受ける。有効:【野伏の歩み】",
					 "船の墓場を進んでいると、強風でマストが倒れてくる!PC全員が「ドッジ-#{[2, 4, 6, 8][difficulty]}」判定を行い、失敗すると「3D+#{[10, 20, 30, 50][difficulty]}」の防護点無視ダメージを受け、BS「☆転倒」を受ける。",
					 "ぺっぺっ、水がしょっぱい!濃い塩水がギアをダメにしてしまう。所有している武器と盾についたアタッチメントがシナリオ終了まで消滅してしまう。【魔導工学のススメ#{[1, 1, 2, 3][difficulty]}】があれば応急処置を行い、この効果を受けない。",
					 "とても寒く冷たい水辺で、体力をどんどん奪われてしまう。「冷気」属性に対する防護点が#{[10, 15, 20, 25][difficulty]}以下のキャラクターは、ラウンド終了時に[FP]を#{[5, 10, 15, 20][difficulty]}点消費する。",
					 "突然間欠泉が吹き出してダメージを受ける!敵味方全員のうちランダムで1体に3D+#{[40, 60, 80, 120][difficulty]}点の「火炎」属性ダメージとBS「☆転倒」を与える。このイベントが2ラウンド目で発生した場合、4ラウンド目のイベントはダイスを振らず「洞窟6-2」の温泉イベントになる。",
			        ]
		  
		  when 6
		    table = [
			         "傷ついた#{["スワンプランナー", "スカイサーチャー", "グリマルキン", "ゴールデンコーン"][difficulty]}を発見する。ラウンド終了までに[HP]を#{[30, 50, 70, 100][difficulty]}点まで回復させればなついて#{["スワンプランナー(ペット/4000GP)", "スカイサーチャー(ペット/6000GP)", "グリマルキン(ペット/15000GP)", "ゴールデンコーン(ペット/30000GP)"][difficulty]}を入手可能。回復できなかった場合、#{["スワンプランナー", "スカイサーチャー", "グリマルキン", "ゴールデンコーン"][difficulty]}は逃走する。",
					 "なにやら派手な魚を見つける。あれはもしやアズマに伝わる幻の魚「ニシキゴイ」か!?行動を消費して[敏捷-#{[8, 10, 12, 15][difficulty]}]判定に成功すれば見事に捕まえ、アイテム欄に入手することができる。売却すると#{[3000, 6000, 12000, 24000][difficulty]}GPになる。この判定は4ラウンド目が終了するまで何度でも行うことができる。有効:【野伏の歩み】",
					 "カエルの合唱が響き渡る。何やら意味がある歌声に聞こえるが…[知力-#{[6, 9, 12, 15][difficulty]}]判定に成功すると歌の意味を理解できる。カエル達は安全な道を教えてくれていたのだ!判定に成功した場合クリア時の財宝ランク+1。判定に失敗すると毒の沼に足を踏み入れ、PC全員が「3D+#{[10, 20, 30, 50][difficulty]}」点の防護点無視ダメージを受ける。有効:「自然と生きる」【賢人の知恵】",
					 "老齢のグラントが岩に腰かけ釣りをしている。このイベントが発生するとエネミーは消滅する。「どうだね、よかったら釣り勝負をやっていかないか?」PC全員が行動を消費して3Dを振り、誰かが3か4を出せば見事勝利することができる。「見事じゃ、そこにあるガラクタはワシには必要ないものじゃから好きに持って行くがいい」と財宝を渡してくれる。財宝ランク#{[3, 5, 7, 9][difficulty]}のアイテムを2つ入手可能。",
					 "沈没した「死者の方舟」だ。探せば何かありそうだが危険そうだ…1Dを振って以下の結果を適用すること。このイベントは無視することができ、その場合は何も起きない。
----------
1～2:…これは財宝だ!財宝ランク#{[3, 5, 7, 9][difficulty]}のアイテムと#{["スケルトンメイル(鎧)", "死者の心臓(装飾品)", "死霊貴族の服(鎧)", "デュラハンの盾(盾)"][difficulty]}を入手。
3～4:…マストが倒れてきた!「水辺5-3」と同様のイベントが発生する。
5～6:…船に残っていたアンデッドが襲ってきた!エネミーとエンカウント。",
					 "貝の群生地だ。貝の中にはキラリと光るものが…あれは真珠だ!行動を消費して[敏捷-#{[6, 9, 12, 15][difficulty]}]判定を行い、成功すれば1回ごとにアイテム「真珠」を入手可能。これは1つ#{[1000, 2000, 4000, 8000][difficulty]}GPで売却可能で、4ラウンド目が終了するまで何回でも入手可能。ただし、判定の成否に関わらず[FP]を2点消費する。「水中行動」があれば判定不要で[FP]も消費しない。有効:【野伏の歩み】",
			        ]
		  
		  else
		    return nil
		end
	  
	  when 5
	    areaText = "森林"
		case type
		  when 1
		    table = [
			         "回復の泉。PC全員の[HP][FP]が完全に回復する。「死亡」以外のあらゆるBSも回復する。",
					 "鬱蒼とした森の奥に見事な佇まいの茶室を見つける。ラウンド中に【ソチャデスカ】を使用した際の回復量が2倍になる。茶室の中には友好的なカラクリフラウがいて、#{[100, 200, 300, 500][difficulty]}GPを支払ったPC全員の[HP][FP]を「3D+#{[10, 20, 30, 50][difficulty]}」点回復してくれる。",
					 "おいしそうな果実の木だ!とてもおいしく、食べるとやたらとテンションが高くなる。[HP][FP]が「3D#{["", "+5", "+10", "+15"][difficulty]}」点回復するが、シナリオ終了まで不利な特異点「脳みそ筋肉」を得たかのように猪突猛進型の性格になってしまう。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すれば興奮作用のある種をどけてデメリットは受けない。有効:「自然と生きる」【賢人の知恵】",
					 "「ひんやりおいしい森のアイスやさんですよ～。今なら私との握手券付き～♪」フラウが果物いっぱいのトロピカルなアイスクリームを売っている。マジカルクッキング「フラウアイスクリーム」(Lv4)を食べさせてもらえる。この料理の効果は、自分たちが「マジカルクッキング」で作った料理と累積する。",
					 "森のなかにひっそりとたたずむジンジャを発見して、ナインテイルのカンヌシかミコが旅の無事を祈ってくれる。PT全員に【不死なる炎】がかかり、最終イベントに入るまで、死亡判定に自動成功するようになる。",
					 "食人植物の花粉による回復の泉の幻影。PTメンバーの[HP][FP]のいずれかが減少している場合このイベントは拒否できない。[知力-6]判定に失敗すると食人植物の群生地にふらふらと入り、PC全員が「3D+#{[20, 30, 40, 60][difficulty]}」の「斬撃」属性ダメージを受ける。有利な特異点「自然と生きる」があれば、事前に気が付きダメージは受けない。有効:【賢人の知恵】",
			        ]
		  
		  when 2
		    table = [
			         "財宝ランク#{[0, 2, 4, 6][difficulty]}の宝箱を発見する。カギやトラップはかかっていない。行動を消費することで開けることができる。",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のカギがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でカギを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のトラップがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でトラップを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "上から3本の蔓が垂れ下がっている。すごく引っ張りたくなる形状だ…行動を消費して引っ張ったキャラクターは1Dを振って以下のものを入手する。蔦を1つ引っ張ると他の蔦はスルスルっと上に消えていってしまう。有効:「非凡な直感」
----------
1～2:大当たり!財宝ランク#{[3, 5, 7, 9][difficulty]}の財宝
3～4:小当たり!おいしい果物(#{["HPポーション", "高級HPポーション", "最高級HPポーション", "奇跡のポーション"][difficulty]}と同等)
5～6:「ハズレ」と書かれた硬い木の実が直撃!「3D+#{[10, 20, 30, 50][difficulty]}」点の「打撃属性ダメージを受ける」",
					 "ミミックの罠。ランダムなキャラクターに「3D+#{[30, 50, 70, 100][difficulty]}」の「斬撃」属性ダメージを与える。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化でき、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GPを入手可能。有効：【盗賊の心得】【ロックスミス】",
					 "トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化することができ、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GP入手可能。",
			        ]
		  
		  when 3
		    table = [
			         "この獣道を通れば近道になりそうだ!しかし狭くて動きにくい…クリア時の財宝ランクが+1されるが、ラウンド中の[移動]に-3のペナルティ。",
					 "「ホウホウホーウ。そっちの道は危ないぞ…」鳥たちが古い言葉で道案内をしてくれる。[知力-6]判定に成功すれば、クリア時の財宝ランク+1。失敗すると次のイベントは必ず「森林」のエンカウントイベントになる。このイベントが4ラウンド目だった場合、道に迷ってクリア時の財宝ランク-1。有効:「自然と生きる」【賢人の知恵】",
					 "時計をもった兎が忙しそうに走っている。追いかけていくと木の幹に落っこちて妙な場所についてしまった!4ラウンド目が終了するまで「迷宮オプション」を新たに1つ追加する。このイベントが4ラウンド目だった場合、近道になりクリア時の財宝ランク+1。",
					 "毒草の群生地だ!突っ切れば近道になりそうだが…気にせず直進すればシナリオ終了まで[HP]の最大値と現在値が#{[10, 15, 20, 25][difficulty]}点減少するが、クリア時の財宝ランク+1。迂回すると悪い効果は受けないがクリア時の財宝ランク-1。",
					 "「花の香りのする方においで」と看板がある。[感覚-#{[6, 9, 12, 15][difficulty]}]判定に失敗すると遠回りになりクリア時の財宝ランク-1。有利な特徴「犬の鼻」が#{["あれば判定不要。", "あれば判定不要。", "二段階あれば判定不要。一段階はボーナスのみ。", "二段階あれば判定不要。一段階はボーナスのみ。"][difficulty]}",
					 "おや、進行方向から動物たちが逃げてくるぞ?…大変だ、森林火災だ!引き返して火災から逃げるとクリア時の財宝ランク-2。構わず突っ切るなら4ラウンド目が終了するまで、ターン開始時に「3D+#{[10, 15, 20, 30][difficulty]}」点の「火炎」属性ダメージを受ける。",
			        ]
		  
		  when 4
		    table = [
			         "森の盗賊団がこちらの懐を狙ってきた!エネミーとエンカウント。このエネミーからダメージをうけるたびに所持品のうち価格の安いものを奪われてしまう。4ラウンド目までに倒せばうばいかえすことができる。",
					 "動物刈りを楽しんでいた魔族と偶然遭遇してしまう。エネミーとエンカウント。「分類:魔物」「分類:魔獣」のエネミーが登場していた場合、魔族たちにに狩られると思い逃亡する。",
					 "魔族の偵察隊と遭遇する。報告される前に倒さなくては!指定のエネミーを1ラウンド以内に倒せなかった場合、次のエンカウントが発生した際、新たに登場するエネミーは準備万端で待ち構えているため[先制]に+10、あらゆる致傷力に+#{[10, 20, 30, 40][difficulty]}のボーナス。",
					 "森を支配する木の魔族の王に遭遇してしまった!エネミーとエンカウント。#{["エネミーは[HP]に+100のボーナス。", "エネミーは[HP]に+150のボーナス。", "エネミーは[HP]に+200のボーナス。", ""][difficulty]}4ラウンド終了までに討伐に成功すると財宝ランク#{[3, 5, 7, 9][difficulty]}のアイテムを入手できる。",
					 "フラウとその尖兵が道案内をしてくれる…と思ったらカラーコンタクトをつけてフラウのふりをした魔族とその尖兵だった!エネミーとエンカウント。尖兵は「PC配置ヘクス」に配置すること。PCはラウンド終了まで[回避]に-6のペナルティ。有利な特異点「背中の目」があれば[回避]へのペナルティは受けない。",
					 "迷彩服をキて軍事訓練中の第３師団精鋭コンバット部隊だ!エネミーとエンカウント。エネミーは[先制]に+4のボーナス。",
			        ]
		  
		  when 5
		    table = [
			         "良い香りが周囲に満ちていく。戦闘中だった場合、闘争心を失わせるキノコの香りで敵味方ともに剣を収め強制的に戦闘終了となる。戦闘中ではなかった場合は[知力-6]判定に失敗すると香りをまともにかいで闘争心を失ってしまい、シナリオ終了まであらゆる致傷力に-5のペナルティ。有効:「犬の鼻」「自然と生きる」【賢人の知恵】",
					 "突然上から木の蔓が誰かを吊り上げて首を絞めようとする!ランダムなPC1人は[感覚-#{[3, 4, 5, 7][difficulty]}]判定を行い、失敗すると「3D+#{[30, 50, 70, 100][difficulty]}」点の防護点無視ダメージを受け、そのラウンド中は行動も[回避]も行えない。有利な特異点「自然と生きる」をもつPCが対象になった場合は何も起きない。有効:【野伏の歩み】",
					 "巧妙なベアトラップが仕掛けてある。ランダムなキャラクター1人(エネミーも含む)に「3D+#{[10, 20, 30, 50][difficulty]}」点の「斬撃」属性ダメージを与え、[移動][回避]を0にする。このトラップにかかったキャラクターか隣接したキャラクターが行動を消費して[感覚-#{[6, 8, 10, 12][difficulty]}]判定に成功すれば解除可能。有効:【盗賊の心得】【ロックスミス】",
					 "突然前も見えないほどのスコールに見舞われる!敵味方全員の攻撃や【特技】の射程が全て1になってしまう。森林「3-6」の山火事が起きていた場合、鎮火する。",
					 "ランダムなPC1人が巨大な食虫植物に喰われてしまう!幸いすぐに助け出すことができたのだが、鎧も服もボロボロにされてしまう(ｲﾔｰﾝ)喰われたPCが装備していた鎧はシナリオ終了まで使用不可能になる。",
					 "すさまじい悪臭を放つ巨大な花だ!あまりの悪臭にPCの装備していた「ペット」じゃ全て気絶してシナリオ終了まで使用不可能になる。なぜかギア製のペットももれなく気絶する。有利な得意点「犬の鼻」をもつPCがいれば近寄る前に回避可能。",
			        ]
		  
		  when 6
		    table = [
			         "魔族の狩りで傷ついた狼を発見する。ラウンド終了までに[HP]を1点でも回復してやればふらふらと歩きだし、木の根元でここを掘れというように吠える。埋まっていたものは1Dを振って決定する。
----------
1:犬の糞(ゴミ)
2:10GP
3:財宝ランク#{[0, 2, 4, 6][difficulty]}のアイテム
4:財宝ランク#{[1, 3, 5, 7][difficulty]}のアイテム
5:財宝ランク#{[2, 4, 6, 8][difficulty]}のアイテム
6:うぃっしゅすたー(大事なもの)",
					 "少し開けた原っぱでフラウのダンスパーティーに誘われる。このイベントが発生するとエネミーは消滅する。行動を消費して[敏捷-#{[6, 8, 10, 12][difficulty]}]判定に成功してダンスを踊ると原っぱの中心からすくすくと大きなキノコが育ち、キノコの馬車でダンジョンのゴール付近まで一気にすっとばしてくれる。第4ラウンドが終了したものと扱い、クリア時の財宝ランク+2。",
					 "フラウたちが「森ガールファッションコンテスト」を開催しており、その助っ人を依頼される。このイベントが発生するとエネミーは消滅する。[意思-#{[6, 8, 10, 12][difficulty]}]判定に成功すれば的確なアドバイスで助っ人を依頼したフラウを優勝に導くことができ、その謝礼として#{["狩人の羽根帽子(装飾品)", "緊急召喚の宝珠(装飾品)", "毒の香水瓶(装飾品)", "女王の花冠(装飾品)"][difficulty]}",
					 "霊樹の花にたまった水が神秘的な魔力を帯びている。[知力-6]判定に成功するとそれにポーションとしての効果があることがわかり、奇跡のポーション(消耗品)を入手する。【ポーションナレッジ】を習得したPCがいれば判定不要。有効:【賢人の知恵】",
					 "迷子のフラウを見つける。4ラウンド目が終了するまでに他のフラウに出会うイベントが発生した場合、偶然にもそのフラウと知り合いで、お礼に財宝ランク#{[3, 5, 7, 9][difficulty]}のアイテムを渡してくれる。フラウに出会えずシナリオをクリアした場合も、迷宮からひとまず出ることができたお礼に財宝ランク#{[1, 3, 5, 7][difficulty]}のアイテムを渡してくれる。",
					 "ランダムに選んだPC1人が、うっかり泉に武器を落としてしまう。すると泉から女神が出現して、落とした武器と同じ種類の超高級品の武器(魔将ドロップ品など)を落としたかどうかを聞いてくる。[意思#{["", "-2", "-4", "-6"][difficulty]}]判定に成功すれば正直に答え、武器に#{[5000, 10000, 30000, 50000][difficulty]}GPまでの任意のアタッチメントを追加してくれる。失敗すると嘘をついて女神を怒らせてしまい、装備していた武器を失ってしまう。",
			        ]
		  
		  else
		    return nil
		end
	  
	  when 6
	    areaText = "墓場"
		case type
		  when 1
		    table = [
			         "回復の泉。PC全員の[HP][FP]が完全に回復する。「☆死亡」以外のあらゆるBSも回復する。",
					 "「彼らは生前の思いが強すぎ成仏できません。語りかけて鎮めてやるとよいでしょう…」アズマ風の墓石が佇んでいる。[知力-#{[3, 6, 9, 12][difficulty]}]判定か[意思-#{[3, 6, 9, 12][difficulty]}]判定に成功するとアズマ式お祈りや語りかけにより霊に感謝され、[HP][FP][Ft]が全回復する。失敗すると霊を怒らせて呪われ、全員の[Ft]が1点減少する。有効:【賢人の知恵】(知力)【詩人の交渉術】(意思)",
					 "墓守の休憩所を見つける。心の落ち着くお線香の香りがする…[HP][FP]#{[10, 15, 20, 25][difficulty]}点とBSを回復する。更にシナリオ終了まで[抵抗]に+2のボーナス。",
					 "「人間か。キミたちはここの亡者のようにならないようにね…」ヒガンバナの世話をするフラウと出会い、「ヒガンバナの毒」を武器に塗ってもらうことができる。物理攻撃の致傷力に+5のボーナス。",
					 "シルヴァテイルのネクロマンサー達が集まって、何やら怪しい儀式をしている。道中で「☆死亡」した、もしくは保険を適用して強制送還されたキャラクターがいれば、[HP][FP]とBSが全回復した状態で復活させてもらうことができる。それ以外の場合は不気味な儀式に不安を感じ、FPを1点消費する。",
					 "回復の泉があるのだが…?PCのうち1人でも[HP][FP]のいずれかが減少している場合このイベントは拒否できない。PC全員の[HP][FP]が完全に回復する。「☆死亡」以外のあらゆるBSも回復する。黄泉の国の水を飲んだことでシナリオ終了まで「分類:アンデッド」となり、【死者に鞭】【アマテラスの光】などの、一部の【特技】の効果を受ける。",
			        ]
		  
		  when 2
		    table = [
			         "財宝ランク#{[0, 2, 4, 6][difficulty]}の宝箱を発見する。カギやトラップはかかっていない。行動を消費することで開けることができる。",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のカギがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でカギを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "財宝ランク#{[1, 3, 5, 7][difficulty]}の宝箱を発見する。難易度#{[3, 6, 9, 12][difficulty]}のトラップがかかっている。行動を消費して[感覚-#{[3, 6, 9, 12][difficulty]}]判定でトラップを解除して開けることができる。有効：【盗賊の心得】【ロックスミス】",
					 "骸が何かを大事そうに握りしめている(抱きかかえている)。行動を消費して[体力-#{[2, 4, 6, 10][difficulty]}]判定に成功すれば、財宝ランク#{[2, 4, 6, 8][difficulty]}のアイテムを入手できるが、Ftが1点減少する。",
					 "ミミックの罠。ランダムなキャラクターに「3D+#{[30, 50, 70, 100][difficulty]}」の「斬撃」属性ダメージを与える。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化でき、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GPを入手可能。有効：【盗賊の心得】【ロックスミス】",
					 "トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。[知力-#{[3, 6, 9, 12][difficulty]}]判定に成功すればこの罠を見抜いて無効化することができ、なおかつ#{[1000, 2000, 5000, 10000][difficulty]}GP入手可能。",
			        ]
		  
		  when 3
		    table = [
			         "ちょっとなにか出そうな、柳の木でできたトンネルを発見する。PC全員が[意思]判定を行い、全員成功した場合はクリア時の財宝ランク+1。最も成功度の低かった(失敗度の大きかった)PCは揺れる柳を幽霊と思い込み、4ラウンド終了まであらゆる判定に-2のペナルティ。",
					 "石畳の道を歩いている途中で朽ちた祠を発見する。何かお供え物をしたほうが良いだろうか?アイテム欄の消耗品1つをお供えすると祠が動いて地下通路が出現する!この通路を通ることで近道できて、クリア時の財宝ランク+1。",
					 "道が途切れ、草が伸び放題の荒れ地に出る。方向もわからず、進むには骨が折れそうだ…[体力-#{[2, 4, 6, 8][difficulty]}]判定を行い、成功すればクリア時の財宝ランク+1。失敗するとクリア時の財宝ランク-1。",
					 "どこまでも卒塔婆とススキしかない…同じ景色が続き、進んでいるか怪しくなる。1Dを振って1～3が出れば何もないが、4～6が出るとクリア時の財宝ランク-1。有利な特異点「天体時計」があればペナルティは受けない。",
					 "地面から突如骨の手が伸びて足を掴んでくる!PC全員が[移動#{["+4", "+2", "", "-2"][difficulty]}]判定を行い、クリア時の財宝ランクが「失敗した人数」分減少する。【死者に鞭】を持つPCがいれば骨は威圧されて引っ込み、この効果は無視できる。",
					 "先へ進む道には纏わりつくような死者の呪いが満ちている。直進するとシナリオ終了まであらゆる判定に-2のペナルティ。遠回りをすると悪影響は受けないがクリア時の財宝ランク-2。【死者に鞭】か【鎮魂の盾】を持つPCがいれば呪いをはねつけ、直進してもペナルティを受けない。",
			        ]
		  
		  when 4
		    table = [
			         "墓場に浮かんでいた人魂が突如魔物になって襲いかかってきた!エネミーとエンカウント。",
					 "朽ちていた骨が突如起き上がり襲いかかってきた!エネミーとエンカウント。このエネミーは業物の武器を持っており、物理攻撃の致傷力に+#{[5, 10, 15, 20][difficulty]}のボーナス。",
					 "不吉な歌を口ずさみ、ステップを踏みながらかわいらしい少女が近づいてくる。エネミーとエンカウント。",
					 "遠くから不吉な進軍の音を聞く。PC全員が[感覚-#{[2, 4, 6, 8][difficulty]}]判定を行い、誰か1人でも成功すれば、第二魔将グレヴディガーの軍勢が迫っているのを知る。全員判定に失敗してしまうとPCは第二魔将グレイヴディガーとその配下である無数の亡霊騎士団と相対することになる。#{["「保険」に入っていなければPCたちは死亡して、グレイヴディガーの配下にさせられてしまう。君たちの冒険はここで終了だ。", "「保険」に入っていなければPCたちは死亡して、グレイヴディガーの配下にさせられてしまう。君たちの冒険はここで終了だ。", "「保険」に入っていなければPCたちは死亡して、グレイヴディガーの配下にさせられてしまう。君たちの冒険はここで終了だ。", "エネミーとエンカウント。"][difficulty]}有効:「狐の耳」「虫の知らせ」",
					 "「我らの眠りを妨げるものは誰だ…!」貴族の棺とそれを守る人形だ。墓荒らしには容赦なく襲い掛かる!エネミーとエンカウント。棺の中には貴金属が入っており、一部エネミーの通常ドロップの金額が増加する。",
					 "壁に埋まった10mはあろうかという巨大な蛇の骨が動き出し襲い掛かってくる!エネミーとエンカウント。",
			        ]
		  
		  when 5
		    table = [
			         "PC全員に墓から突然幻影が襲いかかる。幻影なので実害はないのだが、本当の攻撃と思って「パリイ」か「シールド」を1回消費してしまう。どちらも行えない場合、腰を抜かしてBS「☆転倒」を受ける。【トゥルービジョン】などがかかっているPCには無効。",
					 "「ひひっ、かかったなボケが!」理不尽にもギロチンが突如ランダムなPC1人に落ちてくる!「ドッジ-#{[4, 6, 8, 10][difficulty]}」判定を行い、失敗すると「3D+#{[40, 60, 80, 120][difficulty]}」点の「斬撃」属性ダメージを受ける。",
					 "「すいっちおーん。私達の仲間にしてやるよ!」用途不明の建物に迷い込んでしまったが…なんてこった、ここは火葬場だ!早く脱出しないと灰になるまで焼かれてしまうぞ!PC全員が「3D+#{[30, 40, 50, 70][difficulty]}」点の「火炎」属性ダメージを受ける。[移動]が#{[8, 9, 10, 12][difficulty]}以上のPCは何とか逃げ出しダメージを受けず、さらに自分より[体力]の低いキャラクター1人を連れて脱出可能。有効:【盗賊の心得】【ロックスミス】",
					 "墓石が動き出し中から何かが出てこようとしている![体力-#{[4, 6, 8, 10][difficulty]}]判定に成功すればなにも起こらないが、失敗すると探索中に倒されたエネミーの中で最もCLが高いエネミーが再度出現する。該当モンスターが存在しなかった場合は、昼寝をしていたフラウが出てくるだけ。",
					 "金の亡者のゾンビが群がってくる。金を渡してやるまで満足しそうにない…#{[1000, 2000, 4000, 8000][difficulty]}GPを支払うと満足して去っていくが、支払いを拒否した場合(もしくはお金が足りなかった場合)はPC全員が「3D+#{[10, 20, 30, 50][difficulty]}」の「打撃」属性ダメージを受ける。【死者に鞭】を持つPCがいればひと睨みでそそくさと去っていく。",
					 "「おやおや。死者に気に入られましたか…困りましたねえホッホッ」ランダムなPC1人の武器が死者の怨念を吸い取り魔剣となる!魔剣は攻撃力に+5のボーナスを得るが、装備していると[HP]の最大値が10点減少する。魔剣となった武器は売却不可能で、不要な場合は捨てるしかない。すでに魔剣となっている武器と、【特技】によって入手した武器は魔剣にならない。",
			        ]
		  
		  when 6
		    table = [
			         "雷が突然鳴り響く。敵味方全員が3Dを振り、出目が一番高いキャラクターは「3D+#{[30, 50, 70, 100][difficulty]}」点の「電撃」属性ダメージを受ける。",
					 "「いいところに来たナ。どうだ、お前らも飲んでいくカ?」タルの上に腰かけ、減ることのない酒を口に運び続けるスケルトンがいる。このイベントが発生するとエネミーは消滅する。酒を飲む場合、行動を消費して[意思#{["", "-1", "-2", "-4"][difficulty]}]判定を4回連続で行う。全て成功すると、「ついに酒が切れたカ、最後の晩酌に付き合ってもらって感謝するゼ」と感謝を述べて消滅し、あとには財宝ランク3のアイテムが残る。途中で1度でも失敗した場合、酒に悪酔いしてシナリオ終了まであらゆる判定に-2のペナルティ。",
					 "怪しい輝きを放つ宝石を発見する。手にとったPCは呪われてシナリオ終了まであらゆる判定に-2のペナルティ。手に取らない場合は全員に[意思#{["", "-1", "-2", "-3"][difficulty]}]判定が必要で、不利な特異点「金の亡者」「好奇心は猫を殺す」があるとこの[意思]判定に-4のペナルティ。無事持ち帰った場合呪いは解け、#{[2000, 6000, 20000, 60000][difficulty]}GPで売却できる。",
					 "朽ちたギアの墓場だ。まだ使えるギアがあるかもしれない。【魔導工学のススメ】があれば、SLvに応じたアイテムが1つ入手可能。
----------
SLv1:カラクリバランサー(装飾品)
SLv2:カラクリお茶キット(装飾品)
SLv3:ゴーレムアーム(装飾品)
#{["", "SLv4:ホイールブースター(装飾品)", "SLv4:ホイールブースター(装飾品)", "SLv4:ホイールブースター(装飾品)"][difficulty]}
#{["", "", "SLv5:ナグルファル装甲(装飾品)", "SLv5:ナグルファル装甲(装飾品)"][difficulty]}
#{["", "", "", "SLv6:死者の止まらない歯車(装飾品)"][difficulty]}",
					 "「ほーらよっといでーよっといでー、地獄の沙汰も金次第…」うすら寒い気配の漂う川辺に出る。川辺には渡し守らしき、ローブをかぶった2人の少女がいる。1人あたり#{[200, 500, 1000, 2000][difficulty]}GPを支払えばクリア時の財宝ランク+1。支払いを拒否したかお金が足りない場合、エネミーとエンカウント。",
					 "『千ノ戦イデ千ノ勝チヲ知ル者、ココニ眠ル』と刻まれた棺を見つける。棺を開けた場合はエネミーとエンカウント。勝利すると#{["キメラパーツ(装飾品)", "キメラパーツ(装飾品)", "グレートキメラパーツ(装飾品)", "ウェポンマスターの証(装飾品)"][difficulty]}を入手できる。不利な特異点「好奇心は猫を殺す」「脳みそ筋肉」を持つキャラクターは[意思]判定を行い、失敗すると棺を開けてしまう。",
			        ]
		  
		  else
		    return nil
		end
	  
	  else
	    return nil
	end
	
	result, event = get_table_by_1d6(table)
	number = "#{area}#{type}#{event}"
	
	return "#{tableName}(#{number}):#{areaText}<#{difficultyText}>:#{result}"
  end
  
  #夢幻の迷宮エネミーデータ表
  def getRandomEnemyDataResult(command)
    if( /RED(E|N|H|L)(256|265|465|665|666)/ === command )
	  dif    = $1
	  area   = 0
	  event  = $2.to_i
	  number = event
	elsif( /RED(E|N|H|L)([1-6])4([1-6])/ === command )
	  dif    = $1
	  area   = $2.to_i
	  event  = $3.to_i
	  number = "#{area}4#{event}"
	else
	  return nil
    end
	
	tableName = "エネミーデータ表"
	
	case dif
	  when "E"
	    difficultyText = "初級"
		difficulty = 0
	  
	  when "N"
	    difficultyText = "中級"
		difficulty = 1
	  
	  when "H"
	    difficultyText = "上級"
		difficulty = 2
	  
	  when "L"
	    difficultyText = "悪夢"
		difficulty = 3
	  
	  else
	    return nil
	end
	
	case area
	  when 1
	    areaText = "洞窟"
		table = [
		         [1, [
				      'キャンディークラウン(CL40)1匹',
					  'キャンディクラウン(CL40)「1D-3」匹(最低1匹)',
					  'キャンディークラウン「1D-2」匹(最低1匹)出目が6だった場合ゴールデンクラウン(CL177)1匹',
					  'ゴールデンクラウン(CL177)とエンカウント'
			     ]],
		         [2, [
				      'ベルセルク(CL7)3匹',
					  'ベルセルク(CL7)3匹([命中]+4、[HP]+30、[FP]+10、あらゆる致傷力+20)',
					  'ベルセルク(CL7)3匹([命中]+8、[HP]+60、[FP]+20、あらゆる致傷力+40)',
					  'ベルセルク(CL7)3匹([命中]+16、[HP]+120、[FP]+40、あらゆる致傷力+80)'
			     ]],
		         [3, [
				      'ガーゴイル(CL10)2匹',
					  'ガーゴイル(CL10)2匹([命中]+4、[HP]+20、[FP]+10、あらゆる致傷力と防護点+20)',
					  'ガーゴイル(CL10)2匹([命中]+8、[HP]+40、[FP]+20、あらゆる致傷力と防護点+40)',
					  'ザッハーク(CL39)3匹'
			     ]],
		         [4, [
				      'デビルホイール(CL18)1匹',
					  'デビルホイール(CL18)1匹、あらゆる致傷力+20',
					  'デビルホイール(CL18)1匹、あらゆる致傷力+40',
					  'ムスペルヘイムの獣(CL65)、あらゆる防護点+20'
			     ]],
		         [5, [
				      'ヘルハウンド(CL12)1匹、インプ(CL3)2匹',
					  'フェニックス(CL25)2匹',
					  '火龍ヘルブレイザー(CL50)1匹、ケルベロス(CL33)1匹',
					  '煉獄龍バーガトリ(CL100)1匹'
			     ]],
		         [6, [
				      'アイスメイデン(CL10)1匹、アイスリザード(CL7)2匹',
					  'クリスタルビースト(CL25)2匹',
					  '氷河龍グレイシャル(CL65)1匹',
					  '冥界龍コキュートス(CL110)1匹'
			     ]],
		        ]
	  
	  when 2
	    areaText = "遺跡"
		table = [
		         [1, [
				      '1Dをふって無限の迷宮の地形から1つ選択する。その地形で該当する難易度[初級]に名前の書かれたエネミーが全て1体ずつ出現する。特別な強化が施されている場合それも適用する。',
					  '1Dをふって無限の迷宮の地形から1つ選択する。その地形で該当する難易度[中級]に名前の書かれたエネミーが全て1体ずつ出現する。特別な強化が施されている場合それも適用する。',
					  '1Dをふって無限の迷宮の地形から1つ選択する。その地形で該当する難易度[上級]に名前の書かれたエネミーが全て1体ずつ出現する。特別な強化が施されている場合それも適用する。',
					  '1Dをふって無限の迷宮の地形から1つ選択する。その地形で該当する難易度[悪夢]に名前の書かれたエネミーが全て1体ずつ出現する。特別な強化が施されている場合それも適用する。'
			     ]],
		         [2, [
				      'アルテミス(CL8)3匹',
					  'アルテミス(CL8)3匹([命中]+4、[HP]+30、[FP]+20、あらゆる致傷力+20)',
					  'アルテミス(CL8)3匹([命中]+8、[HP]+60、[FP]+30、あらゆる致傷力+40)',
					  'アルテミス(CL8)3匹([命中]+16、[HP]+120、[FP]+40、あらゆる致傷力+80)'
			     ]],
		         [3, [
				      'スターゲイザー(CL10)2匹',
					  'コスモロジスト(CL20)2匹',
					  'コスモロジスト(CL20)4匹',
					  'デスサジタリー(CL45)2匹'
			     ]],
		         [4, [
				      'ヤシャ(CL10)1匹、スケルトン(CL3)3匹',
					  'ヤシャ(CL10)3匹([命中]+4、[HP]+30、[FP]+10、あらゆる致傷力+15)',
					  'アシュラ(CL48)2匹',
					  'コンゴウ(CL60)2匹'
			     ]],
		         [5, [
				      'ヘルハウンド(CL12)2匹',
					  'クリスタルビースト(CL25)2匹',
					  '火龍ヘルブレイザー(CL50)1匹、氷河龍グレイシャル(CL65)',
					  '『単眼の巨神』アイングロース(CL100/ネームド)'
			     ]],
		         [6, [
				      'ゴーレム(CL13)1匹',
					  'ミスリルゴーレム(CL27)1匹',
					  'アダマンゴーレム(CL45)1匹',
					  'カラクリヒメショーグン(CL75)1匹'
			     ]],
		        ]
	  
	  when 3
	    areaText = "山岳"
		table = [
		         [1, [
				      'アイアンプリチン(CL5)5匹',
					  'アイアンプリチン(CL5)5匹([命中]+4、[HP]+30、[FP]+10)',
					  'アイアンプリチン(CL5)5匹([命中]+8、[HP]+60、[FP]+20)',
					  'アイアンプリチン(CL5)5匹([命中]+16、[HP]+120、[FP]+40)'
			     ]],
		         [2, [
				      'ウイングスレイブ(CL4)5匹',
					  'ウイングスレイブ(CL4)5匹([命中]+4、[HP]+30、[FP]+10、あらゆる致傷力+20)',
					  'ガルーダ(CL40)2匹',
					  '栄光の天使(CL60)2匹'
			     ]],
		         [3, [
				      'ブラックナイト(CL10)1匹、ソルジャー(CL4)3匹',
					  'デュラハン(CL22)1匹、ブラックナイト(CL10)2匹',
					  'サーバントマスター(CL35)1匹、デュラハン(CL22)2匹',
					  'ジェネラル(CL55)1匹、サーバントマスター(CL35)2匹'
			     ]],
		         [4, [
				      'ソルジャーアント(CL8)2匹',
					  'ソルジャーアント(CL8)2匹([命中]+4、[HP]+30、[FP]+10、あらゆる致傷力+20)',
					  'インペリアルアント(CL30)2匹',
					  '『女王キノコ』アカシックツリー(CL50/ネームド)1匹、インペリアルアント(CL30)2匹'
			     ]],
		         [5, [
				      'カボチャの魔女(CL8)2匹',
					  'カボチャの魔女(CL8)2匹([命中]+4、[HP]+30、[FP]+10、あらゆる致傷力+20)',
					  'カボチャの大魔女(CL35)2匹',
					  '堕落の黒天使(CL60)2匹'
			     ]],
		         [6, [
				      'フェニックス(CL25)2匹',
					  'フェニックス(CL25)2匹([命中]+4、[HP]+40、[FP]+10、あらゆる致傷力+30)',
					  'フェニックス(CL25)2匹([命中]+8、[HP]+80、[FP]+20、あらゆる致傷力+60)',
					  '煉獄フェニックス(CL85)2匹'
			     ]],
		        ]
	  
	  when 4
	    areaText = "水辺"
		table = [
		         [1, [
				      'フロストクラブ(CL6)2匹',
					  'フロストクラブ(CL6)3匹',
					  '『氷海の主』ギガントキャンサー(CL20/ネームド)',
					  '『氷海の主』ギガントキャンサー(CL20/ネームド)、フロストクラブ(CL6)3匹'
			     ]],
		         [2, [
				      'アシガル(CL4)3匹',
					  'ハタモト(CL10)3匹',
					  'ヒトキリ(CL33)2匹',
					  'スカーレス(CL38)3匹'
			     ]],
		         [3, [
				      'アンブッシュマン(CL5)3匹',
					  'アンブッシュマン(CL5)3匹([命中]+4、[HP]+20、[FP]+10、あらゆる致傷力+10)',
					  'シャドウストーカー(CL35)2匹',
					  'シャドウストーカー(CL35)3匹'
			     ]],
		         [4, [
				      'アップルドール(CL12)2匹',
					  'アップルドール(CL12)2匹、ポイズンリリー(CL7)2匹',
					  'テラードール(CL30)2匹',
					  'テラードール(CL30)2匹、バリアリーフ(CL27)2匹'
			     ]],
		         [5, [
				      'ナイトライダー(CL15)1匹',
					  'ナイトライダー(CL15)2匹',
					  'ジェネラル(CL55)1匹',
					  'ジェネラル(CL55)2匹'
			     ]],
		         [6, [
				      'ジェルスケルトン(CL10)1匹',
					  'ジェルスケルトン(CL10)1匹([命中]+4、[FP]+10、あらゆる致傷力+20)',
					  'ジェルスケルトン(CL10)1匹([命中]+8、[FP]+20、あらゆる致傷力+40)',
					  'ジェルスケルトン(CL10)1匹([命中]+12、[FP]+40、あらゆる致傷力+80)'
			     ]],
		        ]
	  
	  when 5
	    areaText = "森林"
		table = [
		         [1, [
				      'スナッチャー(CL4)3匹',
					  'ゴールデンビースト(CL10)3匹',
					  'ヨウコ(CL30)2匹',
					  'イビルオーメン(CL42)2匹'
			     ]],
		         [2, [
				      'スターゲイザー(CL10)1匹、オーク(CL3)3匹',
					  'スターゲイザー(CL10)1匹、ヘルハウンド(CL12)2匹',
					  'コスモロジスト(CL20)1匹、ケルベロス(CL33)1匹',
					  'サーバントマスター(CL35)1匹、ケルベロス(CL33)2匹'
			     ]],
		         [3, [
				      'オウルセージ(CL5)1匹、インプ(CL3)3匹。指定エネミー:オウルセージ',
					  'オウルセージ(CL5)3匹。指定エネミー:オウルセージ',
					  'オウルコマンダー(CL18)1匹、キメラ(CL15)2匹。指定エネミー:オウルコマンダー',
					  'オウルコマンダー(CL18)2匹、キメラグレート(CL60)1匹。指定エネミー:オウルコマンダー'
			     ]],
		         [4, [
				      'グリーンアクトレス(CL22)1匹',
					  '魔将樹の騎士(CL40)1匹',
					  '魔将樹の番人(CL80)1匹',
					  '『魔将樹の剣姫』ロジエモール(CL120/ネームド)1匹'
			     ]],
		         [5, [
				      'ポイズンリリー(CL7)1匹、リリーの尖兵(CL5)1匹',
					  'ポイズンリリー(CL7)1匹、リリーの尖兵(CL5)1匹([命中]+4、[HP]+30、[FP]+10、あらゆる致傷力+20)',
					  'バリアリーフ(CL27)1匹、リリーの尖兵(CL5)1匹([命中]+8、[HP]+60、[FP]+20、あらゆる致傷力+40)',
					  '『密林の女王』クイーンリリー(CL70/ネームド)1匹、リリーの尖兵(CL5)1匹([命中]+16、[HP]+120、[FP]+40、あらゆる致傷力+80)'
			     ]],
		         [6, [
				      'ブラックナイト(CL10)1匹、ソルジャー(CL4)3匹',
					  'ヴァルキリー(CL20)1匹、ブラックナイト(CL10)2匹',
					  'フレイヤ(CL45)1匹、ヴァルキリー(CL20)2匹',
					  'ジェネラル(CL55)1匹、フレイヤ(CL45)2匹'
			     ]],
		        ]
	  
	  when 6
	    areaText = "墓場"
		table = [
		         [1, [
				      'ヤコ(CL6)3匹(【狐の送り火】のデータを「疲労:なし」に変更)',
					  'ヨウコ(CL30)1匹(【狐の送り火】のデータを「疲労:なし」に変更)',
					  'ヨウコ(CL30)3匹(【狐の送り火】のデータを「疲労:なし」に変更)',
					  'タタリドラゴン(CL60/ネームド)1匹(【狐の送り火】のデータを「疲労:なし」に変更)'
			     ]],
		         [2, [
				      'スケルトン(CL3)4匹',
					  'ナイトスケルトン(CL12)3匹',
					  'ヒトキリ(CL33)2匹(「分類:アンデッド」を追加)',
					  '堕ちた黒龍(CL48)2匹'
			     ]],
		         [3, [
				      'ポイズンリリー(CL7)1匹(【華劇:リリーオブザバレー】使用済み)、ファントム(CL5)2匹',
					  'ポイズンリリー(CL7)1匹(【華劇:リリーオブザバレー】使用済み)、ゴースト(CL10)3匹',
					  'グリーンアクトレス(CL22)1匹(【華劇:フォレストステップ】使用済み)、デュラハン(CL22)2匹',
					  'グリーンアクトレス(CL22)1匹(【華劇:フォレストステップ】使用済み)、カラクリヒメショーグン(CL75)1匹'
			     ]],
		         [4, [
				      '君たちの冒険はここで終了だ。',
					  '君たちの冒険はここで終了だ。',
					  '君たちの冒険はここで終了だ。',
					  '第二魔将『葬送者』グレイヴディガー(CL200/魔将)1匹、『ディガー様親衛隊長』フネライユ(CL66/ネームド)1匹、『トラップマスター』アンテルモン(CL65/ネームド)1匹'
			     ]],
		         [5, [
				      'ゴースト(CL10)1匹(通常ドロップ「1000GP」)、ソルジャー(CL4)2匹',
					  'ゴースト(CL10)1匹(通常ドロップ「2000GP」)、ハタモト(CL10)3匹',
					  'リッチ(CL44)1匹(通常ドロップ「4000GP」)、ミスリルゴーレム(CL27)1匹',
					  'エルダーリッチ(CL55)1匹(通常ドロップ「8000GP」)、アダマンゴーレム(CL45)1匹'
			     ]],
		         [6, [
				      'ボーンスネーク(CL20)1匹',
					  'ボーンスネーク(CL20)2匹',
					  'ラダマンティスの蛇(CL50)1匹',
					  'ラダマンティスの蛇(CL50)1匹(ネームド仕様[HP4倍、【ネームドエネミー】習得])'
			     ]],
		        ]
				
	  when 0
	    table = [
		         [256, [
				        'ボーンスネーク(CL50)1匹',
						'ラダマンティスの蛇(CL50)1匹',
						'銀河龍ラクテア/ドラゴン形態(CL90)1匹',
						'『三つ首の災厄』トライディザスター(CL100/ネームド)1匹'
				 ]],
				 [265, [
				        'キャンディークラウン(CL40)「1D」匹',
						'キャンディークラウン(CL40)「1D+1」匹',
						'キャンディークラウン(CL40)「1D」匹、ゴールデンクラウン(CL177)1匹',
						'キャンディークラウン(CL40)「1D」匹、ゴールデンクラウン(CL177)2匹'
				 ]],
				 [465, [
				        'リビングデッド(CL5)3匹',
						'ゴースト(CL10)3匹',
						'デュラハン(CL22)3匹',
						'リッチ(CL44)3匹'
				 ]],
				 [665, [
				        'カロン(CL12)2匹',
						'カロンキャプテン(CL25)2匹',
						'リッチ(CL44)2匹',
						'エルダーリッチ(CL55)2匹([HP]+10)'
				 ]],
				 [666, [
				        '『漆黒の戦鬼』ブラックナイト(CL10/ネームド)1匹',
						'『漆黒の戦鬼』ブラックナイト(CL10/ネームド)1匹([命中]+4、あらゆる致傷力+20、[HP]+200)',
						'『白銀の猛将』ジェネラル(CL55/ネームド)1匹',
						'『白銀の猛将』ジェネラル(CL55/ネームド)1匹([命中]+4、あらゆる致傷力+20、[HP]+500)'
				 ]],
		        ]
		case event/100
		  when 1
		    areaText = "洞窟"
		  when 2
		    areaText = "遺跡"
		  when 3
		    areaText = "山岳"
		  when 4
		    areaText = "水辺"
		  when 5
		    areaText = "森林"
		  when 6
		    areaText = "墓場"
		  else
		    return nil
		end
	  
	  else
	    return nil
	end
	
	result = get_table_by_number(event, table)
	
	return "#{tableName}(#{number}):#{areaText}<#{difficultyText}>:#{result[difficulty]}"
	
  end
  
end
