#--*-coding:utf-8-*--
# どどんとふ用 GURPS-FW オリジナルダイスボット
# Last update 2013/11/07

class GurpsFW < DiceBot
  
  def initialize
    super
    @sendMode = 2
    @d66Type = 1
  end
  
  def gameName
    'ガープスフィルトウィズ'
  end
  
  def gameType
    "GurpsFW"
  end
  
  def prefixs
    [
	  'CRT',
	  'HCRT',
	  'FMB',
	  'MFMB',
	  'HIT',
	  'FEAR((\+)?\d*)',
	  'REACT((\+|\-)?\d*)',
	  'TRAP(E|N|H|L)',
	  'TRS((E|N|H|L)\d+)((\+|\-)?\d*)',
	  'RAND(E|N|H|L)[1-6]?',
	  'RENC(E|N|H|L)[1-6]?',
	  'AREA',
	  'DROP(N)?((\+)?\d)?',
	  'HST',
	  'KHST',
	  'RANDOP',
	  'LOT(N|P)',
	]
  end
  
  def getHelpMessage
    return <<INFO_MESSAGE_TEXT
--GURPS汎用コマンド----------
・判定においてクリティカル・ファンブルの自動判別、成功度の自動計算。(3d6<=目標値)
 ・祝福等のダイス目にかかる修正は「3d6-1<=目標値」といった記述で計算されます。
 (ダイス目の修正値はクリティカル・ファンブルに影響を与えません。)
 ・クリティカル値・ファンブル値への修正については現在対応していません。
・クリティカル表 (CRT)
・頭部打撃クリティカル表 (HCRT)
・ファンブル表 (FMB)
・呪文ファンブル表 (MFMB)
・命中部位表 (HIT)
・恐怖表 (FEAR+n)
　nには恐怖判定の失敗度を入れてください。
・反応判定表 (REACT, REACT±n)
　nには反応修正を入れてください。
・D66ダイスあり
--GURPS-FW専用コマンド----------
・ドロップ判定(DROP)/ネームドドロップ判定(DROPN)
 ・ドロップ判定に修正が付く場合は末尾に+xを記述(xは修正値)。(DROP+x、DROPN+x)
・必殺技表(HST)/驚異的必殺技表(KHST)
 ・ホムンクルスの【必殺技！】/【驚異的必殺技！】用コマンド。
・ナンバーワンくじ/ノーマル(LOTN)/プレミアム(LOTP)
--夢幻の迷宮(ver.2013/11/07)----------
・コマンド中のdには難易度を入れてください。(初級：E 中級：N 上級：H 悪夢：L)
・コマンド中のaには地形を入れてください。
 (1：洞窟 2：遺跡 3：断崖 4：水辺 5：森林 6：墓地)
・ランダムイベント(RANDd)/地形固定(RANDda)
・ランダムエンカウント(RENCd)/地形固定(RENCda)
・トラップリスト(TRAPd)
・報酬財宝テーブル(xに到達深度を記述)。 (TRSdx)
 ・財宝テーブルの段階が変動する場合、末尾に±yを記述(yは変動段階)。(TRSdx±y)
  [例：TRSE5-1、TRSH36+2]
・地形決定表(AREA)
・迷宮追加オプション表(RANDOP)
INFO_MESSAGE_TEXT
  end
  
  def dice_command(string, name)
    secret_flg = false
    
    return '1', secret_flg unless( /(^|\s)(S)?(#{prefixs.join('|')})(\s|$)/i =~ string )
    
    secretMarker = $2
    command = $3.upcase
    
    output_msg = getCommandResult(command, name)
    
    if( secretMarker )    # 隠しロール
      secret_flg = true if(output_msg != '1');
    end
    
    return output_msg, secret_flg
  end
  
  def check_nD6(total_n, dice_n, signOfInequality, diff, dice_cnt, dice_max, n1, n_max) # ゲーム別成功度判定(nD6)
    if((dice_cnt == 3) && (signOfInequality == "<="))
      
      success = diff-total_n; #成功度
      crt_string = " ＞ クリティカル(成功度：#{success})";
      fmb_string = " ＞ ファンブル(失敗度：#{success})";
      fail_string = " ＞ 自動失敗(失敗度：#{success})";
      
      #クリティカル
      if   ((dice_n <= 6) && (diff >= 16))
        return crt_string;
      elsif((dice_n <= 5) && (diff >= 15))
        return crt_string;
      elsif(dice_n <= 4)
        return crt_string;
      end
      #ファンブル			
      if   (diff-dice_n <= -10)
        return fmb_string;
      elsif((dice_n >= 17) && (diff <=15))
        return fmb_string;
      elsif(dice_n >= 18)
        return fmb_string;
      elsif(dice_n >= 17)
        return fail_string;
      end
      
      if(total_n <= diff)
        return " ＞ 成功(成功度：#{success})";
      else
        return " ＞ 失敗(失敗度：#{success})";
      end
      
    end
    
    return ''
  end

  def getCommandResult(string, nick_e)
	tableName = ""
    result = ""
    number = 0
	
	case string

		when "CRT"
			tableName = "クリティカル表";
			table = [
				'体を狙っていたら、相手は気絶(回復は30分後に生命力判定)。他はダメージ3倍。',
				'相手の防御点を無視。',
				'ダメージ3倍。',
				'ダメージ2倍。',
				'相手は生命力判定を行い、失敗すると朦朧状態となる。',
				'四肢を狙っていたら、6ターンそこが使えなくなる。通常ダメージ。',
				'通常ダメージ。',
				'通常ダメージ。',
				'通常ダメージ。',
				'四肢を狙っていたら、6ターンそこが使えなくなる。通常ダメージ。',
				'相手の防御点を無視。',
				'四肢を狙っていたら、そこが使えなくなる(通常ダメージ)。他は2倍ダメージ。',
				'相手は武器を落とす。通常ダメージ。',
				'ダメージ2倍。',
				'ダメージ3倍。',
				'体を狙っていたら、相手は気絶(回復は30分後に生命力判定)。他はダメージ3倍。',
				];
			result, number = get_table_by_nD6(table, 3);
			
		when "HCRT"
			tableName = "頭部打撃クリティカル表";
			table = [
				'敵は即死する',
				'敵は意識を失う。30分ごとに生命力判定をして、成功すると意識を回復する。',
				'敵は意識を失う。30分ごとに生命力判定をして、成功すると意識を回復する。',
				'敵は両目を負傷する。朦朧状態になる。目が見えないので、敏捷力-10。',
				'敵は片目を負傷する。朦朧状態になる。敏捷力-2。',
				'敵はバランスを失う。次のターンまで、防御しかできない。',
				'通常ダメージのみ。',
				'通常ダメージのみ。',
				'通常ダメージのみ。',
				'「叩き」攻撃なら、敵は24時間のあいだ耳が聞こえなくなる。「切り」「刺し」なら、1点しかダメージを与えられないが、傷跡が残る。',
				'「叩き」攻撃なら、敵は耳が聞こえなくなる。「切り」「刺し」なら、2点しかダメージを与えられないが、傷跡が残る。',
				'敵は逃げ腰になって武器を落とす(両手に武器を持っていたらランダムに決定)。',
				'敵は通常のダメージを受け、朦朧状態になる。',
				'敵は通常のダメージを受け、朦朧状態になる。',
				'敵は通常のダメージを受け、朦朧状態になる。',
				'敵は通常のダメージを受け、朦朧状態になる。',
				];
			result, number = get_table_by_nD6(table, 3);
		
		when "FMB"
			tableName = "ファンブル表";
			table = [
				'武器が壊れる。ただし、メイスなど固い"叩き"武器は壊れない(ふりなおし)。',
				'武器が壊れる。ただし、フレイルなど固い"叩き"武器は壊れない(ふりなおし)。',
				'自分の腕か足に命中(通常ダメージ)。ただし"刺し"武器や射撃ならふりなおし。',
				'自分の腕か足に命中(半分ダメージ)。ただし"刺し"武器や射撃ならふりなおし。',
				'バランスを失い、次ターンは行動不可。次ターンの行動の番まで、能動防御-2。',
				'使った武器が非準備状態になる。1ターンよぶんに準備行動を行わないと、準備状態にならない。',
				'武器を落とす。',
				'武器を落とす。',
				'武器を落とす。',
				'使った武器が非準備状態になる。1ターンよぶんに準備行動を行わないと、準備状態にならない。',
				'バランスを失い、次ターンは行動不可。次ターンの行動の番まで、能動防御-2。',
				'前か後ろ(ランダム)に武器が1メートル飛んでいく。その場にいるキャラクターは敏捷力判定を行い、失敗するとダメージ(通常の半分)を受ける。ただし、"刺し"武器や弓矢はその場に落ちるだけ。',
				'利き腕をくじいてしまう。30分間、攻撃にも防御にも使えない。',
				'足をすべらせ、その場に倒れる。',
				'武器が壊れる。ただし、モールなど固い"叩き"武器は壊れない(ふりなおし)。',
				'武器が壊れる。ただし、金属バットなど固い"叩き"武器は壊れない(ふりなおし)。',
				];
			result, number = get_table_by_nD6(table, 3);
		
		when "MFMB"
			tableName = "呪文ファンブル表";
			table = [
				'呪文が完全に失敗する。術者は1D点のダメージを受ける。',
				'呪文が術者にかかる。',
				'呪文が術者の仲間にかかる(対象はランダムに決定)。',
				'呪文が近くの敵にかかる(対象はランダムに決定)。',
				'哀れな物音があがり、硫黄のひどい匂いが立ち込める。',
				'呪文が目標以外のもの(仲間、敵、品物)にかかる。対象はランダムに決定するか、おもしろくなるようにGMが決定する。',
				'呪文が完全に失敗する。術者は1点のダメージを受ける。',
				'呪文が完全に失敗する。術者は朦朧状態になる(立ち直るには知力判定を行う)。',
				'大きな物音があがり、色とりどりの閃光が走る。',
				'見せ掛けの効果があらわれるが、弱くてとても役に立たない。',
				'意図した効果と逆の効果があらわれる。',
				'違った目標に、意図した効果とは逆の効果があらわれる(対象はランダムに決定)。',
				'何も起こらないが、術者は一時的にその呪文を忘れてしまう。思い出すまで、1週間ごとに知力判定を行う。',
				'呪文がかかったように思えるが、役に立たないただの見せかけだけ。',
				'呪文が完全に失敗し、術者の右腕が損なわれる。回復に1週間を要する。',
				'呪文が完全に失敗する。GMから見て、術者や呪文が純粋で善良なものでなければ、悪魔(第3版文庫版P.384参照)があらわれ、術者を攻撃する。',
				];
			result, number = get_table_by_nD6(table, 3);
			
		when "HIT"
			tableName = "命中部位表";
			table = [
				'脳',
				'脳',
				'頭',
				'遠い腕',
				'手首(左右ランダム)',
				'近い腕',
				'胴体',
				'胴体',
				'胴体',
				'遠い足',
				'近い足',
				'近い足',
				'足首(左右ランダム)',
				'足首(左右ランダム)',
				'重要機関(胴体の)',
				'武器',
				];
			result, number = get_table_by_nD6(table, 3);
		
		when /FEAR((\+)?\d+)?/
			modify = $1.to_i
      
			tableName = "恐怖表"
			table = [
				   '1ターン朦朧状態。2ターン目に自動回復。',
				   '1ターン朦朧状態。2ターン目に自動回復。',
				   '1ターン朦朧状態。以後、毎ターン不利な修正を無視した意志判定を行い、成功すると回復。',
				   '1ターン朦朧状態。以後、毎ターン不利な修正を無視した意志判定を行い、成功すると回復。',
				   '1ターン朦朧状態。以後、毎ターン通常の意志判定を行い、成功すると回復。',
				   '1ターン朦朧状態。以後、毎ターン通常の意志判定を行い、成功すると回復。',
				   '1Dターン朦朧状態。以後、毎ターン通常の意志判定を行い、成功すると回復。',
				   '2Dターン朦朧状態。以後、毎ターン通常の意志判定を行い、成功すると回復。',
				   '思考不能。15ターン朦朧状態。以後、毎ターン通常の意志判定を行い、成功すると回復。',
				   '新たな癖をひとつ植え付けられる。',
				   '1D点疲労。さらに1Dターン朦朧状態。以後、毎ターン通常の意志判定を行い、成功すると回復。',
				   '1D点疲労。さらに1Dターン朦朧状態。以後、毎ターン通常の意志判定を行い、成功すると回復。',
				   '新たな癖をひとつ獲得。さらに1Dターン朦朧状態。以後、毎ターン通常の意志判定を行い、成功すると回復。',
				   '1D分間意識を失う。以後、1分ごとに生命力判定を行い、成功すると回復。',
				   '生命力判定を行い、失敗すると1点の負傷を受ける。さらに1D分間意識を失う。以後、1分ごとに生命力判定を行い、成功すると回復。',
				   '1点負傷。2D分間意識を失う。以後、1分ごとに生命力判定を行い、成功すると回復。',
				   '卒倒。4D分間意識不明。1D点疲労。',
				   'パニック。1D分間のあいだ、叫びながら走り回ったり、座り込んで泣きわめいたりする。以後、1分ごとに知力判定(修正なし)を行い、成功すると回復。',
				   '-10CPの妄想を植え付けられる。',
				   '-10CPの軽い恐怖症を植え付けられる。',
				   '肉体的な変化。髪が真白になったり、老化したりする。-15CPぶんの肉体的特徴に等しい。',
				   'その恐怖に関連する軽い恐怖症を持っているならそれが強い恐怖症(CP2倍)になる。そうでなければ、-10CPぶんの精神的特徴を植え付けられる。',
				   '-10CPの妄想を植え付けられる。生命力判定を行い、失敗すると1点の負傷を受ける。さらに1D分間意識を失う。以後、1分ごとに生命力判定を行い、成功すると回復。',
				   '-10CPの軽い恐怖症を植え付けられる。生命力判定を行い、失敗すると1点の負傷を受ける。さらに1D分間意識を失う。以後、1分ごとに生命力判定を行い、成功すると回復。',
				   '浅い昏睡状態。30分ごとに生命力判定を行い、成功すると目覚める。目覚めてから6時間はあらゆる判定に-2の修正。',
				   '昏睡状態。1時間ごとに生命力判定を行い、成功すると目覚める。目覚めてから6時間はあらゆる判定に-2の修正。',
				   '硬直。1D日のあいだ身動きしない。その時点で生命力判定を行い、成功すると動けるようになる。失敗するとさらに1D日硬直。その間、適切な医学的処置を受けていないかぎり、初日に1点、2日目に2点、3日目に3点と生命力を失っていく。動けるようになってからも、硬直していたのと同じ日数だけ、あらゆる判定に-2の修正。',
				   '痙攣。1D分間地面に倒れて痙攣する。2D点疲労。また、生命力判定に失敗すると1D点負傷。これがファンブルなら生命力1点を永遠に失う。',
				   '発作。軽い心臓発作を起こし、地面に倒れる。2D点負傷。',
				   '大パニック。キャラクターは支離滅裂な行動に出る。GMが3Dを振り、目が大きければ大きいほど馬鹿げた行動を行う。その行動が終わったら知力判定を行い、成功すると我に返る。失敗すると新たな馬鹿げた行動をとる。',
				   '強い妄想(-15CP)を植え付けられる。',
				   '強い恐怖症、ないし-15CPぶんの精神的特徴を植え付けられる。',
				   '激しい肉体的変化。髪が真白になったり、老化したりする。-20CPぶんの肉体的特徴に等しい。',
				   '激しい肉体的変化。髪が真白になったり、老化したりする。-30CPぶんの肉体的特徴に等しい。',
				   '昏睡状態。1時間ごとに生命力判定を行い、成功すると目覚める。目覚めてから6時間はあらゆる判定に-2の修正。さらに強い妄想(-15CP)を植え付けられる。',
				   '昏睡状態。1時間ごとに生命力判定を行い、成功すると目覚める。目覚めてから6時間はあらゆる判定に-2の修正。さらに強い恐怖症、ないし-30CPぶんの精神的特徴を植え付けられる。',
				   '昏睡状態。1時間ごとに生命力判定を行い、成功すると目覚める。目覚めてから6時間はあらゆる判定に-2の修正。さらに強い恐怖症、ないし-30CPぶんの精神的特徴を植え付けられる。知力が1点永遠に低下する。あわせて精神系の技能、呪文、超能力のレベルも低下する。',
				  ]
      
		  dice, dummy = roll(3, 6)
		  number = dice + modify
		  if(number > 40)
			num = 36
		  else
			num = number - 4
		  end
		  result = table[num]
			
		when /REACT((\+|\-)?\d*)/
		  modify = $1.to_i
		  
		  tableName = "反応表"
		  dice, dummy = roll(3, 6)
		  number = dice + modify
		  
		  if(number < 1)
			result = "最悪"
		  elsif(number < 4)
			result = "とても悪い"
		  elsif(number < 7)
			result = "悪い"
		  elsif(number < 10)
			result = "良くない"
		  elsif(number < 13)
			result = "中立"
		  elsif(number < 16)
			result = "良い"
		  elsif(number < 19)
			result = "とても良い"
		  else
			result = "最高"
		  end
			
		when /TRAP(\w)/
			tableName = "トラップリスト";
			diff = $1;
			dif, table = getTrapTable(diff);
			if(table == nil)
				return ""
			end
			result, number = get_table_by_nD6(table, 3);
			result = "#{dif}：#{result}";
		
		when /TRS(E|N|H|L)(\d+)((\+|\-)?\d*)/
			tableName = "財宝テーブル";
			diff = $1;
			depth = $2.to_i;
			num = depth/10;
			if(num >= 6)
				num = 5;
			end
			case diff
				when "N"
					num += 1;
					
				when "H"
					num += 2;
					
				when "L"
					num += 3;
			end
			if($4 != nil)
				num += $3.to_i;
			end
			table = getTresureTable(num);
			if(table == nil)
				return ""
			end
			result, number = get_table_by_1d6(table);
			
		when /RAND(E|N|H|L)(\d)?/
			tableName = "ランダムイベント表";
			diff = $1;
			if($2 != nil)
				dice1 = $2.to_i;
			else
				dice1, dummy = roll(1, 6);
			end
			dice2, dummy = roll(1, 6);
			area, dif, table = getRandomEvent(dice1, dice2, diff);
			result, dice3 = get_table_by_1d6(table);
			number = "#{dice1}#{dice2}#{dice3}";
			result = "#{area}(#{dif})：#{result}";
			
		when /RENC(E|N|H|L)(\d)?/
			tableName = "ランダムエンカウント表";
			diff = $1;
			if($2 != nil)
				dice1 = $2.to_i;
			else
				dice1, dummy = roll(1, 6);
			end
			dice2 = 4;
			area, dif, table = getRandomEvent(dice1, dice2, diff);
			result, dice3 = get_table_by_1d6(table);
			number = "#{dice1}#{dice2}#{dice3}";
			result = "#{area}(#{dif})：#{result}";
			
		when "AREA"
			tableName = "地形決定表";
			table = [
				'洞窟
「ん、暗くて先が見えないって？そりゃこのフィルトウィズのことかい？」
姿を様々に変える洞窟。ケイヴウォーカーがいれば有利に探索可能。非常に暗く「暗視」がなければ満足に進むことはできないだろう。
☆深度判定：体力判定(「暗視」があれば深度判定に+3のボーナスを受ける)
☆屋内(飛行不可)
☆薄暗い(ストームコーザー「鳥目」を適用)',
				'遺跡
「どんな仕掛けにだって意味はある。人が作ったものだからな」
人為的に作られた様々な建造物の内部。
様々な恐ろしい仕掛けが行く手を阻む。
☆深度判定：<探索>
☆屋内(飛行不可)',
				'断崖
「うーん、とっても気持ちのいい風ね。ん？何を震えてるの？」
一歩踏み外せば奈落の底。過酷な自然の要塞。
ストームコーザーなどの飛行可能な仲間がいると心強いだろう。
☆深度判定：<軽業>
☆屋外',
				'水辺
「人間とは何かと不便なことが多い種族ですな」
川、湖などを泳いだりして進んでいくダンジョン。
リザードやワイズマンがその力を発揮するだろう。
☆深度判定：<水泳>
(水泳に「自動的に成功」するキャラクターは敏捷力+4で判定可能。
 《水泳》のかかっているキャラクターがいた場合も同様。
 【ミズグモ】があれば敏捷力+2で深度判定可能)
☆屋外 ',
				'森林
「ここが危険だと思う？それはアナタがこの森では『異質』だからよ」
鬱蒼とした森林は、人間にはとても過酷な環境となっている。
フラウなどの自然と共に生きる者の力が助けになるだろう。
☆深度判定：<生存>
☆屋外',
				'墓地
「客人とは珍しい・・・『死者の王』に出会わぬよう、ゆめゆめご注意を・・・」
死者どもの彷徨う、暗く冷たい墓地。
ローブをかぶった得体の知れない墓守を<追跡>して脱出せよ。
☆深度判定：<追跡>
☆屋外
☆薄暗い(ストームコーザー「鳥目」を適用)',
			];
			result, number = get_table_by_1d6(table);
			
		when /DROP(N)?((\+)?(\d))?/
			tableName = "ドロップ判定";
			mode = "S";
			text = "";
			modify = 0;
			
			if($1 != nil)
				mode = $1;
			end
			if($4 != nil)
				modify = $4.to_i;
			end
			
			dice, dummy = roll(3, 6);
			number = dice-modify;
			
			if(number <= 3)
				result = "レアアイテム1";

			elsif((number <= 4) && (mode == "N"))
				result = "レアアイテム2";
				
			elsif(number < 7)
				if(mode == "N")
					result = "CL×200GP";
					
				else
					result = "CL×100GP";
					
				end
				
			else
				if(mode == "N")
					result = "CL×20GP";
				
				else
					result = "CL×10GP";
				
				end
				
			end
			
		when "HST"
			tableName = "必殺技表";
			table = [
				'命中判定に[1,1,1]でクリティカル(クリティカル表も参照)。',
				'命中判定に+20のボーナス。',
				'ダメージを与えると「生命力-2」で気絶判定。',
				'ダメージを与えると「敏捷力-4」で転倒判定。',
				'致傷力+2D。',
				'命中判定に[6,6,6]でファンブル(ファンブル表も参照)。',
			];
			result, number = get_table_by_1d6(table);
			
		when "KHST"
			tableName = "驚異的必殺技表";
			table = [
				'命中判定に[1,1,1]でクリティカル。クリティカル表は参照せず、相手は即死。「分類：ネームド」「分類：魔将」に対しては最大HPの半分のダメージを与える。',
				'命中判定に[1,1,1]でクリティカル。クリティカル表は参照せず、致傷力3倍。',
				'命中判定に[1,1,1]でクリティカル。クリティカル表は参照せず、致傷力2倍。',
				'命中判定に[1,1,1]でクリティカル(クリティカル表も参照)。',
				'命中判定に+40のボーナス。',
				'致傷力+4D(火炎特性)。',
				'致傷力+3D(雷撃特性)。',
				'与えたダメージに等しいHPを回復する。回避に-3のペナルティを与える。',
				'1点でもダメージを与えた場合、対象を転倒状態にする。回避に-3のペナルティを与える。',
				'致傷力+3D。',
				'致傷力+4D(冷気特性)。',
				'1点でもダメージを与えた場合、-6のペナルティで気絶判定。',
				'致傷力+4D。防護点無視。',
				'致傷力+6D。回避に-3のペナルティを与える。',
				'命中判定に[6,6,5]でファンブル(ファンブル表も参照)。目標値が16以上だった場合は自動失敗。',
				'命中判定に[6,6,6]でファンブル(ファンブル表も参照)。',
			];
			result, number = get_table_by_nD6(table, 3);
			
		when "RANDOP"
			tableName = "迷宮追加オプション表"
			table = [
				'「宝物の迷宮」
財宝決定の際、1段階深度の高い財宝テーブルを使用する。',
				'「密林の迷宮」　初期深度+10
分類が「魔獣」「獣人」「霊獣」のモンスターは全ての判定に+2のボーナスを得る。',
				'「カラクリ技師の迷宮」
分類「ギア」のモンスターは全ての判定に+2のボーナスを得る。
クリア時に獲得できるAPが2倍になる。',
				'「フラウの舞踏会」
フラウが登場するランダムイベントが発生した際、
「この迷宮を制覇して、私達が舞踏会を開けるようにしてね」とお願いされ、
迷宮クリア時の獲得CPに+1のボーナスを得る。',
				'「アズマ風の迷宮」　初期深度+10
風流なアズマ風の迷宮。
アシガルファイター(CL4)、アンブッシュマン(CL5)、カラクリフラウ(CL6)、
ヤコ(CL6)、ヤシャ(CL10)、ヒトキリ(CL33)、シャドウストーカー(CL35)、
アシュラ(CL48)、コンゴウ(CL60)、カラクリヒメショーグン(CL75)が行う、
全ての判定に+2のボーナスを得る。',
				'「枯れた泉の迷宮」　初期深度+5
回復の泉が全て枯れており、回復効果を得ることができない。毒の泉はそのまま存在する。',

				'「天空への道」　初期深度+15
上へ上へと果てしなく昇っていく迷宮。空気が薄くなって疲労しやすくなる。
技などによるFPの最終的な消費と、FPに受ける最終的なダメージが2倍になる。',
				'「灼熱焦土の塔」　初期深度+10
とてつもなく熱く、気温が50度以上の塔。
「特性：火炎」の攻撃でPCが受ける最終的なダメージが2倍になる。',
				'「永久凍土の塔」　初期深度+10
とてつもなく寒く、気温が氷点下の塔。
「特性：冷気」の攻撃でPCが受ける最終的なダメージが2倍になる。
リザードやワイズマンなどの寒さに弱いキャラクターは動きが鈍り、あらゆる判定に-2のペナルティを受ける。',
				'「盗賊王の迷宮」　初期深度+10
<罠><鍵開け>に+3のペナルティを受ける。',
				'「ミミック狂暴化」
「全地形2-5」のミミックを見破る<罠>の判定に-3のペナルティを受け、
ミミックの致傷力も2倍になる。ミミックから獲得できるGPが3倍になる。',
				'「トレジャーイーター狂暴化」　初期深度+10
「全地形2-6」のトレジャーイーターを見破る<罠>の判定に-5のペナルティを受ける。',
				
				'「暗闇の迷宮」　初期深度+5
「暗視」がなければ視覚判定に-5のペナルティを受ける。
ストームコーザーはペナルティが2倍。',
				'「騒音の迷宮」　初期深度+5
「音量自動補正装置」がなければ聴覚判定に-5のペナルティを受ける。
シルヴァテイルはペナルティが2倍。',
				'「未知の怪物の迷宮」　初期深度+10
モンスターのデータが判明させられなくなる。
モンスター名は全て「謎の影」となる',
				'「氾濫中の迷宮」　初期深度+10
<水泳>に-5のペナルティを受ける。',
				'「間抜けの迷宮」　初期深度+15
あらゆる知力を基準とした判定（精神系技能含む）に-2のペナルティを受ける。',
				'「瘴気の迷宮」　初期深度+15
あらゆる生命力判定に-4のペナルティを受ける。',
				
				'「加速する迷宮」
1ラウンドで1日が経過する迷宮。技のCTやフラウの水分補給に影響する。
「CT:1日」までの技も次ターンで使用可能になっている。',
				'「停滞する迷宮」
敵味方双方が、「CT:次ターン」の技を使用すると最終イベントまで再使用不可。
また、「次ターンまで」有効な技は最終イベントまでずっと適用される。',
				'「猛毒の迷宮」　初期深度+20
最大HP、MP、FPに-5のペナルティを受ける。最低1点は残る。
中級:-10 上級:-15　悪夢:-20',
				'「死の迷宮」　初期深度+25
「保険」の効果が適用されない迷宮。',
				'「幸運の迷宮」
PC全員のフォーチュン最大値+1。',
				'「不運の迷宮」　初期深度+10
PC全員のフォーチュン最大値が半減する。',
				
				'「レアメタルの迷宮」
非常にレアなモンスター「レアメタルキャンディー」「レアメタルクラウン」が生息している迷宮。
キャンディークラウン(CL40)、ゴールデンクラウン(CL177)から
獲得できるAPが5倍になる。ただし、この2体の防護点は10になる。',
				'「魔力の泉」
PCとモンスターの双方が、MPを減少させずに魔法を使用できるようになる。
最大MPの足りていない魔法は使用できない。',
				'「青色の迷宮」　初期深度+10
PCは全員「内気3」の特徴を得る。
迷宮内で他のNPCに出会った際のイベントは全て無視する。',
				'「赤色の迷宮」　初期深度+10
PCは全員「直情」「自信過剰」の特徴を得る。「撤退」はできなくなる。',
				'「ピンクの迷宮」
PCは全員「好色」「平和愛好/専守防衛」の特徴を得る。「分類：魔族」とのエンカウントは無視する。',
				'「ハズレの迷宮」
財宝決定の際、1段階深度の低い財宝テーブルを使用する。',
				
				'「ラダマンティスの迷宮」　初期深度+20
「分類：岩石」のモンスターは全ての判定に+3のボーナスを得る。
また、「遺跡6-6」のイベントの致傷力が2倍になる。',
				'「グレイヴディガーの迷宮」　初期深度+20
「分類：アンデッド」のモンスターは全ての判定に+3のボーナスを得る。
また、「墓場」の深度判定に-5のペナルティを受ける。',
				'「ハイペリオンの迷宮」　初期深度+20
全てのモンスターがターンの最初にHPを5点ずつ回復する。
中級:10点　上級:20点　悪夢:30点。',
				'「ムスペルニブルの迷宮」　初期深度+20
「特性：火炎」「特性：冷気」の攻撃で、PCが受ける最終的なダメージが2倍になる。',
				'「  の迷宮」
何も起きない。第五魔将の封印が解除されている場合のみ、フォーチュン最大値+5。',
				'「バロールの迷宮」　初期深度+20
「分類：ギア」のモンスターは全ての判定とあらゆる攻撃の致傷力に+3のボーナスを得る。',
			]
			result, number = get_table_by_d66(table)
		
		when /LOT(N|P)/
			type = $1
			if(type == "P")
				tableName = "ナンバーワンプレミアムくじ"
			else
				tableName = "ナンバーワンノーマルくじ"
			end
			result = getLotResult(type)
			return "#{nick_e}: #{tableName}：#{result}"
			
		else
			return ""
	end
	
	text = "#{nick_e}: #{tableName}(#{number})：#{result}"
	
	return text
  end
  
  #GURPS-FW ナンバーワンくじ
  def getLotResult(type)
  
	#ノーマルくじ表1
	def normal1
		table = [
			'イレブンチキン',
			'イレブンチキン',
			'イレブンチキン',
			lambda{return "#{normal2}"},
			lambda{return "#{normal2}"},
			lambda{return "#{normal3}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#ノーマルくじ表2
	def normal2
		table = [
			'バロールたわし',
			'イグニスジッポ',
			'ヤコ仮面or梟の文鎮(選択可)',
			'ナレッジのハンモックorジンジャビースト',
			lambda{return "#{normal3}"},
			lambda{return "#{normal3}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#ノーマルくじ表3
	def normal3
		table = [
			'特性HPポーション',
			'特性MPポーション',
			'黒い甲冑',
			'天体望遠鏡',
			'金獅子の剥製',
			lambda{return "#{normal4}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#ノーマルくじ表4
	def normal4
		table = [
			'特性スタミナポーション',
			'戦乙女の兜',
			'フェンリルの首輪',
			'フェニックスカーペット',
			'動くアダマンゴーレム',
			lambda{return "#{normal5}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#ノーマルくじ表5
	def normal5
		table = [
			'キャンディークッション',
			'屑鉄の金床',
			'薪割り王の斧',
			'ロジエの水差し',
			'箱舟の模型',
			lambda{return "#{premium5}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	
	#プレミアムくじ表1
	def premium1
		table = [
			'プレミアムチキン',
			'プレミアムチキン',
			'プレミアムチキン',
			lambda{return "#{normal3}"},
			lambda{return "#{premium2}"},
			lambda{return "#{premium2}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#プレミアムくじ表2
	def premium2
		table = [
			'親衛隊バッジ',
			'ハタモトチャブダイ',
			'星のコンパス',
			'白銀の甲冑',
			lambda{return "#{normal4}"},
			lambda{return "#{premium3}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#プレミアムくじ表3
	def premium3
		table = [
			'特性クイックHPポーション',
			'特性クイックMPポーション',
			'特製クイックスタミナポーション',
			'火龍のフィギュアor氷龍のフィギュア(選択可)',
			'ヒメショーグンドレス',
			lambda{return "#{premium4}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#プレミアムくじ表4
	def premium4
		table = [
			'クイックユグドラポーション',
			'銀河龍のフィギュア/ドラゴン',
			'銀河龍のフィギュア/魔族',
			'魔族チェスセット',
			'イグニスコンロ',
			lambda{return "#{premium5}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#プレミアムくじ表5
	def premium5
		table = [
			'グレヴディバリウス',
			'天使の望遠鏡orデスの目覚まし時計(選択可)',
			'世界樹の蔦',
			'死神の飾りドレス',
			'ザバーニヤ等身大フィギュア',
			lambda{return "#{premium6}"},
		]
		result, = get_table_by_1d6(table)
		return result
	end
	#プレミアムくじ表6
	def premium6
		table = [
			'イレブンチキン',
			'イレブンチキン(2ピース)',
			'イレブンチキン(3ピース)',
			'イレブンチキン(6ピース)',
			'イレブンチキン(12ピース)',
			'wish star',
		]
		result, = get_table_by_1d6(table)
		return result
	end
	
	if(type == "P")
		return premium1
	else
		return normal1
	end
	
	return ""
  
  end
  
  #GURPS-FW 夢幻の迷宮財宝テーブル(ver.2013/05/03)
  def getTresureTable(num)
	case num
		#初級マイナス
		when -1
		table = [
			'HPポーション(消耗品)',
			'MPポーション(消耗品)',
			'スタミナポーション(消耗品)',
			'抵抗ポーション(消耗品)',
			'マジックパウダー：無(消耗品)',
			'200GP',
		];
		
		#初級0-9
		when 0
		table = [
			'高級HPポーション(消耗品)',
			'高級MPポーション(消耗品)',
			'高級スタミナポーション(消耗品)',
			'高級抵抗ポーション(消耗品)',
			'マジックパウダー：銀(消耗品)',
			'600GP',
		];
		
		#初級10-19
		when 1
		table = [
			'大地の守り(装飾品)',
			'ファインウェポンケース(装飾品)',
			'狩人の羽帽子(装飾品)',
			'狙撃手の指貫(装飾品)',
			'スタミナバンド・健康お守り・レザーマント3点セット(装飾品)',
			'1200GP',
		];
		
		#初級20-29
		when 2
		table = [
			'ミスリルダガーorミスリルシールドを選択(短剣or盾)',
			'高級クイック能力増加ポーション(消耗品)',
			'高級クイックHPポーション(消耗品)',
			'高級クイックMPポーション(消耗品)',
			'装飾品1つ(3000GPまでのもの)',
			'2000GP',
		];
		
		#初級30-39
		when 3
		table = [
			'ミスリル武器(4000GPまでのもの)',
			'最高級能力増加ポーション(消耗品)',
			'高級クイック再生ポーション(消耗品)',
			'魔法1つ(5000GPまでのもの)',
			'防具1つ(5000GPまでのもの)',
			'3000GP',
		];
		
		#初級40-49
		when 4
		table = [
			'オサフネorサスケブレードを選択(刀)',
			'アダマンダガー',
			'弓1つ(5000GPまでのもの)',
			'ギロチンブレード(両手剣)',
			'装飾品1つ(5000GPまでのもの)',
			'4500GP',
		];
		
		#初級50-
		when 5
		table = [
			'アダマン武器(8000GPまでのもの)',
			'アダマンシールド(盾)',
			'ミスリルスケイル',
			'蘇生ポーション',
			'装飾品1つ(10000GPまでのもの)',
			'6000GP',
		];
		
		#初級最高
		when 6
		table = [
			'武器1つ(612000GPまでのもの)',
			'盾1つ(12000GPまでのもの)',
			'鎧1つ(12000GPまでのもの)',
			'蘇生ポーション',
			'装飾品1つ(15000GPまでのもの)',
			'10000GP',
		];
		
		#中級最高
		when 7
		table = [
			'武器1つ(30000GPまでのもの)',
			'盾1つ(30000GPまでのもの)',
			'鎧1つ(30000GPまでのもの)',
			'蘇生ポーション+特製クイックHPポーション(特製は人数分)',
			'装飾品1つ(40000GPまでのもの)',
			'25000GP',
		];
		
		#上級最高
		when 8
		table = [
			'武器1つ(60000GPまでのもの)',
			'盾1つ(60000GPまでのもの)',
			'鎧1つ(60000GPまでのもの)',
			'蘇生ポーション+特製クイックポーション(特製は人数分、ＨＰ・ＭＰ・スタミナの３種)',
			'装飾品1つ(80000GPまでのもの)',
			'50000GP',
		];
		
		#悪夢最高
		when 9
		table = [
			'武器1つ(150000GPまでのもの)',
			'盾1つ(150000GPまでのもの)',
			'鎧1つ(150000GPまでのもの)',
			'クイック蘇生ポーション+特製クイックポーション(特製は人数分、ＨＰ・ＭＰ・スタミナの３種)',
			'装飾品1つ(200000GPまでのもの)',
			'黄金の守護者の証(装飾品)+黄金の電子暗号キー(装飾品)',
		];
		
		else
		table = nil;
	end
	
	return table
  end
  
  #トラップリスト(ver.2013/11/07)
  def getTrapTable(diff)
	case diff
		when "E" #初級
			dif = "初級";
			d = 0
			
		when "N" #中級
			dif = "中級";
			d = 1
			
		when "H" #上級
			dif = "上級";
			d= 2
		
		when "L" #悪夢
			dif = "悪夢";
			d = 3
			
		else
			dif = nil
			d = nil
			
	end
	
	table = [
		"トライディザスター:宝箱から広範囲に火炎・冷気・電撃が放たれる。PC全員に火炎により#{['3D', '4D', '5D', '7D'][d]}の「叩き」ダメージ、冷気により#{['3D', '4D', '5D', '7D'][d]}の「叩き」ダメージ、電撃により#{['2D', '3D', '4D', '6D']}の「叩き」ダメージを与える(電撃は金属鎧の防護点無視)",
		"ペトロブラスター：宝箱を開けたキャラクターに《肉を石》をかける。技能レベルは#{['20', '22', '24', '30'][d]}。",
		"クロスボウストーム：宝箱から矢の嵐が放たれる罠。PC全員に#{['2D', '3D', '5D', '8D'][d]}の「刺し」ダメージを与える。盾の受動防御を無視した「よけ#{['', '-2', '-4', '-8'][d]}」で回避が可能。",
		"フォーチュンイーター：PC全員の幸運を食らい、フォーチュンを#{['1', '2', '3', '5'][d]}減少させる。フォーチュンが0の場合#{['3D', '6D', '9D', '15D'][d]}の防護点無視ダメージを受ける。",
		"スロット：スロットが揃うまで開かない宝箱。スロットを1回まわすには#{['100', '300', '500', '1000'][d]}GPが必要。行動を消費して「視覚#{['-5', '-7', '-9', '-13'][d]}」判定に成功すればスロットはそろう。「反射神経」があれば「視覚」そのままで判定可能。",
		"テレポーター：宝箱の周囲に存在するPC全員(とエンカウントしているモンスター)をダンジョン入口方面に転送する。深度が#{['3D減少する', '4D減少する', '5D減少する', '0になる'][d]}。",
		"アイスコフィン：宝箱を開けようとしたキャラクターに冷気で#{['3D', '5D', '7D', '12D'][d]}の「叩き」ダメージを与え更に最終的なダメージの半分のFPダメージを与える。",
		"クロスボウ：宝箱を開けようとしたキャラクターに#{['2D', '3D', '5D', '8D'][d]}の「刺し」ダメージを与える。盾の受動防御を無視した「よけ#{['', '-2', '-4', '-8'][d]}」で回避が可能。",
		"毒針：宝箱を開けようとしたキャラクターに#{['1D', '2D', '3D', '6D'][d]}の「刺し」ダメージを与える。1点でもダメージを受けると「生命力#{['-4', '-5', '-6', '-8'][d]}」で判定を行い、失敗すると1日間すべての判定に-2のペナルティを受ける。盾の受動防御を無視した「よけ#{['', '-2', '-4', '-8'][d]}」で回避が可能。",
		"アラーム：即座にその地形のエンカウント表(イベント表4-1～4-6)を振る。",
		"殺人鬼の斧：宝箱を開けようとしたキャラクターに#{['3D', '4D', '6D', '10D'][d]}の「切り」ダメージを与える。命中部位は「ランダム部位命中表」を用いて決定すること。盾の受動防御を無視した「よけ#{['', '-2', '-4', '-8'][d]}」で回避が可能。",
		"死神：宝箱を開けようとしたキャラクターにネクロマンサーの呪術【憑物】+【死神】の効果を与える。3ラウンドすべての判定に#{['-1', '-2', '-3', '-4'][d]}のペナルティを受け、効果が切れると同時に#{['3D+3', '3D+6', '3D+9', '3D+15'][d]}の防護点無視ダメージを受ける。",
		"幻の宝：宝箱は二重底になっている。「知力#{['-5', '-7', '-9', '-13'][d]}」か<商人#{['', '-2', '-4', '-8'][d]}>の判定に失敗すると、重さ10kgの価値のない偽の宝物を入手してしまう。偽の宝物はシナリオ終了まで捨てることはできないが「トレジャーイーター」の罠にかかると消滅する。",
		"エクスプロージョン：宝箱が爆発し、PC全員に#{['4D', '6D', '9D', '15D'][d]}の「叩き」ダメージを与える。宝箱の中身は粉々になる。",
		"レインボーポイズン：宝箱から七色の毒ガスが放たれる。PC全員が「生命力#{['-4', '-5', '-6', '-8'][d]}」で判定を行い、失敗するとHP、MP、FPに#{['2D', '3D', '4D', '6D'][d]}の防護点無視ダメージを受ける。",
		"デスクラウド：宝箱から致死性の毒ガスが放たれる。PC全員が「生命力#{['-4', '-5', '-6', '-8'][d]}」で判定を行い、失敗したPCは即座に死亡する。",
	];
	return dif, table
  end
  
  #ランダムイベント表(ver.2013/11/07)
  def getRandomEvent(dice1, dice2, diff)
  
	case diff
		when "E"
			dif = "初級";
			d = 0
			
		when "N"
			dif = "中級";
			d = 1
		
		when "H"
			dif = "上級";
			d = 2
		
		when "L"
			dif = "悪夢";
			d = 3
			
		else
			dif = "";
			d = nil
	end
	
	case dice1
		when 1
			area = "洞窟"
			case dice2
				when 1
					table = [
						"回復の泉。PC全員のHP・MP・FPが完全に回復する。気絶・朦朧状態も回復。",
						"淡い光を放つ鉱石に包まれた部屋に出る。フォーチュンが#{getRandomDiff(dice1,12,d,0)}点回復する。",
						"天井が開いていて植物の育っている洞窟内庭園。#{getRandomDiff(dice1,13,d,0)}に成功すると力の沸く木の実を見つけHP・FP・MPを#{getRandomDiff(dice1,13,d,1)}点回復できる。",
						"洞窟内で栽培できる特殊なキノコを栽培するフラウに出会う。100GP支払うことでキノコを1つ譲ってもらうことができ、シナリオ終了まで《怪力2》《すばやさ2》《知恵2》《活力2》のいずれかの効果を得る(ランダム)このキノコは持ち帰ることはできず、2つめを食べても効果はない。",
						"ギア技術を用いた強力な懐中電灯のおいてある休憩室。迷宮を出るまで洞窟の深度判定で「暗視」があるものとして扱う。迷宮を出ると懐中電灯は寿命が来たのか壊れてしまう。",
						"不思議な光を放つ水が沸いている。パーティーメンバーのHP・MP・FPのいずれかが減少している場合このイベントは拒否できない。また、全快でも「好奇心」を持つキャラクターは知力判定に失敗すると飲みにいこうとする。飲んだキャラクターは1Dを振り、以下のような効果が発生する。ロールプレイが面白かった場合シナリオ終了時に1CPのボーナスを与えてもよい。
----------
1：HP・MP・FP全回復
2：シナリオ終了まで肉体的に不利な特徴が1つ消滅する
3：シナリオ終了まで精神的に不利な特徴が1つ消滅する
4：HP・MP・FPが現在地の半分になる　HPがマイナスの場合はHP・MP・FP全回復
5：シナリオ終了まで余分な獣っぽい耳や尻尾が生える　聴覚判定+4
6：シナリオ終了まで性別が男女入れ替わる。
----------",
					]
					
				when 2
					table = [
						"財宝(カギ・トラップなし)。財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギつき。行動を消費して#{getRandomDiff(dice1,22,d,0)}に成功すれば開く)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギなし、トラップつき。行動を消費して#{getRandomDiff(dice1,23,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギ、トラップつき。行動を消費して#{getRandomDiff(dice1,24,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"ミミックの罠。ランダムなキャラクターに3Dの「切り」ダメージを与える。#{getRandomDiff(dice1,25,d,0)}に成功すればこの罠を見抜いて無効化することができ、なおかつ「深度×#{getRandomDiff(dice1,25,d,1)}」GPを入手可能。",
						"トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。#{getRandomDiff(dice1,26,d,0)}に成功すればこの罠を見抜いて無効化することができる。",
					]
					
				when 3
					table = [
						"洞窟内で近道を発見。深度が1D+1増加する。",
						"洞窟内で近道を発見。深度が1D増加する。細い道のため、体の大きなキャラクター(STが13以上)は、通るのに苦労してFPを1点消耗する",
						"分かれ道。2分の1の確率で深度が1D増加する。「方向感覚」があれば必ず増加。",
						"足場の悪い近道。PTの誰かが#{getRandomDiff(dice1,34,d,0)}に成功すれば深度が1D増加する。失敗した場合は#{getRandomDiff(dice1,34,d,1)}の「叩き」ダメージを受ける",
						"大きな岩でふさがれた近道。1ラウンドで破壊することができれば深度が1D増加する。岩はどのヘクスからでも攻撃可能。分類：岩石、防護点8、#{getRandomDiff(dice1,35,d,0)}、切り刺しダメージボーナス無効。",
						"道が3つに分かれている。1Dで1、2が出るとペナルティなし、1Dで3、4が出ると深度-2、1Dで5、6が出ると深度-4。「直感」があれば、#{getRandomDiff(dice1,36,d,0)}の判定に成功すれば正しい道を選択可能。",
					]
					
				when 4
					table = [
						"#{getRandomDiff(dice1,41,d,0)}とエンカウント。2ラウンド経過するとキャンディークラウンは戦場全域に《べたべた》をかけて逃亡する。",
						"#{getRandomDiff(dice1,42,d,0)}彼らはお互いに争っているがPCたちを見つけると向きを変えて襲い掛かってくる。#{getRandomDiff(dice1,42,d,1)}",
						"#{getRandomDiff(dice1,43,d,0)}相手は洞窟では巧妙に擬態しており、【ハイドインシャドウ】状態とみなす。#{getRandomDiff(dice1,43,d,1)}",
						"#{getRandomDiff(dice1,44,d,0)}トロッコに乗って逃げつつの戦闘になり、2ラウンド以内に倒せなければ轢かれてPC全員が#{getRandomDiff(dice1,44,d,1)}の防護点無視ダメージを受ける。また、1ラウンドに1人誰かが体力判定を行ってトロッコを運転する必要があり、これに失敗すると即座に轢かれてしまう。轢かれると戦闘は終了する。パーテイー内にケイヴウォーカーがいればこの判定は不要。",
						"炎の燃え盛る洞窟。深度判定直前に炎で#{getRandomDiff(dice1,45,d,0)}の「叩き」ダメージを受ける。さらに#{getRandomDiff(dice1,45,d,1)}とエンカウント。火炎弱点のモンスターがいれば即座に逃亡する。",
						"冷気に包まれた洞窟。深度判定直前に冷気で#{getRandomDiff(dice1,46,d,0)}のFPダメージを受ける(防護点無視)さらに#{getRandomDiff(dice1,46,d,1)}とエンカウント。冷気弱点のモンスターがいれば即座に逃亡する。",
					]
					
				when 5
					table = [
						"落盤がモンスターを押しつぶす。戦闘中の場合ランダムなモンスター1人を即死させる。APやドロップ品も入手可能。それ以外の場合は特に何も起きない。",
						"採掘用のダイナマイトが打ち捨てられている。行動ターンを消費して使用することで任意の半径#{getRandomDiff(dice1,52,d,0)}の敵味方全員に#{getRandomDiff(dice1,52,d,1)}の「叩き」ダメージを与える。命中判定は自動的に0成功とし、《爆裂火球》と同様にダメージの軽減が可能。",
						"有毒ガスが発生している。分類「ギア」「アンデッド」以外のキャラクターは敵味方全員#{getRandomDiff(dice1,53,d,0)}で判定を行い、失敗度分のダメージを受ける。《空気浄化》などがあれば使用することで無効化できる。",
						"溶岩の流れる部屋。深度判定直前に炎で#{getRandomDiff(dice1,54,d,0)}の「叩き」ダメージを受ける。深度判定を行い、失敗したキャラクターはさらに追加で#{getRandomDiff(dice1,54,d,0)}の「叩き」ダメージを受ける。",
						"落盤がPCのうちランダムに1人を押しつぶす。受動防御無視の#{getRandomDiff(dice1,55,d,0)}に失敗すると#{getRandomDiff(dice1,55,d,1)}の「叩き」ダメージを受ける。パーティーの誰かが「第六感」か「視覚-5」の判定に成功すれば事前に回避可能。(「暗視」があれば「視覚-2」でも判定可能)",
						"進んできた道の後方が急に崩落する。ダンジョン攻略が完了するまで「撤退」ができなくなるが、「深度」が現時点より下がることがなくなる。",
					]
				
				when 6
					table = [
						"プラネタリウムのように鉱石が輝く部屋。星の配置に関する謎かけになっている。行動を消費して#{getRandomDiff(dice1,61,d,0)}に成功すればこの謎を解くことができる。謎が解けると#{getRandomDiff(dice1,61,d,1)}が入手できる。",
						"地熱で温泉が湧いている。このイベントが発生するとモンスターは消滅する。みんなで温泉に浸かることでFPが全回復する。また、温泉の薬効により受けていた毒は無効化され、ラウンドの最初にHPが#{getRandomDiff(dice1,62,d,0)}点ずつ回復するようになる。",
						"地下渓流を発見する。深度判定が体力判定ではなく<水泳>判定になる。深度判定に#{getRandomDiff(dice1,63,d,0)}成功以上した場合は地底湖に沈む財宝を発見可能。財宝にカギやトラップはなく、中身は深度そのままの財宝テーブルを使用する。",
						"アダマン鉱脈を発見する。「<採掘>の成功度×深度×#{getRandomDiff(dice1,64,d,0)}」GP分のアダマン鉱石を入手可能。複数人数で判定を行えばその回数分入手可能。ただし50GP分ごとに重量が1kg。撤退・全滅した場合アダマン鉱石は消滅する。",
						"強烈な磁力を放つ鉱石のある部屋。金属製の防具は重量を2倍に計算する。続いてエンカウント表(4-1～4-6)を振ること。なお、4-5の部屋の炎と4-6の部屋の冷気による効果は適用しない。",
						"怪しい光を放つ鉱石の部屋。鉱石は無生物を破壊する振動を放っており、武器に#{getRandomDiff(dice1,66,d,0)}の効果を与える。また、種族「ギア」のキャラクターも同様の効果を受ける。ラウンド終了前に鉱石を破壊すればこの効果は受けない。鉱石はどのヘクスからでも攻撃可能。分類：岩石、防護点8、HP#{getRandomDiff(dice1,66,d,1)}、切り刺しダメージボーナス無効。",
					]
					
				else
					table = nil
			end
		
		when 2
			area = "遺跡"
			case dice2
				when 1
					table = [
						"回復の泉。PC全員のHP・MP・FPが完全に回復する。気絶・朦朧状態も回復。",
						"随分進んだし一休みしよう。深度が奇数の場合はFPが#{getRandomDiff(dice1,12,d,0)}回復。深度が偶数の場合は進んだように見せかけて迷っているだけだった。深度が1D減少する。",
						"どうやらここは古代の医務室らしい。#{getRandomDiff(dice1,13,d,0)}に成功すればPC全員のHP・MP・FPが完全に回復する。気絶・朦朧状態も回復。",
						"「道標のヒカリゴケ」を栽培しているフラウに出会う。300GPを払うと、以後の深度増加判定に+1のボーナスを得る。",
						"ダンジョンの見取り図を書いた部屋に出る。次のランダムイベントでは、好きな地形を選択してからイベント表を振ることができる。次が最終イベントだった場合、ラウンド終了時の深度判定に+2のボーナスを得る。",
						"「パワーアップ装置！」と書かれた怪しげな機械が置いてある。#{getRandomDiff(dice1,16,d,0)}を支払って使用するとキャラクターを強化(？)可能。使用するかは自由だが、「好奇心」を持つキャラクターは知力判定に失敗すると使用する。使用したキャラクターは1Dを振り、以下のような効果が発生する。
	----------
	1：能力値が1点上昇する。上がる能力値はランダムで1つ。CP総計はそれに応じて増加する
	2：お肌がピチピチになり、容貌が1段階上昇する。「超美形」の場合さらに反応が男女とも+1(+5CP)
	3：習得している技1つを選択して強化する。ソーサルギアは#{getRandomDiff(dice1,16,d,1)}までの魔法を1つ習得する
	4：装置は突然大爆発を起こす！#{getRandomDiff(dice1,16,d,2)}の「叩き」ダメージを受ける
	5：「鋭敏感覚1」が身につく。すでに「鋭敏感覚」がある場合そのレベルが上昇する
	6：能力値が1点下降する。下がる能力値はランダムで1つ。CP総計はそれに応じて減少する
	----------",
					]
					
				when 2
					table = [
						"財宝(カギ・トラップなし)。財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギつき。行動を消費して#{getRandomDiff(dice1,22,d,0)}に成功すれば開く)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギなし、トラップつき。行動を消費して#{getRandomDiff(dice1,23,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギ、トラップつき。行動を消費して#{getRandomDiff(dice1,24,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"ミミックの罠。ランダムなキャラクターに3Dの「切り」ダメージを与える。#{getRandomDiff(dice1,25,d,0)}に成功すればこの罠を見抜いて無効化することができ、なおかつ「深度×#{getRandomDiff(dice1,25,d,1)}」GPを入手可能。",
						"トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。#{getRandomDiff(dice1,26,d,0)}に成功すればこの罠を見抜いて無効化することができる。",
					]
					
				when 3
					table = [
						"鏡に映る怪人が自分の真似をしろとジェスチャーしている#{getRandomDiff(dice1,31,d,0)}のいずれかに成功すると鏡が消滅して隠し通路が開かれ、深度が2D増加する。",
						"小さな魔将の像がフィルトウィズの地図の上で乱雑に置かれている。#{getRandomDiff(dice1,32,d,0)}で判定を行い、魔将の所在地を正しく配置すると隠し通路が開かれ、深度が2D増加する。",
						"シュートの罠に引っかかるが、結果的に新たな道を発見する。深度が2D増加するが、PC全員が増加した深度#{getRandomDiff(dice1,33,d,0)}「叩き」ダメージを受ける。<軽業>で判定を行い、その成功度分ダメージを軽減可能。",
						"ラダマンティス崇拝者が作り出した、巨大な甲羅のようなものが置かれた部屋。登っていけば近道することができそうだ。#{getRandomDiff(dice1,34,d,0)}に成功すれば深度が1D増加する。",
						"後ろから重い物が転がってくる音がする。ローリングストーンだ！#{getRandomDiff(dice1,35,d,0)}で判定を行い、失敗したPCは#{getRandomDiff(dice1,35,d,1)}の「叩き」ダメージを受ける。全員成功だった場合のみ深度が2D増加する。",
						"通路が入り組んでおり道に迷いそうだ。#{getRandomDiff(dice1,36,d,0)}の判定に失敗すると深度が2D減少する。「方向感覚」があればこの影響は受けない。",
					]
					
				when 4
					table = [
						"#{getRandomDiff(dice1,41,d,0)}とエンカウント。2ラウンド経過するとキャンディークラウンは戦場全域に《べたべた》をかけて逃亡する。",
						"石像が並ぶ通路がある。1Dを振って1・2・3なら#{getRandomDiff(dice1,42,d,0)}。1Dを振って4・5・6・の場合ガーゴイルに似ている、ただの石像。<モンスター知識-5>か「第六感」の判定に成功していなければ必ず相手の先制攻撃になり、その際PC先手で進行中の場合もモンスター先手に変更される。#{getRandomDiff(dice1,42,d,1)}",
						"障害物に隠れて#{getRandomDiff(dice1,43,d,0)}が狙撃してくる。モンスターのすぐ傍には合計5ヘクスの障害物(防護点5、HP35。形はGMが任意に決定する)がある。障害物ごしに攻撃するには射撃武器でなくてはならず、射撃武器も命中に-2のペナルティを受ける。",
						"ブツゼンにモンスターが仁王立ちをしており、問答を行ってくる。#{getRandomDiff(dice1,44,d,0)}に成功すると戦闘を回避することができ、APとドロップ品も入手可能。失敗するか戦闘を望んだ場合#{getRandomDiff(dice1,44,d,1)}とエンカウントする。",
						"進路上に鎖に繋がれたモンスターを発見する。迂回して戦闘を避けるなら深度1D減少し、戦闘して倒すと深度が1D増加する。戦闘を行う場合#{getRandomDiff(dice1,45,d,0)}とエンカウントする。",
						"暴れゴーレムが襲いかかってくる！《倍速》の魔法がかかった#{getRandomDiff(dice1,46,d,0)}とエンカウントする。このゴーレムは暴走の負荷によりターンの最初にHPが#{getRandomDiff(dice1,46,d,1)}減少する。",
					]
				
				when 5
					table = [
						"毒矢が飛んでくる。#{getRandomDiff(dice1,51,d,0)}に失敗すると#{getRandomDiff(dice1,51,d,1)}の「刺し」ダメージを受け、1点でもダメージを受けた場合#{getRandomDiff(dice1,51,d,2)}判定を行い失敗すると以後ターンの最初に#{getRandomDiff(dice1,51,d,3)}の防護点無視ダメージを受ける。",
						"毒霧が部屋に散布される。#{getRandomDiff(dice1,52,d,0)}で判定を行い、失敗すると《解毒》などを使用しない限り以後の判定全てに-2のペナルティを受ける。《空気浄化》があれば防御タイミングで使用して打ち消すことができる。",
						"フロアイミテーターだ！この部屋自体が魔物である。ロックバトラー(#{getRandomDiff(dice1,53,d,0)})とエンカウントする。このモンスターがいる限り移動はできず、ラウンドごとの地形変化や深度増加も行わない。PCとフロアイミテーターは常に隣接しているものとして扱う。",
						"どうやら休憩室のようだ、ふわふわのベッドもある。#{getRandomDiff(dice1,54,d,0)}判定に失敗すると転倒状態になり、ダメージを受けるか行動を消費して起こしてもらうまで行動不能。全員失敗した場合、君たちの冒険はここまでだ。せめていい夢を見れるといいだろう(保険は適用可能)",
						"ラダマンティスの蛇の像と目が合う。どうやらダンジョンの監視者に見つかってしまったらしい！以後モンスターとエンカウントする場合、その数が2倍となる(この効果は累積する)なお、ネームドもしくは魔将の数は変化しない。",
						"怪しげな卵が1つ置かれている。GMは#{getRandomDiff(dice1,56,d,0)}の中から好きなものを1体選びエンカウントさせることができる。深度が0の場合、卵の中から1段階高い財宝テーブルのアイテムが手に入る。",
					]
				
				when 6
					table = [
						"突如持っていた灯が消えて真っ暗になってしまう。暗闇を見通せる手段(特徴「暗視」、魔法《持続光》、遺跡1-4のヒカリゴケなど)がない限り、PCはこのラウンド中の敏捷力に-4のペナルティを受ける。(ストームコーザーは-8)",
						"どうやら過去の訓練施設のようだ。「パンチングマシーン」と書かれたものがあり、100GP払って挑戦可能。武器を外した状態での「叩き」ダメージを求め、値が大きいと景品が入手可能。1回挑戦すると、ガタがきていたのか壊れてしまう。＜格闘＞＜猫格闘＞＜空手＞の技を使用しても構わない。
	---------
	ダメージが#{getRandomDiff(dice1,62,d,0)}以上：2D×50GP
	ダメージが#{getRandomDiff(dice1,62,d,1)}以上：深度が1段階低い財宝テーブル
	ダメージが#{getRandomDiff(dice1,62,d,2)}以上：深度が1段階高い財宝テーブル
	---------",
						"謎の装置のせいで気になるあの子と体が入れ替わってしまった！？シナリオ終了までPCのうち2人の体が入れ替わってしまい、精神的な特徴と癖が入れ替わってしまう。なぜか知力や技能はそのまま。プレイヤーは入れ替わった相手の性格を演じること。入れ替わる2人はランダムに決定するか面白くなるようにGMが選ぶ。展開が面白かった場合、GMはシナリオクリア時のCPを1点追加しても良い。",
						"古代のテクノロジーを使用した医療施設だ。このイベントが発生するとモンスターは消滅する。#{getRandomDiff(dice1,64,d,0)}に成功すると全員のHP・FP・MPと転倒以外の状態異常を全回復できる。また、シナリオ終了まで不利な肉体的・精神的な特徴を無効化できる。",
						"キャンディークラウンハウスだ！キャンディークラウン(CL40)×1D#{getRandomDiff(dice1,65,d,0)}とエンカウントする。もし1体も倒せなかった場合、1体も倒せずチャンスをものにできなかった悔しさからFPに出てきたキャンディークラウンの数Dのダメージを受ける(軽減不可)",
						"なぜここに呼ばれたかおわかりになりますでしょうか？ラダマンティス崇拝者の作り出した審判の部屋。<地域知識/フィルトウィズ全域-3>に成功すると罰を与える部屋だとわかり、部屋の中央のラダマンティス像を攻撃できるようになる。像はどのヘクスからでも攻撃可能。分類：岩石、防護点8、HP#{getRandomDiff(dice1,66,d,0)}、切り刺しダメージボーナスなし。2ラウンド以内に破壊すれば現在の深度に等しいAPを入手可能。破壊できなかった場合像から裁きの光が放たれ、PC全員が「#{getRandomDiff(dice1,66,d,1)}」点の防護点無視ダメージを受ける。",
					]
				
				else
					table = nil
			end
						
		when 3
			area = "断崖"
			case dice2
				when 1
					table = [
						"回復の泉。PC全員のHP・MP・FPが完全に回復する。気絶・朦朧状態も回復。",
						"休憩に丁度いい広場を見つけた。FPが2D回復するが、#{getRandomDiff(dice1,12,d,0)}判定を行うこと。PCの半数以上が失敗すると居心地が良すぎて離れづらくなり次の深度判定と地形変化が起きなくなる。その場合次もこのイベントを行うこと。",
						"山小屋を発見し一休み。HPとFPが#{getRandomDiff(dice1,13,d,0)}回復する。4人で休んでいる場合暇つぶしに山小屋の四隅をぐるぐるまわって運動し始めるが、後から妙なことに気が付きMPが1D減少する。",
						"キイチゴを栽培しているフラウに出会う。栄養満点。50GP払うことでFPとMPを#{getRandomDiff(dice1,14,d,0)}回復することができる(1人1回)",
						"少し休憩できそうな洞窟を発見する。中には他のエクスプローラーが残していったと思われる道具もあった。#{getRandomDiff(dice1,15,d,0)}GPまでの好きな消耗品1つを入手して、大雨が降っていればそれも止む。",
						"回復の泉。しかし山間の貴重な水源のため、亜人によって管理されており使用させてもらうには#{getRandomDiff(dice1,16,d,0)}GPが必要。パーティーに管理している亜人と同じ種族がいれば無料で使用可能。使用するとPC全員のHP・MP・FPが完全に回復する。気絶・朦朧状態も回復。どの種族が管理しているかは1Dを振って決定する。
----------
1：ドラコニアン
2：リザードとワイズマン
3：フラウ
4：シルヴァテイル
5：ストームコーザー
6：グラント
----------",
					]
					
				when 2
					table = [
						"財宝(カギ・トラップなし)。財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギつき。行動を消費して#{getRandomDiff(dice1,22,d,0)}に成功すれば開く)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギなし、トラップつき。行動を消費して#{getRandomDiff(dice1,23,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギ、トラップつき。行動を消費して#{getRandomDiff(dice1,24,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"ミミックの罠。ランダムなキャラクターに3Dの「切り」ダメージを与える。#{getRandomDiff(dice1,25,d,0)}に成功すればこの罠を見抜いて無効化することができ、なおかつ「深度×#{getRandomDiff(dice1,25,d,1)}」GPを入手可能。",
						"トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。#{getRandomDiff(dice1,26,d,0)}に成功すればこの罠を見抜いて無効化することができる。",
					]
				
				when 3
					table = [
						"ショートカットコースを発見。#{getRandomDiff(dice1,31,d,0)}に成功すると深度が2D増加する。",
						"鉱物を運んでいたのであろう、運搬用トロッコのレールを発見する。深度が1D増加する。ケイブウォーカーがいる場合#{getRandomDiff(dice1,32,d,0)}で判定を行い、更にその成功度分深度が増加する。",
						"険しい斜面が続く。#{getRandomDiff(dice1,33,d,0)}に失敗すると道の選択を誤り深度が1D、FPが1点減少する。",
						"空を飛べればショートカットできそうな崖を発見する。なんらかの飛行手段のあるPCがいる場合深度が2D増加する。(魔法などの場合その分のMPを消費すること。1人分でよい)飛行手段がなければ遠回りになり、深度が1D減少する。",
						"遠くから山彦のような不思議な声が聞こえる。#{getRandomDiff(dice1,35,d,0)}に成功すると何者かが迷いやすい道を注意してくれているのがわかる。判定に失敗した場合、深度が1D減少する。",
						"急に突風が吹いてきた！全員で#{getRandomDiff(dice1,36,d,0)}判定を行うこと。失敗したキャラクターは急斜面を落下して3Dの「叩き」ダメージを受ける。また、「失敗したPCの人数×1D」の深度が減少する。",
					]
				
				when 4
					table = [
						"#{getRandomDiff(dice1,41,d,0)}とエンカウント。2ラウンド経過するとキャンディークラウンは戦場全域に《べたべた》をかけて逃亡する。",
						"あれはストームコーザー？・・・いや、魔物だ！#{getRandomDiff(dice1,42,d,0)}。うまく地形を利用して幻惑してくるため、この敵からの回避には-2のペナルティを受ける。",
						"登山訓練中の魔族の小隊と出くわす。相手は疲れているようだ？#{getRandomDiff(dice1,43,d,0)}とエンカウント。FPは最大値の半分まで減少している。",
						"突然魔族が飛びかかってきた！#{getRandomDiff(dice1,44,d,0)}。体の一部が宝石でできており、普通の#{getRandomDiff(dice1,44,d,1)}とは異なるようだ。撃破時に入手できるAPが2倍で、ドロップ判定のダイスが良い方に1点修正される。#{getRandomDiff(dice1,44,d,2)}",
						"ケタケタ笑いながら空から襲撃をされる。#{getRandomDiff(dice1,45,d,0)}。彼女達はとても飽きっぽいので2ラウンド行動したあと深度判定の際に立ち去ってしまう(APとドロップは入手できない)#{getRandomDiff(dice1,45,d,1)}",
						"#{getRandomDiff(dice1,46,d,0)}の縄張りに足を踏み入れる#{getRandomDiff(dice1,46,d,1)}。引き返して一度縄張りを離れるなら深度が2D減少する。そのまま進むのであればPC全員で反応判定を行うこと。(反応修正は容貌も含め全て適用。同性とみなす)1人でも「良い」以上の反応であれば見逃してもらえる。全員が「普通」以下の場合は戦闘になる。",
					]
				
				when 5
					table = [
						"ジャーンジャーン！げぇ、落石だ！！魔族がここぞとばかりに岩を落とし始める。#{getRandomDiff(dice1,51,d,0)}の判定に失敗したPCは#{getRandomDiff(dice1,51,d,1)}の「叩き」ダメージを受ける。「第六感」に事前に成功していれば全員が回避可能。",
						"ファイトー！いっぱーつ！！足場が崩れ出す。#{getRandomDiff(dice1,52,d,0)}に失敗したPCは落下して#{getRandomDiff(dice1,52,d,1)}の「叩き」ダメージを受ける。成功したPCは体力判定を行い、落下するキャラを支えることができる。この判定に失敗した場合支えようとしたキャラクターも一緒にダメージを受ける。",
						"滑りやすい岩を飛び移っていく道が続いている。敵味方全員が#{getRandomDiff(dice1,53,d,0)}判定を行い、失敗したキャラクターは転倒してFPに1点のダメージを受ける。浮遊・飛行して移動しているキャラクターはこの影響を受けない。#{getRandomDiff(dice1,53,d,1)}",
						"『銀糸の甲殻』アルゲントゥムの巣が張られている。幸い主はいないようだ・・・？1Dを振って3以下だった敵味方全員はソーサルギアの《べたべた》の効果を受ける。#{getRandomDiff(dice1,54,d,0)}",
						"美しい万年雪の中を進んでいたと思ったのも束の間、雪崩に遭遇してしまう！#{getRandomDiff(dice1,55,d,0)}か「第六感」に誰かが成功すれば回避可能。失敗すると敵味方全員が#{getRandomDiff(dice1,55,d,1)}の防護点無視ダメージ、その半分のFPダメージを受ける。",
						"下から魔族が大量に登ってくる、今のうちに撃退しなくては。魔族の群れは「分類：魔族、#{getRandomDiff(dice1,56,d,0)}、ダメージボーナス有効」とみなし、どのヘクスからも攻撃可能。ラウンド終了後の深度判定時に、PC全員が「残りHP÷2」の防護点無視ダメージを受ける。シナリオ終了時に「与えたダメージ合計÷2」に等しいAPを得ることができる。",
					]
					
				when 6
					table = [
						"急に大雨が降り出した、屋外に避難したいところだが・・・地形が「洞窟」か「遺跡」に変更されるまで深度判定の成功度に#{getRandomDiff(dice1,61,d,0)}のペナルティを受ける。",
						"カラーストーンの原石を見つける。行動ターンを消費して<採掘>か<技師/魔道具ー5>の判定を行い、「成功度×#{getRandomDiff(dice1,62,d,0)}GP」を入手することができる。クリティカル時は成功度を3倍に計算する。",
						"不思議な岩がある。1Dを振って1・2であれば火炎、3・4であれば冷気、5・6であれば電撃特性の攻撃で破壊可能。#{getRandomDiff(dice1,63,d,0)}行動ターンを消費して岩を狙うと宣言すればよい。岩は全てのヘクスから攻撃可能で、破壊したあとには財宝が発見できる。財宝の中身は現在の深度に応じた財宝テーブルを使用する。",
						"ストームコーザーが獲物を取った後調理をしている。このイベントが発生するとモンスターは消滅する。「こんなところで人間に会うなんて珍しいな、お前らも食っていくか？」10GPを支払うことでマジカルクッキング#{getRandomDiff(dice1,64,d,0)}の効果を得ることができる。",
						"高山植物の群生地。#{getRandomDiff(dice1,65,d,0)}のいずれかで判定を行う。成功した場合、「深度×#{getRandomDiff(dice1,65,d,1)}」GP相当の薬草が入手可能。",
						"岩壁が大きく崩れる！崩落に巻き込まれ深度が0になってしまう。#{getRandomDiff(dice1,66,d,0)}に成功すると何やら崩れたあとに鈍く輝く武器を発見する。武器、盾、鎧の中から好きなもの1つを入手することができる(#{getRandomDiff(dice1,66,d,1)}GPまで)",
					]
				
				else
					table = nil
			end
			
		when 4
			area = "水辺"
			case dice2
				when 1
					table = [
						"回復の泉。PC全員のHP・MP・FPが完全に回復する。気絶・朦朧状態も回復。",
						"甲羅干しに適した暖かい小島を見つける。FPとMPを#{getRandomDiff(dice1,12,d,0)}回復。ワイズマンは回復量2倍。",
						"魚の群れを発見する。行動を消費して<釣り>に成功すると、さらに行動ターンで<調理>判定を行うことでジャンル「魚」のマジカルクッキングを行うことができる。<釣り>と<調理>を行うキャラクターは別々でも構わない。できた料理の効果はその場で適用する。",
						"ミントや菖蒲を育てているフラウに出会う。100GP払うと薬湯に入れてもらうことができる。FPとMPが生命力と同じ値だけ回復する。",
						"リザードの集落につく。HPの減ったキャラクターがいれば持て囃され、マジカルクッキング「カリカリミミズ肉」をごちそうしてもらい、この先の道案内も買って出てくれる。そのラウンドの深度判定に+3のボーナスを得る。全員のHPが満タンの場合は、そっけない扱いをされ何も起こらない。",
						"回復の泉に見せかけた毒の泉。パーティーメンバーのHP・MP・FPのいずれかが減少している場合このイベントは拒否できない。毒の水でHP・MP・FPに#{getRandomDiff(dice1,16,d,0)}のダメージを受ける。HP・MP・FPが全快のキャラクターはこの効果を受けない。#{getRandomDiff(dice1,16,d,1)}か「第六感」に成功すればこれが毒の泉だとわかる。",
					]
				
				when 2
					table = [
						"財宝(カギ・トラップなし)。財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギつき。行動を消費して#{getRandomDiff(dice1,22,d,0)}に成功すれば開く)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギなし、トラップつき。行動を消費して#{getRandomDiff(dice1,23,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギ、トラップつき。行動を消費して#{getRandomDiff(dice1,24,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"ミミックの罠。ランダムなキャラクターに3Dの「切り」ダメージを与える。#{getRandomDiff(dice1,25,d,0)}に成功すればこの罠を見抜いて無効化することができ、なおかつ「深度×#{getRandomDiff(dice1,25,d,1)}」GPを入手可能。",
						"トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。#{getRandomDiff(dice1,26,d,0)}に成功すればこの罠を見抜いて無効化することができる。",
					]
				
				when 3
					table = [
						"進みやすい浅瀬だ。深度が1D増加する。#{getRandomDiff(dice1,31,d,0)}に成功すればちょうどいいイカダを組み、深度が2D増加。",
						"様々な漂流物が流れ込む船の墓場。障害物が多く進みにくい。#{getRandomDiff(dice1,32,d,0)}の判定に成功すれば深度が1D増加。失敗した場合深度が1D減少する。",
						"大蓮のような植物の群生地。荷重レベルが「軽荷」以下のキャラクターがいる場合安全に移動できるようになり深度が1D増加する。全員「並荷」以上の場合は大蓮が絡まり深度が1D減少する。",
						"周囲に深い霧が発生する。#{getRandomDiff(dice1,34,d,0)}の判定に失敗すると深度が1D減少する。「暗視」があれば「視覚-2」で判定可能。「方向感覚」があればまったく影響を受けない。",
						"沼地で思うように進めない。#{getRandomDiff(dice1,35,d,0)}で判定を行い、失敗すると深度が1D減少する。ペット「スワンプランナー」を装備している場合と【ミズグモ】がある場合はまったく影響を受けない。",
						"水流が複雑になっており思うように進めず戻されてしまう。#{getRandomDiff(dice1,36,d,0)}の判定に失敗すると深度が2D減少する。リザードかワイズマンは知力そのままで判定してもよい。",
					]
				
				when 4
					table = [
						"#{getRandomDiff(dice1,41,d,0)}とエンカウント。2ラウンド経過するとキャンディークラウンは戦場全域に《べたべた》をかけて逃亡する。",
						"アシガル潜水隊と遭遇。#{getRandomDiff(dice1,42,d,0)}とエンカウント。<偽装>か「視覚-3」判定に成功すると水面に動く竹筒を発見可能。最初の判定に成功していればPC側のイニシアチブ値+1、失敗していれば敵の先手で戦闘を開始する。その際PC先手で進行中の場合もモンスター先手に変更される。",
						"何か水面が揺れている。#{getRandomDiff(dice1,43,d,0)}。敵は全員【ハイドインシャドウ】状態。#{getRandomDiff(dice1,43,d,1)}判定に失敗すると敵の先手で戦闘を開始する。その際PC先手で進行中の場合もモンスター先手に変更される。",
						"水辺で花を育てている少女に出会う・・・が、少女は#{getRandomDiff(dice1,44,d,0)}だった！彼女が育てている花の根本には無数の動物の死体が無残にも肥料にされている。遭遇したラウンドのイニシアチブ判定直後に恐怖判定を行うこと。",
						"水かと思ったらスライムだった！？#{getRandomDiff(dice1,45,d,0)}。相手側のイニシアチブ判定には+3のボーナスがある。",
						"高波にのった騎士が現れる。#{getRandomDiff(dice1,46,d,0)}。最初の攻撃に限り、【チャージアタック】時に追加で5ヘクス移動した扱いになる。",
					]
				
				when 5
					table = [	
						"美しい歌声が響き渡る、意識が引きずり込まれそうだ。その場にいる全員(敵も)は#{getRandomDiff(dice1,51,d,0)}判定を行う。音量自動補正装置がある場合この効果を受けない。失敗した場合1ラウンド朦朧状態となる。朦朧としたキャラクターは深度判定も不可。",
						"小舟で進んでいると、なにやら激しい水の音がする。この先は滝のようだ！行動を消費して#{getRandomDiff(dice1,52,d,0)}を行い、全員が失敗すると#{getRandomDiff(dice1,52,d,1)}の防護点無視ダメージを受ける。この判定がクリティカルだった場合、滝の裏に財宝の洞窟を発見する。罠や鍵はかかっておらず、財宝の中身は1段階高い深度の財宝テーブルを使用する。",
						"船の墓場だ。強風でマストが倒れてくる。#{getRandomDiff(dice1,53,d,0)}に失敗したPCは#{getRandomDiff(dice1,53,d,1)}の「叩き」ダメージを受けて転倒する。",
						"水がしょっぱい、ここは塩水のようだ。ミスリル製とアダマン製以外の金属鎧を身に着けている場合、#{getRandomDiff(dice1,54,d,0)}の判定に失敗すると防具の防護点#{getRandomDiff(dice1,54,d,1)}。下がった防護点は「簡易修理キット」などで修理は可能。ドライブギアの場合、シナリオ終了時にメンテナンスのため(受動防御+防護点)×50GPの費用がかかる。",
						"ここの水は冷たい、気をつけないと体力を奪われてしまう。#{getRandomDiff(dice1,55,d,0)}判定を行い、失敗するとFPに#{getRandomDiff(dice1,55,d,1)}のダメージを受ける。リザードとワイズマンは生命力判定に-3のペナルティを受ける。",
						"凄まじい勢いで間欠泉が噴き出している！#{getRandomDiff(dice1,56,d,0)}の判定に失敗すると。ランダムで1D人が間欠泉に直撃して、#{getRandomDiff(dice1,56,d,1)}の「叩き」ダメージを受ける。",
					]
				
				when 6
					table = [
						"傷付いて荒ぶった#{getRandomDiff(dice1,61,d,0)}を発見する。反応判定を行い(「動物共感」なら+4)13以上が出た場合、#{getRandomDiff(dice1,61,d,0)}はおとなしくなる。そのあと#{getRandomDiff(dice1,61,d,1)}の判定に成功すると、#{getRandomDiff(dice1,61,d,0)}がなつき、#{getRandomDiff(dice1,61,d,0)}(ペット)を手に入れることができる。反応判定が10～12の場合特に何もおこらない。反応判定が9以下だった場合、#{getRandomDiff(dice1,61,d,0)}が暴れてPC全員が1Dの防護点無視ダメージを受け、#{getRandomDiff(dice1,61,d,0)}は逃亡する。",
						"なにやら派手な魚を見つける、あれはもしやアズマに伝わる幻の魚「ニシキゴイ」か！？行動を消費して#{getRandomDiff(dice1,62,d,0)}の判定に成功すると見事つり上げ、持ち帰ると#{getRandomDiff(dice1,62,d,1)}GPとなる。判定にファンブルすると逃げられ、以後判定できなくなる。撤退・全滅した場合ニシキゴイは消滅する。",
						"カエルの合唱が響き渡る。何やら意味がある歌声に聞こえるが・・・#{getRandomDiff(dice1,63,d,0)}の判定に成功すると歌の意味を理解できる。「動物共感」があればこの判定に+4のボーナスを得る。カエル達は安全な道を教えてくれていたのだ。判定に成功した場合深度が2D増加する。判定に失敗すると毒の沼に足を踏み入れ、PC全員が#{getRandomDiff(dice1,63,d,1)}の防護点無視ダメージを受ける。",
						"老齢のグラントが岩に腰かけ釣りをしている。このイベントが発生するとモンスターは消滅する。「どうだね、よかったら釣り勝負をやっていかないか？グラントの太公望(#{getRandomDiff(dice1,64,d,0)})とPCの<釣り>技能で行動を消費して即決勝負を行う。成功度で勝利した場合、「見事じゃ、そこにあるガラクタはワシには必要ない物じゃから好きに持っていくがいい」と財宝を渡してくれる。財宝の中身は1段階高い深度の財宝テーブルを使用する。",
						"船の墓場だ、ここは何かありそうな感じがする。#{getRandomDiff(dice1,65,d,0)}に成功すると「2D×#{getRandomDiff(dice1,65,d,1)}」GPを入手できる。判定がクリティカルだった場合、それに加えて財宝も入手可能。財宝の中身は1段階高い深度の財宝テーブルを使用する。",
						"貝の群生地だ。#{getRandomDiff(dice1,66,d,0)}に成功すると真珠が見つかる。行動を消費して<水泳-4>か<潜水>を行い、1人成功するごとに#{getRandomDiff(dice1,66,d,1)}GPを入手可能。水泳や潜水の判定に失敗した場合はFPに1点のダメージを受ける。",
					]
				
				else
					table = nil
			end
		
		when 5
			area = "森林"
			case dice2
				when 1
					table = [
						"回復の泉。PC全員のHP・MP・FPが完全に回復する。気絶・朦朧状態も回復。",
						"鬱蒼とした森の奥に見事な佇まいの茶室を見つける。【ソチャデスガ】を使用した際の回復量が2倍になる。パーティーにサスライがいない場合は友好的なカラクリフラウ(CL6)がいて、「PTの人数×20」GPで<茶道15>の【ソチャデスガ】を使用してくれる。",
						"おいしそうな果実を見つける。<植物学>か<動植物知識-3>で判定を行い、成功するとHPとFPが#{getRandomDiff(dice1,13,d,0)}回復する。",
						"果実を育てているフラウに出会う。「PTの人数×20」GP払うとジャンル「果実」のマジカルクッキングを行うことができる。品質が良いので<調理>には+2のボーナスを得る。できた料理の効果はその場で適用する。",
						"森の中にひっそりとたたずむジンジャを発見して、ナインテイルのカンヌシかミコが旅の無事を祈ってくれる。パーティー全員に【不死なる炎+5】がかかり、最終イベントに入るまで、死亡判定に自動的に成功するようになる。この効果が続いている間、保険を適用した状態で死亡判定に突入しても帰還せずにその戦闘を継続することが可能。",
						"食人植物の花粉による回復の泉の幻影。パーティーメンバーのHP・MP・FPのいずれかが減少している場合このイベントは拒否できない。パーティーの誰かが#{getRandomDiff(dice1,16,d,0)}に成功しない限り食人植物の群生地にふらふらと入ってしまい、全員が#{getRandomDiff(dice1,16,d,1)}の「切り」ダメージを受ける。パーティーにフラウがいれば事前に気が付きダメージは受けない",
					]
				
				when 2
					table = [
						"財宝(カギ・トラップなし)。財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギつき。行動を消費して#{getRandomDiff(dice1,22,d,0)}に成功すれば開く)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギなし、トラップつき。行動を消費して#{getRandomDiff(dice1,23,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギ、トラップつき。行動を消費して#{getRandomDiff(dice1,24,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"ミミックの罠。ランダムなキャラクターに3Dの「切り」ダメージを与える。#{getRandomDiff(dice1,25,d,0)}に成功すればこの罠を見抜いて無効化することができ、なおかつ「深度×#{getRandomDiff(dice1,25,d,1)}」GPを入手可能。",
						"トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。#{getRandomDiff(dice1,26,d,0)}に成功すればこの罠を見抜いて無効化することができる。",
					]
				
				when 3
					table = [
						"#{getRandomDiff(dice1,31,d,0)}に成功すれば獣道を発見し深度が2D増加する。「動物共感」があれば判定不要。",
						"複雑で迷いそうな密林に迷い込んでしまう。鳥たちが古い言葉の会話を鳴声で再現しており、#{getRandomDiff(dice1,32,d,0)}に成功するとこの森について秘密がわかり深度が1D増加する。失敗した場合道に迷い進行度が1D減少する。",
						"兎たちがこちらを伺っている。「動物共感」があれば道案内をしてくれ、深度が1D増加する。この時マジカルクッキングで作ったものが「キャロットタルト」だった場合は「動物共感」があるのと同じように深度が1D増加するうえ、以後ラウンド開始時にずっとこの効果を得ることができる。",
						"毒草の群生地だ。直進すると進行度が1D増加するが、#{getRandomDiff(dice1,34,d,0)}判定に失敗するとHPとFPに#{getRandomDiff(dice1,34,d,1)}の防護点無視ダメージを受ける。遠回りする場合、進行度が1D減少する。",
						"背の高い草が生い茂っており、岩も多く進みづらい、飛行を能力を持ったPCが先の様子を確認しない限り、移動に手間取り進行度が2D減少する。ペット「スカイサーチャー」や魔法《飛行》《魔法の目》でも確認可能。",
						"森林火災に遭遇する、進行方向から動物たちが逃げ出していくのが見える。迂回して安全策を通るなら進行度が2D減少する。このまま進む場合シナリオ終了までラウンド開始時に炎により#{getRandomDiff(dice1,36,d,0)}の「叩き」ダメージを受ける。",
					]
				
				when 4
					table = [
						"#{getRandomDiff(dice1,41,d,0)}とエンカウント。2ラウンド経過するとキャンディークラウンは戦場全域に《べたべた》をかけて逃亡する。",
						"動物狩りを楽しんでいた魔族と偶然遭遇してしまう。#{getRandomDiff(dice1,42,d,0)}とエンカウント。#{getRandomDiff(dice1,42,d,1)}には全員《ぼやけ5》がかかった状態。#{getRandomDiff(dice1,42,d,2)}減らしておくこと。",
						"魔族の偵察隊と遭遇する。#{getRandomDiff(dice1,43,d,0)}とエンカウント。オウルセージのうち1体は行動ターンに逃亡して他の魔族に警戒を呼び掛けに行く。これを阻止できなかった場合、以後出現する「分類：魔族」のモンスターは物理攻撃の致傷力+#{getRandomDiff(dice1,43,d,1)}、防護点+#{getRandomDiff(dice1,43,d,1)}のボーナスを得る。",
						"木々の間を飛び回る何かに背後から突然襲撃される。#{getRandomDiff(dice1,44,d,0)}。ペット「スカイサーチャー」か「広視界」がなければ必ず相手の先制攻撃になり、その際PC先手で進行中の場合もモンスター先手に変更される。",
						"果物を採取する少女達を発見する。しかしよく見ると血塗れの鋏を持つ人形だった！#{getRandomDiff(dice1,45,d,0)}とエンカウント。パーティーメンバー全員が#{getRandomDiff(dice1,45,d,1)}で判定を行い、成功すれば回避可能。",
						"前方の森に何か違和感を感じる。周囲に擬態していた#{getRandomDiff(dice1,46,d,0)}。「視覚-5」か「第六感」の判定に成功していなければ必ず相手の先制攻撃になり、その際PC先手で進行中の場合もモンスター先手に変更される。判定成功時は深度を1D減少させて戦闘回避も可能。",
					]
				
				when 5
					table = [
						"良い香りが周囲に満ちていく。闘争心を失わせるキノコの香りで、戦闘中だった場合敵味方ともに剣を収め強制的に戦闘終了となる。また、以後シナリオ終了まで「平和愛好：専守防衛」の特徴を得る。(意志判定に失敗するとイニシアチブ判定に自動敗北)この効果を受けたくない場合、#{getRandomDiff(dice1,51,d,0)}のいずれかの判定に成功する必要がある。この判定には「鋭敏味覚」のレベル分ボーナスを得る。",
						"美味しそうな果実が生っているのを見つける。意志判定に失敗するとすぐに食べてしまうが(「グルメ」の場合「意志-3」)興奮作用のある実のため頭に血が昇ってしまう。HPとFPが#{getRandomDiff(dice1,52,d,0)}回復するが「バーサーク」の特徴を得る。",
						"巧妙なベアトラップが仕掛けてある。ランダムなキャラクター1人(モンスターも含む)に#{getRandomDiff(dice1,53,d,0)}の「切り」ダメージを与える。以後ターンの最初に#{getRandomDiff(dice1,53,d,1)}の判定に成功するまで移動不可。本人か隣接したキャラクターが行動を消費して#{getRandomDiff(dice1,53,d,2)}で判定することでも解除可能。",
						"突然のスコールに見舞われる。#{getRandomDiff(dice1,54,d,0)}判定を行い、失敗すると体温が奪われFPに#{getRandomDiff(dice1,54,d,1)}のダメージを受ける。リザードとワイズマンはこの効果を受けない。<気象学-3>に成功すればあらかじめ雨宿りができ、この効果を受けない。森林イベント3-6の山火事が起きていた場合、その効果は消滅する。",
						"巨大食虫植物の群生地に足を踏み入れてしまう。#{getRandomDiff(dice1,55,d,0)}で判定を行い、失敗するとランダムで1人が植物に飲み込まれてしまう。強酸により#{getRandomDiff(dice1,55,d,1)}の「叩き」ダメージを受け、金属でない鎧を装備していた場合1Dで1、2が出ると破壊される。",
						"すさまじい悪臭を放つ巨大な花。#{getRandomDiff(dice1,56,d,0)}判定に失敗したキャラクターはシナリオ終了まで知力が#{getRandomDiff(dice1,56,d,1)}点減少する(最大MPは変化しないものとする)また、対応技能が<技師/魔道具>以外のペットは匂いで気絶してシナリオ終了まで効果を得られなくなる。",
					]
				
				when 6
					table = [
						"魔族の狩りにより深く傷ついたクレッセントムーンを発見する。<応急処置-7>か<獣医-3>の判定に成功すると、クレッセントムーンの傷は完治し、クレッセントムーン(ペット)を手に入れることができる。",
						"少し開けた原っぱで、フラウのダンスパーティーに誘われる。このイベントが発生するとモンスターは消滅する#{getRandomDiff(dice1,62,d,0)}で判定を行い、成功するとそこにキノコが生え始める。フラウは協力してくれたお礼にこのキノコを分けてくれる。大変貴重な珍味で、持ち帰ると「(1D+成功度)×#{getRandomDiff(dice1,62,d,1)}」GPになる。",
						"フラウたちが「森ガールファッションコンテスト」を開催しており、その助っ人を依頼される。このイベントが発生するとモンスターは消滅する。#{getRandomDiff(dice1,63,d,0)}に成功すると自然と一体化したファッションが高評価を受け、お礼に#{getRandomDiff(dice1,63,d,1)}(装飾品)を入手できる。",
						"霊樹の花にたまった水が魔力を帯びている。<神秘学>に成功するとそれにポーションとしての効果があることが分かる。1Dを振り、その出目に対応したポーションが手に入る。
----------
#{getRandomDiff(dice1,64,d,0)}
----------",
						"迷子のフラウを見つける。イベント表で他のフラウに出会った場合そのフラウと知り合いで、お礼に財宝を渡してくれる。財宝の中身は1段階高い深度の財宝テーブルを使用する。フラウに出会えずシナリオをクリアした場合も、1段階低い深度の財宝テーブルの中身をくれる。",
						"ランダムに選んだPC1人が、うっかり泉に武器を落としてしまう。すると女神が出て落とした武器と同じ技能で扱うもので、価格が一ランク上のアイテムを落としたのかと聞いてくる。落とした武器と提示してきた武器の差額を1000で割った値をペナルティとして意志判定を行うこと。「守銭奴」はペナルティが2倍になるが、「正直」の場合は自動的に成功になる。成功すると正直に答え提示されたアイテムを両方手に入れることができるが、失敗すると嘘をついて女神を怒らせてしまい、武器を失う。落とした武器が10000GP以上だった場合や、それ以上の武器がアイテムリストになかった場合、自動的にアイテムは返却してもらえる。",
					]
				
				else
					table = nil
			end
			
		when 6
			area = "墓地"
			case dice2
				when 1
					table = [
						"回復の泉。PC全員のHP・MP・FPが完全に回復する。気絶・朦朧状態も回復。",
						"アズマ風の墓石が佇んでいる。<地域知識/アズマ><地域知識/カベノナカ-4>のいずれかで判定を行う。成功すると正しくお参りを行うことができ、HP、FP、MPの全てが#{getRandomDiff(dice1,12,d,0)}回復する。失敗すると霊を怒らせ、全員がFPに#{getRandomDiff(dice1,12,d,1)}のダメージを受ける。",
						"墓守の休憩所を見つける。様々な薬草が置いてあり、行動を消費して<応急処置>を行うことができる。成功すれば#{getRandomDiff(dice1,13,d,0)}のHPが回復する。",
						"ヒガンバナの世話をするフラウと出会う。100GPを払うと「ヒガンバナの毒」を武器に塗ってもらうことができる。最終ダメージに+2の効果があり、武器の通じない「ファントム」のようなモンスターにも武器による攻撃が有効になる。この効果はシナリオ終了時まで持続する。",
						"シルヴァテイルのネクロマンサー達が集まって、何やら怪しい儀式をしている。道中で死亡もしくは保険を適用して強制送還されたキャラクターがいれば、#{getRandomDiff(dice1,15,d,0)}GPを支払うことで復活させてもらうことができる。それ以外の場合、何か不気味な儀式に不安を感じ、FPを1点消耗する。",
						"回復の泉があるのだが・・・？パーティーメンバーのHP・MP・FPのいずれかが減少している場合このイベントは拒否できない。HP・MP・FPが完全に回復して気絶や朦朧からも立ち直るが、黄泉の国の水を飲んだことで迷宮から出るまで「分類：アンデッド」となる。回復魔法の効果などは通常の効果があるが、一部の技や魔法で特攻を受ける。《閃光》を受けた際も3Dの防護点無視ダメージを受ける。",
					]
				
				when 2
					table = [
						"財宝(カギ・トラップなし)。財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギつき。行動を消費して#{getRandomDiff(dice1,22,d,0)}に成功すれば開く)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギなし、トラップつき。行動を消費して#{getRandomDiff(dice1,23,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"財宝(カギ、トラップつき。行動を消費して#{getRandomDiff(dice1,24,d,0)}に成功すれば解除可能)財宝の中身は1段階低い深度の財宝テーブルを使用する。",
						"ミミックの罠。ランダムなキャラクターに3Dの「切り」ダメージを与える。#{getRandomDiff(dice1,25,d,0)}に成功すればこの罠を見抜いて無効化することができ、なおかつ「深度×#{getRandomDiff(dice1,25,d,1)}」GPを入手可能。",
						"トレジャーイーターの罠。冒険中に入手したアイテム(消耗品・GP以外)を全て失う。#{getRandomDiff(dice1,26,d,0)}に成功すればこの罠を見抜いて無効化することができる。",
					]
				
				when 3
					table = [
						"なにもなさそうな道だが、#{getRandomDiff(dice1,31,d,0)}で判定を行う。成功するとちょっとなにかでそうな近道を発見する。深度が2D増加するが、「臆病」なキャラクターは意志判定が必要。",
						"舗装されていて通りやすい道が続く。深度が1D増加する。途中には祠があり、マジカルクッキングで作った食べ物を持っていた場合、それをお供えすることでHP・MP・FPが全回復する。",
						"道が途切れ、草が伸び放題の荒れ地に出る。進むには骨が折れそうだ。#{getRandomDiff(dice1,33,d,0)}に成功すれば深度+2。失敗するとFPに#{getRandomDiff(dice1,33,d,1)}点のダメージを受ける。",
						"どこまでも卒塔婆とススキしかない・・・同じ景色が続き進んでいるか怪しくなる。2分の1の確率で深度が1D減少する。「方向感覚」があればこの効果は無視できる。",
						"地面から突如骨の手が伸び移動を邪魔する。全員「移動力+5」を目標値に判定を行い、失敗したキャラクターの人数だけ深度が減少する。【死者に鞭】を持つネクロマンサーがいればこの効果は無視できる。",
						"先へ進む道には死者の呪いが満ちている。そのまま進むと深度が1D増加するが、以後全ての判定の目標値に#{getRandomDiff(dice1,36,d,0)}のペナルティを受ける。遠回りをすると悪影響は受けないが深度が1D減少する。【死者に鞭】を持つネクロマンサーがいれば直進しても悪影響を受けない。",
					]
				
				when 4
					table = [
						"#{getRandomDiff(dice1,41,d,0)}とエンカウント。2ラウンド経過するとキャンディークラウンは戦場全域に《べたべた》をかけて逃亡する。",
						"朽ちていた骨が突如起き上がり襲いかかる。#{getRandomDiff(dice1,42,d,0)}。「第六感」の判定に成功していなければ必ず相手の先制攻撃になり、その際PC先手で進行中の場合もモンスター先手に変更される。",
						"不吉な歌を口すざみ、ステップを踏みながらかわいらしい少女が近づいてくる。#{getRandomDiff(dice1,43,d,0)}とエンカウント。#{getRandomDiff(dice1,43,d,1)}の「華劇」は最初から#{getRandomDiff(dice1,43,d,2)}段階進行している。",
						"遠くから不吉な進軍の音を聞く。PCは全員「聴覚-4」か「第六感」で判定を行うこと。ネクロマンサーは知力判定を行ってもよい。誰か1人でも判定に成功すれば、魔将グレイヴディガーの軍勢が迫っているのを知り、深度を1D減少させてひとまず逃亡することができる。全員判定に失敗してしまうとPCは魔将グレイヴディガー(CL200)とその配下である無数の亡霊騎士団と相対することになる。#{getRandomDiff(dice1,44,d,0)}",
						"貴族の棺とそれを守る人形。#{getRandomDiff(dice1,45,d,0)}とエンカウント。棺の中には貴金属が入っており、#{getRandomDiff(dice1,45,d,1)}を倒せば「深度×#{getRandomDiff(dice1,45,d,2)}」GPを入手可能。",
						"壁に埋まった10mはあろうかという巨大な蛇の骨が、動き出し襲いかかってくる。#{getRandomDiff(dice1,46,d,0)}。",
					]
				
				when 5
					table = [
						"PC全員に墓から突然幻影が襲いかかる。#{getRandomDiff(dice1,51,d,0)}判定に失敗すると気を取られ「受け」か「止め」を1回消費する。「受け」も「止め」も行えない場合腰を抜かして転倒してしまう。",
						"ギロチンが突如PCのうちランダムに1人に目掛けて落ちてくる。盾の受動防御を無視した#{getRandomDiff(dice1,52,d,0)}に失敗すると#{getRandomDiff(dice1,52,d,1)}の「切り」ダメージを受ける。",
						"用途不明の建物に迷い込む。#{getRandomDiff(dice1,53,d,0)}に成功すると、その建物が火葬場であると判明し、すぐに脱出できる。判定に失敗するとPC全員が火炎で#{getRandomDiff(dice1,53,d,1)}の「叩き」ダメージを受ける。",
						"墓石が動き出し中から何かが出てこようとしている。行動を消費して#{getRandomDiff(dice1,54,d,0)}で判定を行い、成功すればなにも起こらない。失敗した場合、探索中に倒されたモンスターの中で最もCLが高いモンスターと再度エンカウントする(深度判定終了後)該当するモンスターが存在しなかった場合、#{getRandomDiff(dice1,54,d,1)}が出現する。",
						"金の亡者が群がってくる。「2D×#{getRandomDiff(dice1,55,d,0)}」GPを払うと支払うと満足して去っていくが、支払を拒否した場合はPC全員が#{getRandomDiff(dice1,55,d,1)}の「叩き」ダメージを受ける。【死者に鞭】を持つネクロマンサーがいればこの効果は無視できる。",
						"ランダムなPC1人の武器が死者の怨念を吸い取り魔剣となる。魔剣は致傷力に+2のボーナスを得るが、所有者は最大HPが5点減少し、不利な特徴「バーサーク」「残忍」を持つようになる。魔剣には「マジックパウダー：無」が常にかかっているものとみなす。魔剣となった武器は売却不可能で、不要な場合捨てるしかない。すでに魔剣になっている武器と、グラントの宝剣は魔剣にはならない。",
					]
				
				when 6
					table = [
						"雷が突然鳴り響く。その場にいる全てのキャラクター(モンスター含む)は全員3Dを振り、金属鎧を着ているキャラクターはその値に+3する。この値が一番高いキャラクターは電撃により#{getRandomDiff(dice1,61,d,0)}の「叩き」ダメージを受ける(金属鎧の防護点を無視)",
						"タルの上に腰かけ酒を口に運び続ける、減ることのない酒に向き合うスケルトンがいる。「どうだ、お前らも飲んでいくか？」と声をかけられる。酒を飲む場合、#{getRandomDiff(dice1,62,d,0)}判定を4回連続で行うこと。全て成功した場合は、「ついに酒が切れたか、最後の晩酌に付き合ってもらって感謝する」と感謝を述べて財宝を渡してくれる。財宝の中身は1段階高い深度の財宝テーブルを使用する。途中で1度でも失敗した場合、酒に悪酔いしてシナリオ終了まで全ての判定に-1のペナルティを受ける。",
						"妖しい輝きを放つ宝石を発見する。手にとると呪われてシナリオ終了まで全ての判定に#{getRandomDiff(dice1,63,d,0)}のペナルティを受ける。手にとらない場合は意志判定に成功しなければならず、「守銭奴」「好奇心」「直情」がある場合意志判定に-3のペナルティを受ける(不利な特徴が複数ある場合修正は累積する)無事持ち帰った場合呪いは解け、#{getRandomDiff(dice1,63,d,1)}GPで売却できる",
						"朽ちたギアの墓場。まだ使えるギアがあるかもしれない。<技師/魔道具>の判定を行い、5成功以上ならアイテムが入手可能。アイテムの内容は1Dで決定する。
----------
#{getRandomDiff(dice1,64,d,0)}
----------",
						"うすら寒い気配の漂う川辺に出る。川辺には渡し守らしき、ローブをかぶった2人の少女がいる。1人あたり#{getRandomDiff(dice1,65,d,0)}GPを支払えば深度が1D増加する。支払を拒否した場合は#{getRandomDiff(dice1,65,d,1)}。",
						"『千ノ戦イデ千ノ勝チ方ヲ知ル者、ココニ眠ル』と刻まれた棺を見つける。「好奇心」「直情」のキャラクターは開けずにいるには意志判定が必要。棺を開けた場合は#{getRandomDiff(dice1,66,d,0)}。勝利した場合、通常のドロップとは別に#{getRandomDiff(dice1,66,d,1)}(《戻る武器》は無し)が必ず手に入る。
----------
#{getRandomDiff(dice1,66,d,2)}
----------",
					]
				
				else
					table = nil
			end
		
		else
			return nil
	end
	
	return area, dif, table
  end
  
  def getRandomDiff(dice1, dice23, dif, index)
  table = []
  
	case dice1
		when 1 #洞窟
			table = [
				[12, [
						['1', '2', '3', '4']
				]],
				[13, [
						['<植物学>か<動植物知識-3>', '<植物学-2>か<動植物知識-5>', '<植物学-4>か<動植物知識-7>', '<植物学-8>か<動植物知識-11>'],
						['5', '10', '15', '20'],
				]],
				
				[22, [
						['<鍵開け-3>', '<鍵開け-5>', '<鍵開け-7>', '<鍵開け-11>']
				]],
				[23, [
						['<罠-3>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				[24, [
						['<罠-3><鍵開け-3>', '<罠-5><鍵開け-5>', '<罠-7><鍵開け-7>', '<罠-11><鍵開け-11>']
				]],
				[25, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>'],
						['100', '200', '300', '500'],
				]],
				[26, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				
				[34, [
						['<軽業>', '<軽業-2>', '<軽業-4>', '<軽業-8>'],
						['3D', '4D', '6D', '10D'],
				]],
				[35, [
						['HP30', 'HP60', 'HP90', 'HP150']
				]],
				[36, [
						['「知力-1」', '「知力-2」', '「知力-3」', '「知力-5」']
				]],
				
				[41, [
						['キャンディークラウン(CL40)', 'キャンディークラウン(CL40)「1D-3」匹(最低1匹)', 'キャンディークラウン(CL40)「1D-2」匹(最低1匹)、出目が6だった場合ゴールデンクラウン(CL177)1匹', 'ゴールデンクラウン(CL177)']
				]],
				[42, [
						['ベルセルク(CL7)×3とエンカウント。', 'ベルセルク(CL7)×3とエンカウント。', 'ベルセルク(CL15)×3とエンカウント、命中+10、ST24、HP+40、FP+8。', 'ベルセルク(CL25)×3とエンカウント、命中+20、ST32、HP+90、FP+18。'],
						['争っていたためHPとFPは半減している', '', '', ''],
				]],
				[43, [
						['ロックバトラー(CL6)×3とエンカウント。', 'ガーゴイル(CL10)×3とエンカウント、【ハイドインシャドウ】を追加。', 'ガーゴイル(CL15)×3とエンカウント、以下のように強化。', 'ザッハーク(CL39)×2とエンカウント。'],
						['', '', '
----------
ガーゴイル（ＣＬ１５）　魔族/岩石
ＳＴ２０　ＤＸ１３　ＩＱ１３　ＨＴ１８　ＨＰ６３　ＦＰ３３
受防３　防護１８　移動６（飛行）　よけ６　受け８　止め－
ガーゴイルの戦槌１６（両手メイス）・・・命中２０　３ｄ＋８「叩き」　重量５
・ニンジャ
【ハイドインシャドウ】
・グラント
【グランドインペイル＋３】【エクステンドインペイル】【トルマリンスパーク＋３】
【チェーンスパーク】【グラビティブレイク＋４】【グラビティパニッシュ】
----------', ''],
				]],
				[44, [
						['デビルホール(CL18)とエンカウント。', 'デビルホイール(CL22)とエンカウント、防護点+2、HP+12。', 'デビルホイール(CL26)とエンカウント、防護点+4、HP+24。', 'ムスペルヘイムの獣(CL65)とエンカウント。'],
						['5D', '6D', '8D', '12D'],
				]],
				[45, [
						['3D', '4D', '5D', '6D'],
						['ヘルハウンド(CL12)、インプ(CL3)×2', 'ヘルハウンド(CL12)×2', 'フェニックス(CL25)、ヘルハウンド(CL12)×2', '火龍ヘルブレイザー(CL50)、ケルベロス(CL33)'],
				]],
				[46, [
						['1D', '1D+1', '2D', '3D'],
						['アイスメイデン(CL10)、アイスリザード(CL7)、スノー(CL3)', 'カロン(CL12)×2、アイスメイデン(CL10)', 'クリスタルビースト(CL25)×2', '氷龍グレイシャル(CL65)'],
				]],
				
				[52, [
						['3ヘクス', '5ヘクス', '7ヘクス', '12ヘクス'],
						['3D', '5D', '7D', '12D'],
				]],
				[53, [
						['「生命力-4」', '「生命力-6」', '「生命力-8」', '「生命力-12」']
				]],
				[54, [
						['2D', '3D', '5D', '10D']
				]],
				[55, [
						['「よけ」', '「よけ-2」', '「よけ-4」', '「よけ-8」'],
						['5D', '7D', '9D', '15D'],
				]],
				
				[61, [
						['<天文学-5>', '<天文学-5>', '<天文学-7>', '<天文学-11>'],
						['レア装飾品「星の怒り」かレア魔法《彗星》(好きな方)', 'レア装飾品「星の怒り」かレア魔法《彗星》(好きな方)', 'レア魔法《流星群》', 'レア魔法《滅びの矢》'],
				]],
				[62, [
						['2', '3', '4', '5']
				]],
				[63, [
						['7', '9', '11', '15']
				]],
				[64, [
						['50', '100', '150', '200']
				]],
				[66, [
						['《粉砕3》', '《粉砕4》', '《粉砕6》', '《粉砕10》'],
						['HP30', 'HP60', 'HP90', 'HP150'],
				]],
			]
			
		when 2 #遺跡
			table = [
				[12, [
						['2D', '3D', '4D', '6D']
				]],
				[13, [
						['<錬金術>か<医師-3>', '<錬金術-2>か<医師-5>', '<錬金術-4>か<医師-7>', '<錬金術-8>か<医師-11>']
				]],
				[16, [
						['3000GP', '4000GP', '6000GP', '10000GP'],
						['5000GP', '10000GP', '20000GP', '40000GP'],
						['8D', '10D', '15D', '20D'],
				]],
				
				[22, [
						['<鍵開け-3>', '<鍵開け-5>', '<鍵開け-7>', '<鍵開け-11>']
				]],
				[23, [
						['<罠-3>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				[24, [
						['<罠-3><鍵開け-3>', '<罠-5><鍵開け-5>', '<罠-7><鍵開け-7>', '<罠-11><鍵開け-11>']
				]],
				[25, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>'],
						['100', '200', '300', '500'],
				]],
				[26, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				
				[31, [
						['<身振り-3><演技><演劇>', '<身振り-5><演技-2><演劇-2>', '<身振り-7><演技-4><演劇-4>', '<身振り-11><演技-8><演劇-8>'],
				]],
				[32, [
						['<モンスター知識-5>か<地域知識/カベノソト-3>', '<モンスター知識-7>か<地域知識/カベノソト-5>', '<モンスター知識-9>か<地域知識/カベノソト-7>', '<モンスター知識-13>か<地域知識/カベノソト-11>'],
				]],
				[33, [
						['に等しい', '×2の', '×3の', '×5の'],
				]],
				[34, [
						['<登攀>', '<登攀-2>', '<登攀-4>', '<登攀-8>'],
				]],
				[35, [
						['「敏捷力」', '「敏捷力-2」', '「敏捷力-4」', '「敏捷力-8」'],
						['6D', '8D', '10D', '15D'],
				]],
				[36, [
						['「知力-5」', '知力-6', '「知力-7」', '「知力-9」'],
				]],
				
				[41, [
						['キャンディークラウン(CL40)', 'キャンディークラウン(CL40)「1D-3」匹(最低1匹)', 'キャンディークラウン(CL40)「1D-2」匹(最低1匹)、出目が6だった場合ゴールデンクラウン(CL177)1匹', 'ゴールデンクラウン(CL177)']
				]],
				[42, [
						['ガーゴイル(CL10)とエンカウント', 'ガーゴイル(CL15)とエンカウント、以下のように強化', 'ザッハーク(CL39)とエンカウント', 'ラダマンティスの蛇(CL50)×2とエンカウント、必ず敵の先制攻撃'],
						['', '
----------
ガーゴイル（ＣＬ１５）　魔族/岩石
ＳＴ２０　ＤＸ１３　ＩＱ１３　ＨＴ１８　ＨＰ６３　ＦＰ３３
受防３　防護１８　移動６（飛行）　よけ６　受け８　止め－
宝石への命中判定ペナルティは－１０
ガーゴイルの戦槌１６（両手メイス）・・・命中２０　３ｄ＋８「叩き」　重量５
・ニンジャ
行動：【ハイドインシャドウ】　ＦＰ１　姿を消す　「視覚－５」で発見可能
・グラント
行動：【グランドインペイル＋３】＋【エクステンドインペイル＋１】（両手メイス）　ＦＰ１０
３Ｄ＋８「叩き」　受動防御無視「よけ」のみ　半径３ヘクス攻撃　射程５
行動：【トルマリンスパーク＋２】＋【チェーンスパーク】（両手メイス）　ＦＰ７
３Ｄ＋８「叩き」　命中もしくは「受け」「止め」時に電撃で２Ｄ＋２の追加ダメージ
行動：【グラビティブレイク＋２】＋【グラビティパニッシュ】（両手メイス）　ＦＰ７
３Ｄ＋１３「叩き」　「荷重レベル＋３」の回避ペナルティ　命中後１ターンペナルティ持続
----------', '', ''],
				]],
				[43, [
						['スターゲイザー(CL10)、ウイングシレイブ(CL4)', 'スターゲイザー(CL10)×2、ポイズンリリー(CL7)', 'コスモロジスト(CL20)×2、オウルコマンダー(CL18)', '栄光の天使(CL60)、ヴァルキリー(CL20)×2'],
				]],
				[44, [
						['<文学>か<礼儀作法-3>', '<文学-3>か<礼儀作法-6>', '<文学-6>か<礼儀作法-9>', '<文学-12>か<礼儀作法-15>'],
						['ヤシャ(CL10)、スケルトン(CL3)×2', 'ヤシャ(CL15、ST17、HP43、FP28、命中22に強化)、ゴースト(CL10)×2', 'ヤシャ(CL25、ST23、HP63、FP38、命中30に強化)、カロン(CL12)×2', 'コンゴウ(CL60)×2'],
				]],
				[45, [
						['ヘルハウンド(CL12)', 'ケルベロス(CL33)', '火龍ヘルブレイザー(CL50)', '煉獄龍バーガトリ(CL100)'],
				]],
				[46, [
						['ゴーレム(CL12)', 'ミスリルゴーレム(CL27)', 'アダマンゴーレム(CL45)', 'カラクリヒメショウグン(CL75)'],
						['2D', '3D', '4D', '4D'],
				]],
				
				[51, [
						['「よけ」', '「よけ-2」', '「よけ-4」', '「よけ-8」'],
						['1D+3', '2D+1', '2d+3', '4D'],
						['「生命力」', '「生命力-2」', '「生命力-4」', '「生命力-8」'],
						['1D', '2D', '3D', '5D'],
				]],
				[52, [
						['「生命力-3」', '「生命力-5」', '「生命力-7」', '「生命力-11」'],
				]],
				[53, [
						['HPを2倍に計算しCLは10とする', 'HPを3倍に計算しCLは15とする', 'HPを4倍に計算しCLは20とする', 'HPを6倍に計算しCLは30とする'],
				]],
				[54, [
						['「意志」', '「意志-2」', '「意志-4」', '「意志-8」'],
				]],
				[56, [
						['「現在の深度÷2」以下のCLのモンスター', '「現在の深度」以下のCLのモンスター', '「現在の深度×1.5」以下のCLのモンスター', 'CL80以下のモンスター(ネームド以外)'],
				]],
				
				[62, [
						['6', '7', '8', '10'],
						['9', '10', '11', '14'],
						['12', '13', '14', '16'],
				]],
				[64, [
						['<医師>か<考古学>', '<医師-2>か<考古学-2>', '<医師-4>か<考古学-4>', '<医師-8>か<考古学-8>'],
				]],
				[65, [
						['', '', '、ゴールデンクラウン(CL177)', '、ゴールデンクラウン(CL177)×2'],
				]],
				[66, [
						['30', '60', '90', '150'],
						['「深度÷2」', '「深度」', '「深度×1.5」', '「深度×2」'],
				]],
			]
			
		when 3 #断崖
			table = [
				[12, [
						['「意志」', '「意志-2」', '「意志-4」', '「意志-7」'],
				]],
				[13, [
						['2D', '3D', '4D', '6D'],
				]],
				[14, [
						['1D', '2D', '3D', '5D'],
				]],
				[15, [
						['500', '1000', '2000', '4000'],
				]],
				[16, [
						['500', '1000', '2000', '4000'],
				]],
			
				[22, [
						['<鍵開け-3>', '<鍵開け-5>', '<鍵開け-7>', '<鍵開け-11>'],
				]],
				[23, [
						['<罠-3>', '<罠-5>', '<罠-7>', '<罠-11>'],
				]],
				[24, [
						['<罠-3><鍵開け-3>', '<罠-5><鍵開け-5>', '<罠-7><鍵開け-7>', '<罠-11><鍵開け-11>'],
				]],
				[25, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>'],
						['100', '200', '300', '500'],
				]],
				[26, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>'],
				]],
				
				[31, [
						['<登攀>', '<登攀-2>', '<登攀-4>', '<登攀-7>'],
				]],
				[32, [
						['<運転/アカシックホイール>', '<運転/アカシックホイール-2>', '<運転/アカシックホイール/-4>', '<運転/アカシックホイール-7>'],
				]],
				[33, [
						['<生存>', '<生存-2>', '<生存-4>', '<生存-7>'],
				]],
				[35, [
						['<神秘学>', '<神秘学-2>', '<神秘学-4>', '<神秘学-7>'],
				]],
				[36, [
						['「体力」', '「体力-2」', '「体力-4」', '「体力-8」'],
				]],
				
				[41, [
						['キャンディークラウン(CL40)', 'キャンディークラウン(CL40)「1D-3」匹(最低1匹)', 'キャンディークラウン(CL40)「1D-2」匹(最低1匹)、出目が6だった場合ゴールデンクラウン(CL177)1匹', 'ゴールデンクラウン(CL177)'],
				]],
				[42, [
						['ウイングスレイブ(CL4)×2とエンカウント', 'ウイングスレイブ(CL8)×2とエンカウント、致傷力+1、命中+2、HP+8', 'ウイングスレイブ(CL12)×2とエンカウント、致傷力+3、命中+6、HP+16', 'ガルーダ(CL40)×2とエンカウント'],
				]],
				[43, [
						['ブラックナイト(CL10)、ソルジャー(CL4)×2、オーク(CL3)', 'ブラックナイト(CL10)×2、ハタモト(CL10)、サーバント(CL5)', 'サーバントマスター(CL35)、ヘルハウンド(CL12)×2', 'ジェネラル(CL55)、サーバントマスター(CL35)、ケルベロス(CL33)'],
				]],
				[44, [
						['ガーゴイル(CL10)とエンカウント', 'ガーゴイル(CL15)とエンカウント、以下のように強化', 'ザッハーク(CL39)とエンカウント', '銀河龍ラクテア(CL90)とエンカウント'],
						['ガーゴイル', 'ガーゴイル', 'ザッハーク', '銀河龍ラクテア'],
						['', '
----------
ガーゴイル(CL15)　魔族/岩石
ST20　DX13　IQ13　HT18　HP63　FP33
受防3　防護18　移動6(飛行)　よけ6　受け8　止め-
宝石への命中判定ペナルティは-10
ガーゴイルの戦槌16(両手メイス)・・・命中20　3D+8「叩き」　重量5
・ニンジャ
行動：【ハイドインシャドウ】　ＦＰ1　姿を消す　「視覚-5」で発見可能
・グラント
行動：【グランドインペイル+3】+【エクステンドインペイル+1】（両手メイス）　FP10
3D+8「叩き」　受動防御無視「よけ」のみ　半径3ヘクス攻撃　射程5
行動：【トルマリンスパーク+2】+【チェーンスパーク】(両手メイス)　FP7
3D+8「叩き」　命中もしくは「受け」「止め」時に電撃で2D+2の追加ダメージ
行動：【グラビティブレイク+2】＋【グラビティパニッシュ】(両手メイス)　FP7
3D+13「叩き」　「荷重レベル+3」の回避ペナルティ　命中後1ターンペナルティ持続
----------', '', ''],
				]],
				[45, [
						['カボチャの魔女(CL8)×2とエンカウント', 'カボチャの魔女(CL10)×2とエンカウント、《カボチャの雨》の致傷力+1Dされ、生命力-1で気絶判定、HP+2', 'カボチャの魔女(CL14)×2とエンカウント、《カボチャの雨》の致傷力+2Dされ生命力-3で気絶判定、HP+6', 'カボチャの大魔女(CL35)×2とエンカウント'],
						['', '', '', '
----------
カボチャの大魔女(CL35)　魔族
ST11 DX15 IQ20 HT15 HP120 MP160 FP81
受防1 防護4 移動10(飛行)よけ10 受け- 止め-
<戦術20>　イニシアチブ値12
・ソーサルギア
《韋駄天》《火炎武器》《氷結武器》《電撃武器》《べたべた》
《音噴射》《集団誘眠》《粉砕８》
・センチュリオン
イニシ：【ファーストムーブ】(戦術)　FP3 イニシアチブ判定に自動的に勝利
・アークメイジ
ダメージ後：【マナシールド+2】　FP3　HPダメージをMPで肩代わり 1ターンに3回まで
支援：【ダブルキャスト】　FP5　次の行動ターンに連続で魔法が使用可能
行動：【テンペスト】　FP7　他の魔法に追加使用　「通常」の魔法や呪術を周囲半径10ヘクスに　CT：シナリオ
・オリジナル魔法
《カボチャの大災厄》(パンプキンカタストロフ)　通常　消費30
半径5ヘクスの敵味方を区別せず6Dの「叩き」ダメージを与える。
隙間なく降り注ぐカボチャは回避不可能で、
1点でもダメージを受けると「生命力-6」判定を行い、失敗すると気絶する
----------'],
				]],
				[46, [
						['フェニックス(CL25)', 'フェニックス(CL30)', 'フェニックス(CL35)', '煉獄フェニックス(CL85)'],
						['', '、クチバシの致傷力+2、命中+4、アクセルギア【ディザスタープログラム】を追加', '、クチバシの致傷力+4、命中+8、アクセルギア【ディザスタープログラム】を追加', ''],
				]],
				
				[51, [
						['「敏捷力-3」', '「敏捷力-4」', '「敏捷力-5」', '「敏捷力-7」'],
						['3D+5', '5D+5', '7D+5', '11D+5'],
				]],
				[52, [
						['<登攀>', '<登攀-2>', '<登攀-4>', '<登攀-7>'],
						['4D', '6D', '8D', '12D'],
				]],
				[53, [
						['「敏捷力」', '「敏捷力-2」', '「敏捷力-4」', '「敏捷力-7」'],
						['', '', '', '判定失敗時さらに最も単価の高い消耗品を自分のヘクスに落とす(拾うには行動消費)'],
				]],
				[54, [
						['', '', '《べたべた》判定後、『銀糸の甲殻』アルゲントゥム(CL40・ネームド)とエンカウント。', '《べたべた》判定後、『銀糸の甲殻』アルゲントゥム(CL50・ネームド)×2とエンカウント、あらゆる致傷力+2D、命中判定+8。'],
				]],
				[55, [
						['<生存-3>', '<生存-5>', '<生存-7>', '<生存-11>'],
						['4D', '5D', '6D', '8D'],
				]],
				[56, [
						['防護点2、HP80', '防護点4、HP120', '防護点6、HP160', '防護点8、HP320'],
				]],
				
				[61, [
						['-2', '-3', '-4', '-6'],
				]],
				[62, [
						['100', '200', '300', '500'],
				]],
				[63, [
						['', '', '1Dを2回振って属性決定、2回攻撃で破壊。', '1Dを3回振って属性決定、3回攻撃で破壊。'],
				]],
				[64, [
						['「ジャンボ串焼き」', '「ジャンボ串焼き」「グラント風香草焼き」のいずれか(選択可能)', '「ジャンボ串焼き」「グラント風香草焼き」「ドラゴンステーキ」のいずれか(選択可能)', '「ジャンボ串焼き」「グラント風香草焼き」「ドラゴンステーキ」「マツザカスペシャル」のいずれか(選択可能)'],
				]],
				[65, [
						['<植物学><医師><動植物知識-3>', '<植物学-2><医師-2><動植物知識-5>', '<植物学-4><医師-4><動植物知識-7>', '<植物知識-7><医師-7><動植物知識-11>'],
						['100', '200', '300', '500'],
				]],
				[66, [
						['「視覚-5」か<武具屋>', '「視覚-7」か<武具屋-2>', '「視覚-9」か<武具屋-4>', '「視覚-13」か<武具屋-7>'],
						['10000', '20000', '30000', '60000'],
				]],
			]
			
		when 4 #水辺
			table = [
				[12, [
						['1D', '2D', '3D', '5D'],
				]],
				[16, [
						['<毒物-5>', '<毒物-7>', '<毒物-9>', '<毒物-13>'],
						['1D', '2D', '3D', '5D']
				]],
				
				[22, [
						['<鍵開け-3>', '<鍵開け-5>', '<鍵開け-7>', '<鍵開け-11>']
				]],
				[23, [
						['<罠-3>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				[24, [
						['<罠-3><鍵開け-3>', '<罠-5><鍵開け-5>', '<罠-7><鍵開け-7>', '<罠-11><鍵開け-11>']
				]],
				[25, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>'],
						['100', '200', '300', '500'],
				]],
				[26, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				
				[31, [
						['<生存>', '<生存-2>', '<生存-4>', '<生存-7>'],
				]],
				[32, [
						['<登攀>か<軽業>', '<登攀-2>か<軽業-2>', '<登攀-4>か<軽業-4>', '<登攀-8>か<軽業-8>'],
				]],
				[34, [
						['「視覚-5」', '「視覚-6」', '「視覚-7」', '「視覚-11」'],
				]],
				[35, [
						['「体力-5」', '「体力-6」', '「体力-7」', '「体力-9」'],
				]],
				[36, [
						['<船乗り-3>', '<船乗り-5>', '<船乗り-7>', '<船乗り-11>'],
				]],
				
				[41, [
						['キャンディークラウン(CL40)', 'キャンディークラウン(CL40)「1D-3」匹(最低1匹)', 'キャンディークラウン(CL40)「1D-2」匹(最低1匹)、出目が6だった場合ゴールデンクラウン(CL177)1匹', 'ゴールデンクラウン(CL177)']
				]],
				[42, [
						['アシガル(CL4)×2、アイスリザード(CL7)', 'ハタモト(CL10)×2、アイスリザード(CL7)', 'ナイトライダー(CL15)×2、アイスメイデン(CL10)', 'スカーレス(CL38)×3'],
				]],
				[43, [
						['アンブッシュマン(CL5)×3とエンカウント', 'アンブッシュマン(CL9)×3とエンカウント、致傷力+2、命中+4、HP+8、FP+4', 'アンブッシュマン(CL13)×3とエンカウント、致傷力+4、命中+8、HP16、FP+8', 'シャドウストーカー(CL35)×2とエンカウント'],
						['「視覚-5」', '「視覚-5」', '「視覚-5」', '「視覚-9」'],
				]],
				[44, [
						['アップルドール(CL12)', 'アップルドール(CL12)×2', 'アップルドール(CL12)×2とポイズンリリー(CL7)×2', '水陸両用改造型アップルドール(CL30)×2とバリアリーフ(CL27)'],
				]],
				[45, [
						['ジェルスケルトン(CL10)とエンカウント', 'ジェルスケルトン(CL15)とエンカウント、ST21、命中+2、防護6、HP+15、FP+10', 'ジェルスケルトン(CL20)とエンカウント、ST25、命中+4、防護8、HP+30、FP+20', 'ジェルスケルトン(CL40)とエンカウント、ST45、命中+12、防護12、HP+90、FP+60'],
				]],
				[46, [
						['ナイトライダー(CL15)とエンカウント', 'ナイトライダー(CL15)×2とエンカウント', 'ナイトライダー(CL15)×2、バリアリーフ(CL27)とエンカウント', 'ジェネラル(CL55)、バリアリーフ(CL27)とエンカウント、ジェネラルはペット「スワンプランナー」に<乗馬20>で騎乗、移動8'],
				]],
				
				[51, [
						['「意志-3」', '「意志-4」', '「意志-5」', '「意志-7」'],
				]],
				[52, [
						['<水泳>', '<水泳-2>', '<水泳-4>', '<水泳-8>'],
						['8D', '10D', '12D', '20D'],
				]],
				[53, [
						['「よけ」', '「よけ-2」', '「よけ-4」', '「よけ-8」'],
						['4D', '6D', '8D', '12D'],
				]],
				[54, [
						['<武具屋>', '<武具屋-2>', '<武具屋-4>', '<武具屋-8>'],
						['-2', '-3', '-4', '-6'],
				]],
				[55, [
						['「生命力」', '「生命力-2」', '「生命力-4」', '「生命力-8」'],
						['1D', '2D', '3D', '5D'],
				]],
				[56, [
						['<地質学>か「聴覚-7」', '<地質学-2>か「聴覚-9」', '<地質学-4>か「聴覚-11」', '<地質学-8>か「聴覚-15」'],
						['5D', '7D', '9D', '13D'],
				]],
				
				[61, [
						['スワンプランナー', 'スワンプランナー', 'スワンプランナー', 'ゴールデンコーン'],
						['<応急処置-4>か<獣医>', '<応急処置-4>か<獣医>', '<応急処置-4>か<獣医>', '<応急処置-10>か<獣医-6>'],
				]],
				[62, [
						['<釣り-5>', '<釣り-7>', '<釣り-9>', '<釣り-13>'],
						['3000', '6000', '9000', '18000'],
				]],
				[63, [
						['<歌唱-3>か<作詞>', '<歌唱-5>か<作詞-2>', '<歌唱-7>か<作詞-4>', '<歌唱-11>か<作詞-8>'],
						['2D', '3D', '4D', '6D'],
				]],
				[64, [
						['<釣り20>', '<釣り22>', '<釣り24>', '<釣り28>'],
				]],
				[65, [
						['<探索-3>', '<探索-5>', '<探索-7>', '<探索-11>'],
						['100', '200', '300', '500'],
				]],
				[66, [
						['<動植物知識>', '<動植物知識-2>', '<動植物知識-4>', '<動植物知識-8>'],
						['1000', '2000', '3000', '5000'],
				]],
			]
			
		when 5 #森林
			table = [
				[13, [
						['2D', '3D', '4D', '6D'],
				]],
				[16, [
						['<植物学-3>か<動植物知識-5>', '<植物学-5>か<動植物知識-7>', '<植物学-7>か<動植物知識-9>', '<植物学-11>か<動植物知識-13>'],
						['3D', '4D', '6D', '9D'],
				]],
				
				[22, [
						['<鍵開け-3>', '<鍵開け-5>', '<鍵開け-7>', '<鍵開け-11>']
				]],
				[23, [
						['<罠-3>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				[24, [
						['<罠-3><鍵開け-3>', '<罠-5><鍵開け-5>', '<罠-7><鍵開け-7>', '<罠-11><鍵開け-11>']
				]],
				[25, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>'],
						['100', '200', '300', '500'],
				]],
				[26, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				
				[31, [
						['<生存>', '<生存-2>', '<生存-4>', '<生存-8>'],
				]],
				[32, [
						['<考古学>', '<考古学-2>', '<考古学-4>', '<考古学-8>'],
				]],
				[34, [
						['「生命力」', '「生命力-2」', '「生命力-4」', '「生命力-8」'],
						['1D', '2D', '3D', '5D'],
				]],
				[36, [
						['2D', '3D', '4D', '6D'],
				]],
				
				[41, [
						['キャンディークラウン(CL40)', 'キャンディークラウン(CL40)「1D-3」匹(最低1匹)', 'キャンディークラウン(CL40)「1D-2」匹(最低1匹)、出目が6だった場合ゴールデンクラウン(CL177)1匹', 'ゴールデンクラウン(CL177)']
				]],
				[42, [
						['スターゲイザー(CL10)、オーク(CL3)×3', 'スターゲイザー(CL10)、ヘルハウンド(CL12)×2', 'コスモロジスト(CL20)、ナイトライダー(CL15)×2', 'サーバントマスター(CL35)、ガルーダ(40)×2'],
						['オーク', 'ヘルハウンド', 'ナイトライダー', 'ガルーダ'],
						['スターゲイザーのMPを15点', 'スターゲイザーのMPを10点', 'コスモロジストのMPを10点', 'サーバントマスターのMPを10点'],
				]],
				[43, [
						['オウルセイージ(CL5)×2、インプ(CL3)、オーク(CL3)', 'オウルセージ(CL5)×3、キメラ(CL15)', 'オウルコマンダー(CL18)×2、ブラックナイト(CL10)×2', 'オウルコマンダー(CL18)×2、ヨウコ(CL30)、アダマンゴーレム(CL45)'],
						['2', '3', '4', '6'],
				]],
				[44, [
						['ｇールデンビースト(CL10)とエンカウント', 'ゴールデンビースト(CL15)とエンカウント、致傷力+2、命中+4、HP+10、FP+10', 'ゴールデンビースト(CL25)とエンカウント、致傷力+4、命中+10、HP+30、FP+30', 'イビルオーメン(CL42)×2とエンカウント'],
				]],
				[45, [
						['アップルドール(CL12)、ポイズンリリー(CL7)', 'アップルドール(CL12)×2、ポイズンリリー(CL7)', '水陸両用改造型アップルドール(CL30)、グリーンアクトレス(CL22)', '水陸両用改造型アップルドール(CL30)×2、リッチ(CL44)'],
						['<忍び>', '<忍び-1>', '<忍び-2>', '<忍び-4>'],
				]],
				[46, [
						['キメラ(CL15)とエンカウント', 'キメラ(CL20)とエンカウント、防護+2、致傷力+2、命中+4、HP+20、FP+10', '防護+4、致傷力+6、命中+10、HP+60、FP+30', 'キメラグレート(CL60)とエンカウント'],
				]],
				
				[51, [
						['<毒物><植物学><動植物知識-3>', '<毒物-2><植物学-2><動植物知識-5>', '<毒物-4><植物学-4><動植物知識-7>', '<毒物-8><植物学-8><動植物知識-11>'],
				]],
				[52, [
						['2D', '3D', '4D', '5D'],
				]],
				[53, [
						['2D', '4D', '6D', '10D'],
						['「体力-5」', '「体力-7」', '「体力-9」', '「体力-13」'],
						['<罠-5>', '<罠-7>', '<罠-9>', '<罠-13>'],
				]],
				[54, [
						['1D', '2D', '3D', '5D'],
						['「生命力」', '「生命力-2」', '「生命力-4」', '「生命力-8」'],
				]],
				[55, [
						['<植物学>か<動植物知識-3>', '<植物学-2>か<動植物知識-5>', '<植物学-2>か<動植物知識-5>', '<植物学-2>か<動植物知識-5>'],
						['3D', '5D', '7D', '11D'],
				]],
				[56, [
						['「生命力」', '「生命力-2」', '「生命力-4」', '「生命力-8」'],
						['1', '2', '3', '4'],
				]],
				
				[62, [
						['<踊り>', '<踊り-2>', '<踊り-4>', '<踊り-8>'],
						['200', '400', '600', '1000'],
				]],
				[63, [
						['<偽装-5>', '<偽装-9>', '<偽装-13>', '<偽装-19>'],
						['狩人の羽帽子', '緊急召喚の宝珠', '毒の香水瓶', '女王の花冠'],
				]],
				[64, [
						[
'1:高級クイックHPポーション
2:高級クイックMPポーション
3:高級クイックスタミナポーション
4:クイック解毒ポーション
5:クイック中和ポーション
6:高級抵抗ポーション',
'1:高級クイックHPポーション
2:高級クイックMPポーション
3:高級クイックスタミナポーション
4:クイック解毒ポーション
5:クイック中和ポーション
6:高級抵抗ポーション',
'1:高級クイックHPポーション
2:最高級クイックMPポーション
3:最高級クイックスタミナポーション
4:加速ポーション
5:加速ポーション
6:最高級抵抗ポーション',
'1:特製クイックHPポーション
2:特製クイックHPポーション
3:特製クイックMPポーション
4:特製クイックMPポーション
5:特製クイックスタミナポーション
6:特製クイックスタミナポーション'
						],
				]],
			]
			
		when 6 #墓地
			table = [
				
				[12, [
						['2D', '3D', '4D', '6D'],
						['1D', '3D', '5D', '8D'],
				]],
				[13, [
						['2D', '3D', '4D', '6D'],
				]],
				[15, [
						['1000', '2000', '3000', '5000'],
				]],
			
				[22, [
						['<鍵開け-3>', '<鍵開け-5>', '<鍵開け-7>', '<鍵開け-11>']
				]],
				[23, [
						['<罠-3>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				[24, [
						['<罠-3><鍵開け-3>', '<罠-5><鍵開け-5>', '<罠-7><鍵開け-7>', '<罠-11><鍵開け-11>']
				]],
				[25, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>'],
						['100', '200', '300', '500'],
				]],
				[26, [
						['<罠-5>', '<罠-5>', '<罠-7>', '<罠-11>']
				]],
				
				[31, [
						['「視覚-5」', '「視覚-7」', '「視覚-9」', '「視覚-13」'],
				]],
				[33, [
						['<生存>', '<生存-2>', '<生存-4>', '<生存-8>'],
						['2', '4', '6', '10'],
				]],
				[36, [
						['-1', '-2', '-3', '-4'],
				]],
				
				[41, [
						['キャンディークラウン(CL40)', 'キャンディークラウン(CL40)「1D-3」匹(最低1匹)', 'キャンディークラウン(CL40)「1D-2」匹(最低1匹)、出目が6だった場合ゴールデンクラウン(CL177)1匹', 'ゴールデンクラウン(CL177)']
				]],
				[42, [
						['スケルトン(CL3)×3とエンカウント', 'スケルトン(CL3)×6とエンカウント、致傷力+2、命中+2', 'デッドリーローズ(CL15)×3とエンカウント、スケルトン化しており「叩きダメージボーナス2倍」を追加', '堕ちた黒竜(CL48)×3とエンカウント、スケルトン化しており「叩きダメージボーナス2倍」を追加'],
				]],
				[43, [
						['ポイズンリリー(CL7)、ファントム(CL5)×2', 'ポイズンリリー(CL7)、ゴースト(CL10)×2', 'グリーンアクトレス(CL22)、デュラハン(CL22)×2', 'グリーンアクトレス(CL22)、ヒトキリ(CL33)×2'],
						['ポイズンリリー', 'ポイズンリリー', 'グリーンアクトレス', 'グリーンアクトレス'],
						['1', '2', '3', '4'],
				]],
				[44, [
						['「保険」に入っていなければPC達は死亡し、グレイヴディガーの配下にさせられてしまう。冒険はここで終了だ。', '「保険」に入っていなければPC達は死亡し、グレイヴディガーの配下にさせられてしまう。冒険はここで終了だ。', '「保険」に入っていなければPC達は死亡し、グレイヴディガーの配下にさせられてしまう。冒険はここで終了だ。', '『葬送者』グレイヴディガー(CL200・魔将)、『ディガー様親衛隊隊長』フュネライユ(CL66・ネームド)、エルダーリッチ(CL55)、イビルオーメン(CL42)×2とエンカウント。'],
				]],
				[45, [
						['ゴースト(CL10)、ソルジャー(CL4)×2', 'ゴースト(CL10)、ハタモト(CL10)×2', 'デュラハン(CL22)、ハタモト(CL10)×3', 'エルダーリッチ(CL55)、アダマンゴーレム(CL45)×2'],
						['ゴースト', 'ゴースト', 'デュラハン', 'エルダーリッチ'],
						['100', '200', '300', '500'],
				]],
				[46, [
						['ボーンスネーク(CL20)とエンカウント', 'ボーンスネーク(CL20)×2とエンカウント', 'ボーンスネーク(CL20)×3とエンカウント、致傷力+2', 'ラダマンティスの蛇(CL50)×2とエンカウント、半ば化石になりかけており「叩きダメージボーナス2倍」を追加'],
				]],
				
				[51, [
						['「意志」', '「意志-2」', '「意志-4」', '「意志-8」'],
				]],
				[52, [
						['「よけ」', '「よけ-2」', '「よけ-4」', '「よけ-8」'],
						['3D', '5D', '7D', '11D'],
				]],
				[53, [
						['<建築>', '<建築-2>', '<建築-4>', '<建築-8>'],
						['3D', '5D', '7D', '11D'],
				]],
				[54, [
						['「体力-3」', '「体力-5」', '「体力-7」', '「体力-11」'],
						['ジェルスケルトン(CL10)', 'ボーンスネーク(CL20)', 'リッチ(CL44)', '『ディガー様親衛隊隊長』フュネライユ(CL66・ネームド)'],
				]],
				[55, [
						['100', '200', '400', '1000'],
						['3D', '5D', '7D', '11D'],
				]],
				
				[61, [
						['5D', '7D', '9D', '13D'],
				]],
				[62, [
						['「生命力」', '「生命力-1」', '「生命力-2」', '「製絵魅力-4」'],
				]],
				[63, [
						['-1', '-2', '-3', '-4'],
						['2000', '6000', '20000', '60000'],
				]],
				[64, [
						[
'1:火炎弾×5(アームガン弾薬)
2:冷凍弾×5(アームガン弾薬)
3:貫甲弾×3(アームガン弾薬)
4:簡易ソーサルセット(装飾品)
5:ギアテール(装飾品)
6:パイルバンカー高速収納装置(装飾品)',
'1:火炎弾×5(アームガン弾薬)
2:冷凍弾×5(アームガン弾薬)
3:貫甲弾×3(アームガン弾薬)
4:ゴーレムアーム(装飾品)
5:ゴーレムアーム(装飾品)
6:ホイールブースター(装飾品)',
'1:火炎弾×5(アームガン弾薬)
2:冷凍弾×5(アームガン弾薬)
3:貫甲弾×3(アームガン弾薬)
4:ヒュージーミスリルフィスト(装飾品)
5:ヒュージーミスリルフィスト(装飾品)
6:ヒュージーブレード(両手剣)',
'1:火炎弾×5(アームガン弾薬)
2:冷凍弾×5(アームガン弾薬)
3:貫甲弾×3(アームガン弾薬)
4:ヒュージーブレード(両手剣)
5:ヒュージーブレード(両手剣)
6:ナグルファル装甲(装飾品)'
						],
				]],
				[65, [
						['200', '500', '1000', '5000'],
						['カロン(CL12)×2とエンカウント', 'カロン(CL12)×2とエンカウント、致傷力+2', 'カロンキャプテン(CL25)×2とエンカウント', 'エルダーリッチ(CL55)×2とエンカウント'],
				]],
				[66, [
						['墓場のブラックナイト(CL10)とエンカウント', '墓場のブラックナイト(CL20)とエンカウント', '墓場のブラックナイト(CL30)とエンカウント', '墓場のハイペリオンダミー(CL100)とエンカウント'],
						['キメラウェポンズ', 'キメラウェポンズ', 'キメラウェポンズ', 'グレートキメラウェポンズ'],
						[
'墓場のブラックナイト(標準CL10)　魔族
攻防ともに高い能力を持つ、魔族のエリート騎士。
常時《倍速》で武器には《戻る武器》がかかっている。
ST16　DX15　IQ12　HT15　HP45　FP26
受防3(金属鎧)　防護6(金属鎧)　移動5　よけ5　受け9　止め-
常時《倍速》　<跳躍18>
キメラウェポンズ18(特殊)・・・攻撃ごとに形状変化　上質　壊れない　《戻る武器》
キメラウェポンズ/両手剣・・・命中21　2D+6「切り」　射程2
キメラウェポンズ/両手メイス・・・命中21　2D+7「叩き」　射程2
キメラウェポンズ/両手斧・・・命中21　2D+6「切り」　射程2
キメラウェポンズ/長槍・・・命中21　2D+6「刺し」　射程3
・ウォリアー
行動：【クロスブレイク】+【ハイスピードブレイク】(両手剣)　FP6　2D+7「切り」　2回攻撃
行動：【リープアタック】+【ジェノサイドリープ】(両手剣)　FP4
2D+6「切り」<跳躍>でフェイント　2体まで攻撃　移動妨害・大振りにならない
行動：【ヘビースマッシュ】(両手メイス)　FP2　2D+13「叩き」
行動：【トマホークミサイル】(両手斧)　FP2　2D+8「切り」　回避-2　半致傷16　最大射程24
行動：【スターダストフォール】(長槍)　FP3　1D+6　回避-3　半致傷16　最大射程24
行動：【ワールウィンド】(長槍)　FP3　2D+6「切り」　周囲半径3ヘクス
・オリジナル
【騎士の闘気】
使用：常時　判定：なし　疲労：なし　強化：×
ターンの最初にFPを3点回復する。
所有レア：漆黒の甲冑(鎧)',

'墓場のブラックナイト(標準CL20)　魔族
攻防ともに高い能力を持つ、魔族のエリート騎士。
常時《倍速》で武器には《戻る武器》がかかっている。
ST16　DX15　IQ12　HT15　HP75　FP36
受防3(金属鎧)　防護6(金属鎧)　移動5　よけ5　受け9　止め-
常時《倍速》　<跳躍18>
キメラウェポンズ18(特殊)・・・攻撃ごとに形状変化　上質　壊れない　《戻る武器》
キメラウェポンズ/両手剣・・・命中31　2D+10「切り」　射程2
キメラウェポンズ/両手メイス・・・命中31　2D+11「叩き」　射程2
キメラウェポンズ/両手斧・・・命中31　2D+10「切り」　射程2
キメラウェポンズ/長槍・・・命中31　2D+10「刺し」　射程3
・ウォリアー
行動：【クロスブレイク】+【ハイスピードブレイク】(両手剣)　FP6　2D+11「切り」　2回攻撃
行動：【リープアタック】+【ジェノサイドリープ】(両手剣)　FP4
2D+10「切り」<跳躍>でフェイント　2体まで攻撃　移動妨害・大振りにならない
行動：【ヘビースマッシュ】(両手メイス)　FP2　2D+17「叩き」
行動：【トマホークミサイル】(両手斧)　FP2　2D+12「切り」　回避-2　半致傷16　最大射程24
行動：【スターダストフォール】(長槍)　FP3　1D+10　回避-3　半致傷16　最大射程24
行動：【ワールウィンド】(長槍)　FP3　2D+10「切り」　周囲半径3ヘクス
・オリジナル
【騎士の闘気】
使用：常時　判定：なし　疲労：なし　強化：×
ターンの最初にFPを3点回復する。
所有レア：漆黒の甲冑(鎧)',

'墓場のブラックナイト(標準CL30)　魔族
攻防ともに高い能力を持つ、魔族のエリート騎士。
常時《倍速》で武器には《戻る武器》がかかっている。
ST16　DX15　IQ12　HT15　HP105　FP46
受防3(金属鎧)　防護6(金属鎧)　移動5　よけ5　受け9　止め-
常時《倍速》　<跳躍18>
キメラウェポンズ18(特殊)・・・攻撃ごとに形状変化　上質　壊れない　《戻る武器》
キメラウェポンズ/両手剣・・・命中41　2D+14「切り」　射程2
キメラウェポンズ/両手メイス・・・命中41　2D+15「叩き」　射程2
キメラウェポンズ/両手斧・・・命中41　2D+14「切り」　射程2
キメラウェポンズ/長槍・・・命中41　2D+14「刺し」　射程3
・ウォリアー
行動：【クロスブレイク】+【ハイスピードブレイク】(両手剣)　FP6　2D+15「切り」　2回攻撃
行動：【リープアタック】+【ジェノサイドリープ】(両手剣)　FP4
2D+14「切り」<跳躍>でフェイント　2体まで攻撃　移動妨害・大振りにならない
行動：【ヘビースマッシュ】(両手メイス)　FP2　2D+21「叩き」
行動：【トマホークミサイル】(両手斧)　FP2　2D+16「切り」　回避-2　半致傷16　最大射程24
行動：【スターダストフォール】(長槍)　FP3　1D+14　回避-3　半致傷16　最大射程24
行動：【ワールウィンド】(長槍)　FP3　2D+14「切り」　周囲半径3ヘクス
・オリジナル
【騎士の闘気】
使用：常時　判定：なし　疲労：なし　強化：×
ターンの最初にFPを3点回復する。
所有レア：漆黒の甲冑(鎧)',

'墓場のハイペリオンダミー(標準CL100)　魔族
第三魔将ハイペリオンを模して造られたダミー装甲。
常時《倍速》で武器には《戻る武器》がかかっている。
ST75　DX22　IQ15　HT27　HP527　FP275
受防4　防護15　移動10　よけ10　受け14　止め-
バッドステータス無効　ファンブル無効　切り刺しダメージボーナス無効
常時《倍速》　<戦術20>　イニシアチブ値12　装備重量150ｋｇ
グレートキメラウェポンズ28(特殊)・・・攻撃ごとに形状変化　最高品質　《戻る武器》
キメラウェポンズ/両手剣・・・命中58　17D+10「切り」　射程2
キメラウェポンズ/両手メイス・・・命中58　17D+11「叩き」　射程2
キメラウェポンズ/両手斧・・・命中58　17D+10「切り」　射程2
キメラウェポンズ/長槍・・・命中58　17D+10「刺し」　射程3
世界樹装甲・・・防護点が減少しない(一時的な「防護点無視」の効果は受ける)
着用者のHPをターンの最初に10点回復する
・ウォリアー
行動：【クロスブレイク+5】+【ハイスピードブレイク+5】(両手剣)　FP16
17D+16「切り」　回避-5　2回攻撃
行動：【ヘビースマッシュ+5】+【ヘビーストライク】(両手メイス)　FP11
17D+40「切り」　「受け」「止め」時に装備を破壊　「生命力-6」に失敗すると朦朧
行動：【トマホークミサイル+5】+【トールハンマー】(両手斧)　FP10
命中64　17D+27「切り」　回避-2　半致傷750　最大射程1120
行動：【スターダストフォール+5】+【プロミストビクトリー】(長槍)　FP12
8D+20「刺し」　必中クリティカル　クリティカル表参照なし　射撃攻撃　半致傷75　最大射程112
行動：【ワールウィンド+5】+【バイオレントウィンド】(長槍)　FP
17D+10+(移動距離÷2)「切り」　周囲半径3ヘクス　「敏捷-9」で転倒判定　大振りにならない
・センチュリオン
イニシ：【ファーストムーブ】(戦術)　FP3　イニシアチブ判定に自動的に勝利
回避：【ツーハンドプロテクト】　FP3　武器技能の3分の2で「受け」を行う
行動：【ソニックブーム+4】　FP7　他の技に追加使用　近接物理攻撃の射程が50に
ダメージ後：【アドバンストガード】　FP5　近接物理攻撃で受けた最終ダメージを半減　CT：次
・マスターナイト
行動：【グレートチャージ】　FP5　他の近接技に追加使用　致傷力+15
行動：【シーズエンジン】　FP6　他の射撃技に追加使用　「切り」+3D　「刺し」+2D
・オリジナル
【無限の闘気】
使用：常時　判定：なし　疲労：なし　強化：×
ターンの最初にFPを30点回復する。
【障壁破壊】
使用：常時　判定：なし　疲労：なし　強化：×
移動および攻撃時に《物質障壁》《完全障壁》の影響を受けない。
また、ハイペリオンダミーの攻撃は受動防御のみで回避することができない。
所有レア：世界樹装甲(鎧)'],
				]],
			]
			
		else
			return "[ERROR:getRandomDiff]"
	end
  
    result = get_table_by_number(dice23, table)
	return result[index][dif]
  end
end
